/********************************************************************************
** Form generated from reading UI file 'about.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ABOUT_H
#define UI_ABOUT_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QWidget>

namespace KvManager {

class Ui_AboutDialog
{
public:
    QGridLayout *gridLayout;
    QTabWidget *tabWidget;
    QWidget *tab;
    QGridLayout *gridLayout_2;
    QLabel *iconLabel;
    QLabel *titleLabel;
    QLabel *textLabel;
    QSpacerItem *verticalSpacer;
    QSpacerItem *verticalSpacer_2;
    QWidget *tab_2;
    QGridLayout *gridLayout_3;
    QTextBrowser *textBrowser;
    QWidget *tab_3;
    QGridLayout *gridLayout_4;
    QTextBrowser *textBrowser_2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *AboutDialog)
    {
        if (AboutDialog->objectName().isEmpty())
            AboutDialog->setObjectName("AboutDialog");
        AboutDialog->resize(400, 300);
        AboutDialog->setWindowTitle(QString::fromUtf8("Dialog"));
        gridLayout = new QGridLayout(AboutDialog);
        gridLayout->setObjectName("gridLayout");
        tabWidget = new QTabWidget(AboutDialog);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        gridLayout_2 = new QGridLayout(tab);
        gridLayout_2->setObjectName("gridLayout_2");
        iconLabel = new QLabel(tab);
        iconLabel->setObjectName("iconLabel");
        iconLabel->setAlignment(Qt::AlignCenter);

        gridLayout_2->addWidget(iconLabel, 0, 0, 1, 1);

        titleLabel = new QLabel(tab);
        titleLabel->setObjectName("titleLabel");
        titleLabel->setAlignment(Qt::AlignCenter);

        gridLayout_2->addWidget(titleLabel, 1, 0, 1, 1);

        textLabel = new QLabel(tab);
        textLabel->setObjectName("textLabel");
        textLabel->setAlignment(Qt::AlignCenter);

        gridLayout_2->addWidget(textLabel, 3, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 2, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_2, 4, 0, 1, 1);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        gridLayout_3 = new QGridLayout(tab_2);
        gridLayout_3->setObjectName("gridLayout_3");
        textBrowser = new QTextBrowser(tab_2);
        textBrowser->setObjectName("textBrowser");
        textBrowser->setFocusPolicy(Qt::NoFocus);
        textBrowser->setHtml(QString::fromUtf8("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\"  font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Arabic (Algeria):</span> <a href=\"https://github.com/HishamAHai\">HishamAHai at GitHub</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Belarusian:</span> Zmicer Turok</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-"
                        "indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Bulgarian:</span> <a href=\"https://github.com/runtav-gyz\">runtav-gyz at GitHub</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Catalan:</span> Daniel <a href=\"https://github.com/trikaphundo\">(trikaphundo at GitHub)</a>, Joan Mir\303\263, <a href=\"https://github.com/Davidmp1\">Davidmp1 at GitHub</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-r"
                        "ight:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Chinese (Simplified):</span> <a href=\"https://github.com/jaybird1986\">jaybird1986 at GitHub</a>, Feng Yu <a href=\"https://github.com/abcfy2\">(abcfy2 at GitHub)</a>, <a href=\"https://github.com/greatyingzi\">greatyingzi at GitHub</a>, <a href=\"https://github.com/ling0412\">ling0412 at GitHub</a>, <a href=\"https://github.com/LiYulin-s\">LiYulin at GitHub</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Chinese (Traditional):</span> BigELK176</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0"
                        "px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Czech:</span> <a href=\"https://github.com/p-bo\">p-bo at GitHub</a>, <a href=\"https://github.com/Translate-SW\">Translate-SW at GitHub</a>, <a href=\"https://github.com/vikdevelop\">vikdevelop at GitHub</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Danish:</span> <a href=\"https://github.com/larshenrikoern\">larshenrikoern at GitHub</a>, Carl Andersen, Peter Jespersen <a href=\"https://github.com/PeterJespersen\"><span;>(PeterJespersen at GitHub)</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p st"
                        "yle=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Dutch:</span> Heimen Stoffels <a href=\"https://github.com/Vistaus\">(Vistaus at GitHub)</a>, <a href=\"https://github.com/Pjotr123\">Pjotr123 at GitHub</a>, <a href=\"https://github.com/PanderMusubi\">PanderMusubi at GitHub</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Esperanto:</span> Tsu Jan (author), Feike Donia <a href=\"https://github.com/feikedonia\">(feikedonia at GitHub)</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-b"
                        "ottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Estonian:</span> <a href=\"https://github.com/rimasx\">rimasx at GitHub</a>, Priit J\303\265er\303\274\303\274t, <a href=\"https://github.com/Jalakas\">Jalakas at GitHub</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Finnish:</span> <a href=\"https://github.com/mahtiankka\">MahtiAnkka at GitHub</a>, Robin, Tommi Nieminen <a href=\"https://github.com/Legisign\">(Legisign at GitHub)</a>, <a href=\"https://github.com/Chiitoo\">Chiitoo at GitHub</a>, Jouni J\303\244rvinen <a href=\"https://github.com/rautamiekka\">(rautamiekka at GitHub)</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; m"
                        "argin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">French:</span> <a href=\"https://github.com/roxfr\">roxfr at GitHub</a>, <a href=\"https://github.com/Bapt17\">Bapt17 at GitHub</a>, <a href=\"https://github.com/Wallon007\">Wallon007 at GitHub</a>, Oliver Chiasson <a href=\"https://github.com/OlivierChiasson\">(OlivierChiasson at GitHub)</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Georgian:</span> <a href=\"https://github.com/NorwayFun\">NorwayFun at GitHub</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; ma"
                        "rgin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">German:</span> Ettore Atalan <a href=\"https://github.com/Atalanttore\">(Atalanttore at GitHub)</a>, hugo G</a>, Roman Volak <a href=\"https://github.com/RomanVolak\">(RomanVolak at GitHub)</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Greek:</span> Dimitrios Glentadakis <a href=\"https://github.com/dglent\">(dglent at GitHub)</a>, Giannis Antypas</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;"
                        "\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Hebrew:</span> itay alush <a href=\"https://github.com/itayalush1\">(itayalush1 at GitHub)</a>, Omer I.S. <a href=\"https://github.com/omeritzics\">(omeritzics at GitHub)</a>, Yaron Shahrabani <a href=\"https://github.com/yarons\">(yarons at GitHub)</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Hungarian:</span> <a href=\"https://github.com/zoli111\">zoli111 at GitHub</a>, \303\201cs Zolt\303\241n</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
""
                        "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Indonesian:</span> Muhammad Andryan Noor <a href=\"https://github.com/andryNoor\">(andryNoor at GitHub)</a>, Arif Budiman <a href=\"https://github.com/arifpedia\">(arifpedia at GitHub)</a>, Gema Aji Wardian <a href=\"https://github.com/nerdv2\">(nerdv2 at GitHub)</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Italian:</span> <a href=\"https://github.com/stefonarch\">stefonarch at GitHub</a>, <a href=\"https://github.com/EncryptedEasty\">EncryptedEasty at GitHub</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-"
                        "block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Japanese:</span> Masamichi Ito <a href=\"https://github.com/ito32bit\">(ito32bit at GitHub)</a</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Korean:</span> <a href=\"https://github.com/MarongHappy\">MarongHappy at GitHub</a>, Jung-Kyu Park <a href=\"https://github.com/bagjunggyu\">(bagjunggyu at GitHub)</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; "
                        "margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Lithuanian:</span> <a href=\"https://github.com/welaq\">welaq at GitHub</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Norwegian:</span> Allan Nordh\303\270y <a href=\"https://github.com/comradekingu\">(comradekingu at GitHub)</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Polish:</span> Marcin Miko\305\202ajczak <a href=\"https://github.com/m4sk1n\">(m4sk1n at GitHub)<"
                        "/a>, Eryk Michalak <a href=\"https://github.com/gnu-ewm\">(gnu-ewm at GitHub)</a>, <a href=\"https://github.com/Daviteusz\">Daviteusz at GitHub</a>, Jan Rolsk, <a href=\"https://github.com/Nmrawe\">Nmrawe at GitHub</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Portuguese:</span> Hugo Carvalho <a href=\"https://github.com/hugok79\">(hugok79 at GitHub)</a>, S\303\251rgio Marques <a href=\"https://github.com/smarquespt\">(smarquespt at GitHub)</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><spa"
                        "n style=\" font-weight:600;\">Portuguese (Brazil):</span> Leandro Ramos <a href=\"https://github.com/leandroramos\">(leandroramos at GitHub)</a>, <a href=\"https://github.com/eltonfabricio10\">eltonfabricio10 at GitHub</a>, <a href=\"https://github.com/rodrigolinuxx\">rodrigolinuxx at GitHub</a>, <a href=\"https://github.com/BiP213\">BiP213 at GitHub</a>, <a href=\"https://github.com/cassiojsl\">cassiojsl at GitHub</a>, Gabriel Proen\303\247a Alves <a href=\"https://github.com/gabrielproencaalves\">(gabrielproencaalves at GitHub)</a>, Pedro Maimere <a href=\"https://github.com/maimere\">(maimere at GitHub)</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Punjabi:</span> Aman Alam <a href=\"https://github.com/aalam\">(aalam at GitHub)</a"
                        "></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Russian:</span> \320\235\320\270\320\272\320\276\320\273\320\260\320\271 \320\241\320\274\320\276\320\273\321\214\321\217\320\275\320\270\320\275\320\276\320\262 <a href=\"https://github.com/smolnp\">(smolnp at GitHub)</a>, Pavel Shlyak <a href=\"https://github.com/shlyakpavel\">(shlyakpavel at GitHub)</a>, <a href=\"https://github.com/4fury\">4fury at GitHub</a>, Dmitry Astankov <a href=\"https://github.com/Illumaria\">(Illumaria at GitHub)</a>, <a href=\"https://github.com/roaldiopi\">roaldiopi at GitHub</a>, Andrei Stepanov <a href=\"https://github.com/adem4ik\">(adem4ik at GitHub)</a>, <a href=\"https://github.com/kirusyaga\">kirusyaga at GitHub</a></p>\n"
"<p style=\"-qt-paragraph-type"
                        ":empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Slovak:</span> Paolo Vigoroso, <a href=\"https://github.com/Leifdin\">Leifdin at GitHub</a>, Du\305\241an Kazik <a href=\"https://github.com/prescott66\">(prescott66 at GitHub)</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Spanish:</span> <a href=\"https://github.com/micrococo\">micrococo at GitHub</a>, Maximiliano Dvyhailo <a href=\"https://github.com/MaxiDvy\">(MaxiDvy at GitHub)</a>, Robert Schneider, <a href=\"https://github.com/marianofussero\">ma"
                        "rianofussero at GitHub</a>, Juan Alvarez <a href=\"https://github.com/JotaJota96\">(JotaJota96 at GitHub)</a>, <a href=\"https://github.com/toni-em\">toni-em at GitHub</a>, <a href=\"https://github.com/Lautauro\">Lautauro at GitHub</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Turkish:</span> Mehmet Akif <a href=\"https://github.com/madanadam\">(madanadam at GitHub)</a>, Dr. Ayhan YAL\303\207INSOY <a href=\"https://github.com/ayhanyalcinsoy\">(ayhanyalcinsoy at GitHub)</a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-inde"
                        "nt:0; text-indent:0px;\"><span style=\" font-weight:600;\">Ukrainian:</span> Ihor Hordiichuk <a href=\"https://github.com/IhorHordiichuk\">(IhorHordiichuk at GitHub)</a>, Taras Panchenko <a href=\"https://github.com/TarasPanchenko\">(TarasPanchenko at GitHub)</a></p></body></html>"));
        textBrowser->setOpenExternalLinks(true);

        gridLayout_3->addWidget(textBrowser, 0, 0, 1, 1);

        tabWidget->addTab(tab_2, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        gridLayout_4 = new QGridLayout(tab_3);
        gridLayout_4->setObjectName("gridLayout_4");
        textBrowser_2 = new QTextBrowser(tab_3);
        textBrowser_2->setObjectName("textBrowser_2");
        textBrowser_2->setFocusPolicy(Qt::NoFocus);
        textBrowser_2->setHtml(QString::fromUtf8("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\"  font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-style:italic;\">Kvantum</span> is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either <a href=\"https://spdx.org/licenses/GPL-3.0+.html\"><span;>version 3 of the License</span></a>, or (at your option) any later version.</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-bloc"
                        "k-indent:0; text-indent:0px;\"><span style=\" font-style:italic;\">Kvantum</span> is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.</p></body></html>"));
        textBrowser_2->setOpenExternalLinks(true);

        gridLayout_4->addWidget(textBrowser_2, 0, 0, 1, 1);

        tabWidget->addTab(tab_3, QString());

        gridLayout->addWidget(tabWidget, 0, 0, 1, 1);

        buttonBox = new QDialogButtonBox(AboutDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        gridLayout->addWidget(buttonBox, 1, 0, 1, 1);


        retranslateUi(AboutDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, AboutDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, AboutDialog, qOverload<>(&QDialog::reject));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(AboutDialog);
    } // setupUi

    void retranslateUi(QDialog *AboutDialog)
    {
        iconLabel->setText(QString());
        titleLabel->setText(QString());
        textLabel->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(tab), QString());
        tabWidget->setTabText(tabWidget->indexOf(tab_2), QString());
        tabWidget->setTabText(tabWidget->indexOf(tab_3), QCoreApplication::translate("KvManager::AboutDialog", "License", nullptr));
        (void)AboutDialog;
    } // retranslateUi

};

} // namespace KvManager

namespace KvManager {
namespace Ui {
    class AboutDialog: public Ui_AboutDialog {};
} // namespace Ui
} // namespace KvManager

#endif // UI_ABOUT_H
