/********************************************************************************
** Form generated from reading UI file 'kvantummanager.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KVANTUMMANAGER_H
#define UI_KVANTUMMANAGER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStatusBar>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "combobox.h"

namespace KvManager {

class Ui_KvantumManager
{
public:
    QWidget *widget;
    QGridLayout *gridLayout_3;
    QToolBox *toolBox;
    QWidget *page;
    QGridLayout *gridLayout;
    QLabel *installLabel;
    QSpacerItem *verticalSpacer_1;
    QPushButton *openTheme;
    QLineEdit *lineEdit;
    QSpacerItem *verticalSpacer_3;
    QPushButton *installTheme;
    QSpacerItem *verticalSpacer_2;
    QWidget *page_2;
    QGridLayout *gridLayout_2;
    QLabel *label;
    KvManager::ComboBox *comboBox;
    QSpacerItem *verticalSpacer_6;
    QPushButton *deleteTheme;
    QPushButton *useTheme;
    QSpacerItem *verticalSpacer_5;
    QLabel *usageLabel;
    QSpacerItem *verticalSpacer_4;
    QWidget *page_3;
    QGridLayout *gridLayout_4;
    QLabel *configLabel;
    QSpacerItem *verticalSpacer_7;
    QSpacerItem *verticalSpacer_8;
    QSpacerItem *verticalSpacer_9;
    QPushButton *restoreButton;
    QPushButton *saveButton;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_5;
    QTabWidget *tabWidget;
    QWidget *tab;
    QGridLayout *gridLayout_8;
    QSpacerItem *horizontalSpacer_1;
    QCheckBox *checkBoxDolphin;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *checkBoxNormalBtn;
    QSpacerItem *horizontalSpacer_3;
    QCheckBox *checkBoxPcmanfmSide;
    QCheckBox *checkBoxIconlessBtn;
    QCheckBox *checkBoxPcmanfmView;
    QCheckBox *checkBoxIconlessMenu;
    QCheckBox *checkBoxBlurTranslucent;
    QCheckBox *checkBoxToolbar;
    QCheckBox *checkBoxBlurActive;
    QCheckBox *checkBoxVToolbar;
    QCheckBox *checkBoxKtitle;
    QCheckBox *checkBoxTint;
    QCheckBox *checkBoxMenuTitle;
    QCheckBox *checkBoxCenteredForms;
    QCheckBox *checkBoxDark;
    QCheckBox *checkBoxNoninteger;
    QCheckBox *checkBoxGrip;
    QLabel *labelTint;
    QSpinBox *spinTint;
    QCheckBox *checkBoxScrollJump;
    QLabel *labelOpacity;
    QSpinBox *spinOpacity;
    QCheckBox *checkBoxKineticScrolling;
    QLabel *labelLxqtMenu;
    QSpinBox *spinLxqtMenu;
    QWidget *tab_2;
    QGridLayout *gridLayout_9;
    QCheckBox *checkBoxNoComposite;
    QVBoxLayout *verticalLayout_2;
    QGroupBox *blurBox;
    QGridLayout *gridLayout_14;
    QSpinBox *spinMenuBlur;
    QLabel *label_11;
    QLabel *label_12;
    QSpinBox *spinTooltipBlur;
    QGroupBox *contrastBox;
    QGridLayout *gridLayout_13;
    QLabel *label_9;
    QLabel *label_8;
    QLabel *label_4;
    QDoubleSpinBox *spinContrast;
    QDoubleSpinBox *spinIntensity;
    QDoubleSpinBox *spinSaturation;
    QSpacerItem *verticalSpacer_14;
    QSpacerItem *horizontalSpacer_4;
    QCheckBox *checkBoxBlurPopup;
    QCheckBox *checkBoxShadowlessPopup;
    QCheckBox *checkBoxTrans;
    QHBoxLayout *horizontalLayout;
    QLabel *opaqueLabel;
    QSpacerItem *horizontalSpacerOpaque;
    QLineEdit *opaqueEdit;
    QSpacerItem *horizontalSpacer;
    QLabel *reduceOpacityLabel;
    QSpacerItem *horizontalSpacerWinOpacity;
    QSpinBox *spinReduceOpacity;
    QLabel *reduceMenuOpacityLabel;
    QSpacerItem *horizontalSpacerMenuOpacity;
    QSpinBox *spinReduceMenuOpacity;
    QCheckBox *checkBoxBlurWindow;
    QSpacerItem *horizontalSpacer_5;
    QCheckBox *checkBoxAnimation;
    QCheckBox *checkBoxPattern;
    QCheckBox *checkBoxInactiveness;
    QCheckBox *checkBoxTransient;
    QCheckBox *checkBoxTransientGroove;
    QWidget *tab_3;
    QGridLayout *gridLayout_10;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_7;
    QLabel *labelSmall;
    QSpinBox *spinSmall;
    QLabel *labelLarge;
    QSpinBox *spinLarge;
    QLabel *labelButton;
    QSpinBox *spinButton;
    QLabel *labelToolbar;
    QSpinBox *spinToolbar;
    QLabel *labelLayout;
    QSpinBox *spinLayout;
    QLabel *labelMarging;
    QSpinBox *spinLayoutMargin;
    QLabel *labelOverlap;
    QSpinBox *spinOverlap;
    QLabel *labelSpinWidth;
    QSpinBox *spinSpinBtnWidth;
    QLabel *labelMinScrollLength;
    QSpinBox *spinMinScrollLength;
    QSpacerItem *horizontalSpacer_7;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout_12;
    QLabel *labelTooltipDelay;
    QLabel *label_5;
    QSpinBox *spinTooltipDelay;
    QSpinBox *spinSubmenuDelay;
    QSpacerItem *horizontalSpacer_6;
    QWidget *tab_4;
    QGridLayout *gridLayout_11;
    QCheckBox *checkBoxDE;
    QCheckBox *checkBoxGroupLabel;
    QCheckBox *checkBoxInlineSpin;
    QCheckBox *checkBoxRubber;
    QCheckBox *checkBoxVSpin;
    QCheckBox *checkBoxMenubar;
    QCheckBox *checkBoxComboEdit;
    QCheckBox *checkBoxMenuToolbar;
    QCheckBox *checkBoxComboMenu;
    QCheckBox *checkBoxGroupToolbar;
    QCheckBox *checkBoxHideComboCheckboxes;
    QCheckBox *checkBoxAlt;
    QCheckBox *checkBoxleftTab;
    QCheckBox *checkBoxJoinTab;
    QCheckBox *checkBoxNoScrollArrow;
    QLabel *label_10;
    QComboBox *comboClick;
    QSpacerItem *horizontalSpacer_8;
    QSpacerItem *horizontalSpacer_9;
    QLabel *label_2;
    QComboBox *comboToolButton;
    QSpacerItem *horizontalSpacer_10;
    QCheckBox *checkBoxScrollIn;
    QLabel *label_3;
    QComboBox *comboDialogButton;
    QCheckBox *checkBoxFocusRect;
    QCheckBox *checkBoxTree;
    QLabel *labelX11Drag;
    QComboBox *comboX11Drag;
    QCheckBox *checkBoxScrollableMenu;
    QCheckBox *checkBoxBtnDrag;
    QWidget *page_4;
    QGridLayout *gridLayout_6;
    QLabel *appLabel;
    QSpacerItem *verticalSpacer_10;
    QLabel *label_6;
    QLabel *label_7;
    QSpacerItem *verticalSpacer_11;
    KvManager::ComboBox *appCombo;
    QLineEdit *appsEdit;
    QSpacerItem *verticalSpacer_13;
    QPushButton *removeAppButton;
    QPushButton *saveAppButton;
    QSpacerItem *verticalSpacer;
    QPushButton *quit;
    QPushButton *preview;
    QPushButton *aboutButton;
    QSpacerItem *verticalSpacer_12;
    QPushButton *whatsthisButton;
    QStatusBar *statusBar;

    void setupUi(QMainWindow *MainWindow)
    {
        if (MainWindow->objectName().isEmpty())
            MainWindow->setObjectName("MainWindow");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(MainWindow->sizePolicy().hasHeightForWidth());
        MainWindow->setSizePolicy(sizePolicy);
        widget = new QWidget(MainWindow);
        widget->setObjectName("widget");
        sizePolicy.setHeightForWidth(widget->sizePolicy().hasHeightForWidth());
        widget->setSizePolicy(sizePolicy);
        gridLayout_3 = new QGridLayout(widget);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setContentsMargins(-1, 10, -1, -1);
        toolBox = new QToolBox(widget);
        toolBox->setObjectName("toolBox");
        sizePolicy.setHeightForWidth(toolBox->sizePolicy().hasHeightForWidth());
        toolBox->setSizePolicy(sizePolicy);
        page = new QWidget();
        page->setObjectName("page");
        gridLayout = new QGridLayout(page);
        gridLayout->setObjectName("gridLayout");
        installLabel = new QLabel(page);
        installLabel->setObjectName("installLabel");
        installLabel->setTextFormat(Qt::RichText);
        installLabel->setWordWrap(true);
        installLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse);

        gridLayout->addWidget(installLabel, 0, 0, 1, 2);

        verticalSpacer_1 = new QSpacerItem(5, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_1, 1, 0, 1, 2);

        openTheme = new QPushButton(page);
        openTheme->setObjectName("openTheme");

        gridLayout->addWidget(openTheme, 2, 0, 1, 1);

        lineEdit = new QLineEdit(page);
        lineEdit->setObjectName("lineEdit");
        lineEdit->setMinimumSize(QSize(200, 0));

        gridLayout->addWidget(lineEdit, 2, 1, 1, 1);

        verticalSpacer_3 = new QSpacerItem(5, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_3, 3, 0, 1, 1);

        installTheme = new QPushButton(page);
        installTheme->setObjectName("installTheme");
        installTheme->setEnabled(false);

        gridLayout->addWidget(installTheme, 4, 1, 1, 1, Qt::AlignRight);

        verticalSpacer_2 = new QSpacerItem(5, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_2, 5, 0, 1, 2);

        toolBox->addItem(page, QString::fromUtf8("Install/Update Theme"));
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        gridLayout_2 = new QGridLayout(page_2);
        gridLayout_2->setObjectName("gridLayout_2");
        label = new QLabel(page_2);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 0, 0, 1, 1, Qt::AlignRight);

        comboBox = new KvManager::ComboBox(page_2);
        comboBox->setObjectName("comboBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(comboBox->sizePolicy().hasHeightForWidth());
        comboBox->setSizePolicy(sizePolicy1);
        comboBox->setMinimumSize(QSize(200, 0));

        gridLayout_2->addWidget(comboBox, 0, 1, 1, 1);

        verticalSpacer_6 = new QSpacerItem(5, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_6, 1, 0, 1, 2);

        deleteTheme = new QPushButton(page_2);
        deleteTheme->setObjectName("deleteTheme");

        gridLayout_2->addWidget(deleteTheme, 2, 0, 1, 1, Qt::AlignLeft);

        useTheme = new QPushButton(page_2);
        useTheme->setObjectName("useTheme");

        gridLayout_2->addWidget(useTheme, 2, 1, 1, 1, Qt::AlignRight);

        verticalSpacer_5 = new QSpacerItem(5, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_5, 3, 0, 1, 2);

        usageLabel = new QLabel(page_2);
        usageLabel->setObjectName("usageLabel");
        usageLabel->setTextFormat(Qt::RichText);
        usageLabel->setWordWrap(true);
        usageLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse);

        gridLayout_2->addWidget(usageLabel, 4, 0, 1, 2);

        verticalSpacer_4 = new QSpacerItem(5, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_4, 5, 0, 1, 2);

        toolBox->addItem(page_2, QString::fromUtf8("Change/Delete Theme"));
        page_3 = new QWidget();
        page_3->setObjectName("page_3");
        gridLayout_4 = new QGridLayout(page_3);
        gridLayout_4->setObjectName("gridLayout_4");
        gridLayout_4->setSizeConstraint(QLayout::SetMinimumSize);
        configLabel = new QLabel(page_3);
        configLabel->setObjectName("configLabel");
        configLabel->setWordWrap(true);
        configLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse);

        gridLayout_4->addWidget(configLabel, 0, 0, 1, 2);

        verticalSpacer_7 = new QSpacerItem(5, 15, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(verticalSpacer_7, 2, 0, 1, 2);

        verticalSpacer_8 = new QSpacerItem(5, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(verticalSpacer_8, 9, 0, 1, 2);

        verticalSpacer_9 = new QSpacerItem(5, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_4->addItem(verticalSpacer_9, 12, 0, 1, 2);

        restoreButton = new QPushButton(page_3);
        restoreButton->setObjectName("restoreButton");

        gridLayout_4->addWidget(restoreButton, 11, 0, 1, 1, Qt::AlignLeft);

        saveButton = new QPushButton(page_3);
        saveButton->setObjectName("saveButton");
        saveButton->setFocusPolicy(Qt::NoFocus);

        gridLayout_4->addWidget(saveButton, 11, 1, 1, 1, Qt::AlignRight);

        groupBox = new QGroupBox(page_3);
        groupBox->setObjectName("groupBox");
        gridLayout_5 = new QGridLayout(groupBox);
        gridLayout_5->setObjectName("gridLayout_5");
        gridLayout_5->setContentsMargins(-1, 10, -1, -1);
        tabWidget = new QTabWidget(groupBox);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        gridLayout_8 = new QGridLayout(tab);
        gridLayout_8->setObjectName("gridLayout_8");
        gridLayout_8->setSizeConstraint(QLayout::SetMinimumSize);
        horizontalSpacer_1 = new QSpacerItem(5, 5, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_8->addItem(horizontalSpacer_1, 0, 0, 1, 1);

        checkBoxDolphin = new QCheckBox(tab);
        checkBoxDolphin->setObjectName("checkBoxDolphin");

        gridLayout_8->addWidget(checkBoxDolphin, 0, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(20, 5, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_8->addItem(horizontalSpacer_2, 0, 2, 1, 1);

        checkBoxNormalBtn = new QCheckBox(tab);
        checkBoxNormalBtn->setObjectName("checkBoxNormalBtn");

        gridLayout_8->addWidget(checkBoxNormalBtn, 0, 3, 1, 2);

        horizontalSpacer_3 = new QSpacerItem(5, 5, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_8->addItem(horizontalSpacer_3, 0, 5, 1, 1);

        checkBoxPcmanfmSide = new QCheckBox(tab);
        checkBoxPcmanfmSide->setObjectName("checkBoxPcmanfmSide");

        gridLayout_8->addWidget(checkBoxPcmanfmSide, 1, 1, 1, 1);

        checkBoxIconlessBtn = new QCheckBox(tab);
        checkBoxIconlessBtn->setObjectName("checkBoxIconlessBtn");

        gridLayout_8->addWidget(checkBoxIconlessBtn, 1, 3, 1, 2);

        checkBoxPcmanfmView = new QCheckBox(tab);
        checkBoxPcmanfmView->setObjectName("checkBoxPcmanfmView");

        gridLayout_8->addWidget(checkBoxPcmanfmView, 2, 1, 1, 1);

        checkBoxIconlessMenu = new QCheckBox(tab);
        checkBoxIconlessMenu->setObjectName("checkBoxIconlessMenu");

        gridLayout_8->addWidget(checkBoxIconlessMenu, 2, 3, 1, 2);

        checkBoxBlurTranslucent = new QCheckBox(tab);
        checkBoxBlurTranslucent->setObjectName("checkBoxBlurTranslucent");

        gridLayout_8->addWidget(checkBoxBlurTranslucent, 3, 1, 1, 1);

        checkBoxToolbar = new QCheckBox(tab);
        checkBoxToolbar->setObjectName("checkBoxToolbar");

        gridLayout_8->addWidget(checkBoxToolbar, 3, 3, 1, 2);

        checkBoxBlurActive = new QCheckBox(tab);
        checkBoxBlurActive->setObjectName("checkBoxBlurActive");

        gridLayout_8->addWidget(checkBoxBlurActive, 4, 1, 1, 1);

        checkBoxVToolbar = new QCheckBox(tab);
        checkBoxVToolbar->setObjectName("checkBoxVToolbar");

        gridLayout_8->addWidget(checkBoxVToolbar, 4, 3, 1, 2);

        checkBoxKtitle = new QCheckBox(tab);
        checkBoxKtitle->setObjectName("checkBoxKtitle");

        gridLayout_8->addWidget(checkBoxKtitle, 5, 1, 1, 1);

        checkBoxTint = new QCheckBox(tab);
        checkBoxTint->setObjectName("checkBoxTint");

        gridLayout_8->addWidget(checkBoxTint, 5, 3, 1, 2);

        checkBoxMenuTitle = new QCheckBox(tab);
        checkBoxMenuTitle->setObjectName("checkBoxMenuTitle");

        gridLayout_8->addWidget(checkBoxMenuTitle, 6, 1, 1, 1);

        checkBoxCenteredForms = new QCheckBox(tab);
        checkBoxCenteredForms->setObjectName("checkBoxCenteredForms");

        gridLayout_8->addWidget(checkBoxCenteredForms, 6, 3, 1, 2);

        checkBoxDark = new QCheckBox(tab);
        checkBoxDark->setObjectName("checkBoxDark");

        gridLayout_8->addWidget(checkBoxDark, 7, 1, 1, 1);

        checkBoxNoninteger = new QCheckBox(tab);
        checkBoxNoninteger->setObjectName("checkBoxNoninteger");

        gridLayout_8->addWidget(checkBoxNoninteger, 7, 3, 1, 2);

        checkBoxGrip = new QCheckBox(tab);
        checkBoxGrip->setObjectName("checkBoxGrip");

        gridLayout_8->addWidget(checkBoxGrip, 8, 1, 1, 1);

        labelTint = new QLabel(tab);
        labelTint->setObjectName("labelTint");

        gridLayout_8->addWidget(labelTint, 8, 3, 1, 1);

        spinTint = new QSpinBox(tab);
        spinTint->setObjectName("spinTint");
        spinTint->setMaximum(100);

        gridLayout_8->addWidget(spinTint, 8, 4, 1, 1);

        checkBoxScrollJump = new QCheckBox(tab);
        checkBoxScrollJump->setObjectName("checkBoxScrollJump");

        gridLayout_8->addWidget(checkBoxScrollJump, 9, 1, 1, 1);

        labelOpacity = new QLabel(tab);
        labelOpacity->setObjectName("labelOpacity");

        gridLayout_8->addWidget(labelOpacity, 9, 3, 1, 1);

        spinOpacity = new QSpinBox(tab);
        spinOpacity->setObjectName("spinOpacity");
        spinOpacity->setMaximum(100);
        spinOpacity->setValue(100);

        gridLayout_8->addWidget(spinOpacity, 9, 4, 1, 1);

        checkBoxKineticScrolling = new QCheckBox(tab);
        checkBoxKineticScrolling->setObjectName("checkBoxKineticScrolling");
        checkBoxKineticScrolling->setEnabled(false);

        gridLayout_8->addWidget(checkBoxKineticScrolling, 10, 1, 1, 1);

        labelLxqtMenu = new QLabel(tab);
        labelLxqtMenu->setObjectName("labelLxqtMenu");

        gridLayout_8->addWidget(labelLxqtMenu, 10, 3, 1, 1);

        spinLxqtMenu = new QSpinBox(tab);
        spinLxqtMenu->setObjectName("spinLxqtMenu");
        spinLxqtMenu->setMaximum(32);
        spinLxqtMenu->setValue(0);

        gridLayout_8->addWidget(spinLxqtMenu, 10, 4, 1, 1);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        gridLayout_9 = new QGridLayout(tab_2);
        gridLayout_9->setObjectName("gridLayout_9");
        checkBoxNoComposite = new QCheckBox(tab_2);
        checkBoxNoComposite->setObjectName("checkBoxNoComposite");

        gridLayout_9->addWidget(checkBoxNoComposite, 0, 1, 1, 3);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        blurBox = new QGroupBox(tab_2);
        blurBox->setObjectName("blurBox");
        gridLayout_14 = new QGridLayout(blurBox);
        gridLayout_14->setObjectName("gridLayout_14");
        spinMenuBlur = new QSpinBox(blurBox);
        spinMenuBlur->setObjectName("spinMenuBlur");
        spinMenuBlur->setMaximum(10);

        gridLayout_14->addWidget(spinMenuBlur, 0, 1, 1, 1);

        label_11 = new QLabel(blurBox);
        label_11->setObjectName("label_11");

        gridLayout_14->addWidget(label_11, 0, 0, 1, 1);

        label_12 = new QLabel(blurBox);
        label_12->setObjectName("label_12");

        gridLayout_14->addWidget(label_12, 1, 0, 1, 1);

        spinTooltipBlur = new QSpinBox(blurBox);
        spinTooltipBlur->setObjectName("spinTooltipBlur");
        spinTooltipBlur->setMaximum(10);

        gridLayout_14->addWidget(spinTooltipBlur, 1, 1, 1, 1);


        verticalLayout_2->addWidget(blurBox);

        contrastBox = new QGroupBox(tab_2);
        contrastBox->setObjectName("contrastBox");
        gridLayout_13 = new QGridLayout(contrastBox);
        gridLayout_13->setObjectName("gridLayout_13");
        label_9 = new QLabel(contrastBox);
        label_9->setObjectName("label_9");

        gridLayout_13->addWidget(label_9, 2, 0, 1, 1);

        label_8 = new QLabel(contrastBox);
        label_8->setObjectName("label_8");

        gridLayout_13->addWidget(label_8, 1, 0, 1, 1);

        label_4 = new QLabel(contrastBox);
        label_4->setObjectName("label_4");

        gridLayout_13->addWidget(label_4, 0, 0, 1, 1);

        spinContrast = new QDoubleSpinBox(contrastBox);
        spinContrast->setObjectName("spinContrast");
        spinContrast->setMaximum(2.000000000000000);
        spinContrast->setSingleStep(0.100000000000000);
        spinContrast->setValue(1.000000000000000);

        gridLayout_13->addWidget(spinContrast, 0, 1, 1, 1);

        spinIntensity = new QDoubleSpinBox(contrastBox);
        spinIntensity->setObjectName("spinIntensity");
        spinIntensity->setMaximum(2.000000000000000);
        spinIntensity->setSingleStep(0.100000000000000);
        spinIntensity->setValue(1.000000000000000);

        gridLayout_13->addWidget(spinIntensity, 1, 1, 1, 1);

        spinSaturation = new QDoubleSpinBox(contrastBox);
        spinSaturation->setObjectName("spinSaturation");
        spinSaturation->setMaximum(2.000000000000000);
        spinSaturation->setSingleStep(0.100000000000000);
        spinSaturation->setValue(1.000000000000000);

        gridLayout_13->addWidget(spinSaturation, 2, 1, 1, 1);


        verticalLayout_2->addWidget(contrastBox);

        verticalSpacer_14 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_14);


        gridLayout_9->addLayout(verticalLayout_2, 0, 5, 12, 1);

        horizontalSpacer_4 = new QSpacerItem(5, 5, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_9->addItem(horizontalSpacer_4, 0, 6, 1, 1);

        checkBoxBlurPopup = new QCheckBox(tab_2);
        checkBoxBlurPopup->setObjectName("checkBoxBlurPopup");

        gridLayout_9->addWidget(checkBoxBlurPopup, 1, 1, 1, 3);

        checkBoxShadowlessPopup = new QCheckBox(tab_2);
        checkBoxShadowlessPopup->setObjectName("checkBoxShadowlessPopup");

        gridLayout_9->addWidget(checkBoxShadowlessPopup, 2, 1, 1, 3);

        checkBoxTrans = new QCheckBox(tab_2);
        checkBoxTrans->setObjectName("checkBoxTrans");

        gridLayout_9->addWidget(checkBoxTrans, 3, 1, 1, 3);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        opaqueLabel = new QLabel(tab_2);
        opaqueLabel->setObjectName("opaqueLabel");

        horizontalLayout->addWidget(opaqueLabel);

        horizontalSpacerOpaque = new QSpacerItem(5, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacerOpaque);

        opaqueEdit = new QLineEdit(tab_2);
        opaqueEdit->setObjectName("opaqueEdit");

        horizontalLayout->addWidget(opaqueEdit);


        gridLayout_9->addLayout(horizontalLayout, 4, 1, 1, 3);

        horizontalSpacer = new QSpacerItem(20, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        gridLayout_9->addItem(horizontalSpacer, 4, 4, 1, 1);

        reduceOpacityLabel = new QLabel(tab_2);
        reduceOpacityLabel->setObjectName("reduceOpacityLabel");

        gridLayout_9->addWidget(reduceOpacityLabel, 5, 1, 1, 1, Qt::AlignLeft);

        horizontalSpacerWinOpacity = new QSpacerItem(5, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        gridLayout_9->addItem(horizontalSpacerWinOpacity, 5, 2, 1, 1);

        spinReduceOpacity = new QSpinBox(tab_2);
        spinReduceOpacity->setObjectName("spinReduceOpacity");
        spinReduceOpacity->setMinimum(-90);
        spinReduceOpacity->setMaximum(90);

        gridLayout_9->addWidget(spinReduceOpacity, 5, 3, 1, 1, Qt::AlignLeft);

        reduceMenuOpacityLabel = new QLabel(tab_2);
        reduceMenuOpacityLabel->setObjectName("reduceMenuOpacityLabel");

        gridLayout_9->addWidget(reduceMenuOpacityLabel, 6, 1, 1, 1, Qt::AlignLeft);

        horizontalSpacerMenuOpacity = new QSpacerItem(5, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        gridLayout_9->addItem(horizontalSpacerMenuOpacity, 6, 2, 1, 1);

        spinReduceMenuOpacity = new QSpinBox(tab_2);
        spinReduceMenuOpacity->setObjectName("spinReduceMenuOpacity");
        spinReduceMenuOpacity->setMaximum(90);

        gridLayout_9->addWidget(spinReduceMenuOpacity, 6, 3, 1, 1, Qt::AlignLeft);

        checkBoxBlurWindow = new QCheckBox(tab_2);
        checkBoxBlurWindow->setObjectName("checkBoxBlurWindow");

        gridLayout_9->addWidget(checkBoxBlurWindow, 7, 1, 1, 3);

        horizontalSpacer_5 = new QSpacerItem(10, 5, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_9->addItem(horizontalSpacer_5, 7, 0, 1, 1);

        checkBoxAnimation = new QCheckBox(tab_2);
        checkBoxAnimation->setObjectName("checkBoxAnimation");

        gridLayout_9->addWidget(checkBoxAnimation, 8, 1, 1, 3);

        checkBoxPattern = new QCheckBox(tab_2);
        checkBoxPattern->setObjectName("checkBoxPattern");

        gridLayout_9->addWidget(checkBoxPattern, 9, 1, 1, 3);

        checkBoxInactiveness = new QCheckBox(tab_2);
        checkBoxInactiveness->setObjectName("checkBoxInactiveness");

        gridLayout_9->addWidget(checkBoxInactiveness, 10, 1, 1, 3);

        checkBoxTransient = new QCheckBox(tab_2);
        checkBoxTransient->setObjectName("checkBoxTransient");

        gridLayout_9->addWidget(checkBoxTransient, 11, 1, 1, 3);

        checkBoxTransientGroove = new QCheckBox(tab_2);
        checkBoxTransientGroove->setObjectName("checkBoxTransientGroove");
        checkBoxTransientGroove->setEnabled(false);

        gridLayout_9->addWidget(checkBoxTransientGroove, 12, 1, 1, 3);

        tabWidget->addTab(tab_2, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        gridLayout_10 = new QGridLayout(tab_3);
        gridLayout_10->setObjectName("gridLayout_10");
        groupBox_2 = new QGroupBox(tab_3);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_7 = new QGridLayout(groupBox_2);
        gridLayout_7->setObjectName("gridLayout_7");
        labelSmall = new QLabel(groupBox_2);
        labelSmall->setObjectName("labelSmall");

        gridLayout_7->addWidget(labelSmall, 0, 0, 1, 1);

        spinSmall = new QSpinBox(groupBox_2);
        spinSmall->setObjectName("spinSmall");
        spinSmall->setMinimum(16);
        spinSmall->setMaximum(48);

        gridLayout_7->addWidget(spinSmall, 0, 1, 1, 1);

        labelLarge = new QLabel(groupBox_2);
        labelLarge->setObjectName("labelLarge");

        gridLayout_7->addWidget(labelLarge, 1, 0, 1, 1);

        spinLarge = new QSpinBox(groupBox_2);
        spinLarge->setObjectName("spinLarge");
        spinLarge->setMinimum(24);
        spinLarge->setMaximum(128);

        gridLayout_7->addWidget(spinLarge, 1, 1, 1, 1);

        labelButton = new QLabel(groupBox_2);
        labelButton->setObjectName("labelButton");

        gridLayout_7->addWidget(labelButton, 2, 0, 1, 1);

        spinButton = new QSpinBox(groupBox_2);
        spinButton->setObjectName("spinButton");
        spinButton->setMinimum(16);
        spinButton->setMaximum(64);

        gridLayout_7->addWidget(spinButton, 2, 1, 1, 1);

        labelToolbar = new QLabel(groupBox_2);
        labelToolbar->setObjectName("labelToolbar");

        gridLayout_7->addWidget(labelToolbar, 3, 0, 1, 1);

        spinToolbar = new QSpinBox(groupBox_2);
        spinToolbar->setObjectName("spinToolbar");
        spinToolbar->setMinimum(15);
        spinToolbar->setMaximum(64);

        gridLayout_7->addWidget(spinToolbar, 3, 1, 1, 1);

        labelLayout = new QLabel(groupBox_2);
        labelLayout->setObjectName("labelLayout");

        gridLayout_7->addWidget(labelLayout, 4, 0, 1, 1);

        spinLayout = new QSpinBox(groupBox_2);
        spinLayout->setObjectName("spinLayout");
        spinLayout->setMinimum(2);
        spinLayout->setMaximum(16);

        gridLayout_7->addWidget(spinLayout, 4, 1, 1, 1);

        labelMarging = new QLabel(groupBox_2);
        labelMarging->setObjectName("labelMarging");

        gridLayout_7->addWidget(labelMarging, 5, 0, 1, 1);

        spinLayoutMargin = new QSpinBox(groupBox_2);
        spinLayoutMargin->setObjectName("spinLayoutMargin");
        spinLayoutMargin->setMinimum(2);
        spinLayoutMargin->setMaximum(16);

        gridLayout_7->addWidget(spinLayoutMargin, 5, 1, 1, 1);

        labelOverlap = new QLabel(groupBox_2);
        labelOverlap->setObjectName("labelOverlap");

        gridLayout_7->addWidget(labelOverlap, 6, 0, 1, 1);

        spinOverlap = new QSpinBox(groupBox_2);
        spinOverlap->setObjectName("spinOverlap");
        spinOverlap->setMaximum(16);
        spinOverlap->setValue(0);

        gridLayout_7->addWidget(spinOverlap, 6, 1, 1, 1);

        labelSpinWidth = new QLabel(groupBox_2);
        labelSpinWidth->setObjectName("labelSpinWidth");

        gridLayout_7->addWidget(labelSpinWidth, 7, 0, 1, 1);

        spinSpinBtnWidth = new QSpinBox(groupBox_2);
        spinSpinBtnWidth->setObjectName("spinSpinBtnWidth");
        spinSpinBtnWidth->setMinimum(16);
        spinSpinBtnWidth->setMaximum(32);
        spinSpinBtnWidth->setValue(16);

        gridLayout_7->addWidget(spinSpinBtnWidth, 7, 1, 1, 1);

        labelMinScrollLength = new QLabel(groupBox_2);
        labelMinScrollLength->setObjectName("labelMinScrollLength");

        gridLayout_7->addWidget(labelMinScrollLength, 8, 0, 1, 1);

        spinMinScrollLength = new QSpinBox(groupBox_2);
        spinMinScrollLength->setObjectName("spinMinScrollLength");
        spinMinScrollLength->setMinimum(16);
        spinMinScrollLength->setMaximum(100);
        spinMinScrollLength->setValue(16);

        gridLayout_7->addWidget(spinMinScrollLength, 8, 1, 1, 1);


        gridLayout_10->addWidget(groupBox_2, 0, 1, 1, 1);

        horizontalSpacer_7 = new QSpacerItem(5, 5, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_10->addItem(horizontalSpacer_7, 0, 0, 1, 1);

        groupBox_3 = new QGroupBox(tab_3);
        groupBox_3->setObjectName("groupBox_3");
        gridLayout_12 = new QGridLayout(groupBox_3);
        gridLayout_12->setObjectName("gridLayout_12");
        labelTooltipDelay = new QLabel(groupBox_3);
        labelTooltipDelay->setObjectName("labelTooltipDelay");

        gridLayout_12->addWidget(labelTooltipDelay, 0, 0, 1, 1);

        label_5 = new QLabel(groupBox_3);
        label_5->setObjectName("label_5");

        gridLayout_12->addWidget(label_5, 1, 0, 1, 1);

        spinTooltipDelay = new QSpinBox(groupBox_3);
        spinTooltipDelay->setObjectName("spinTooltipDelay");
        spinTooltipDelay->setMinimum(-1);
        spinTooltipDelay->setMaximum(9999);
        spinTooltipDelay->setValue(-1);

        gridLayout_12->addWidget(spinTooltipDelay, 0, 1, 1, 1);

        spinSubmenuDelay = new QSpinBox(groupBox_3);
        spinSubmenuDelay->setObjectName("spinSubmenuDelay");
        spinSubmenuDelay->setMinimum(-1);
        spinSubmenuDelay->setMaximum(1000);
        spinSubmenuDelay->setValue(250);

        gridLayout_12->addWidget(spinSubmenuDelay, 1, 1, 1, 1);


        gridLayout_10->addWidget(groupBox_3, 0, 2, 1, 1);

        horizontalSpacer_6 = new QSpacerItem(5, 5, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_10->addItem(horizontalSpacer_6, 0, 3, 1, 1);

        tabWidget->addTab(tab_3, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName("tab_4");
        gridLayout_11 = new QGridLayout(tab_4);
        gridLayout_11->setObjectName("gridLayout_11");
        checkBoxDE = new QCheckBox(tab_4);
        checkBoxDE->setObjectName("checkBoxDE");

        gridLayout_11->addWidget(checkBoxDE, 0, 1, 1, 1);

        checkBoxGroupLabel = new QCheckBox(tab_4);
        checkBoxGroupLabel->setObjectName("checkBoxGroupLabel");

        gridLayout_11->addWidget(checkBoxGroupLabel, 0, 3, 1, 2);

        checkBoxInlineSpin = new QCheckBox(tab_4);
        checkBoxInlineSpin->setObjectName("checkBoxInlineSpin");

        gridLayout_11->addWidget(checkBoxInlineSpin, 1, 1, 1, 1);

        checkBoxRubber = new QCheckBox(tab_4);
        checkBoxRubber->setObjectName("checkBoxRubber");

        gridLayout_11->addWidget(checkBoxRubber, 1, 3, 1, 2);

        checkBoxVSpin = new QCheckBox(tab_4);
        checkBoxVSpin->setObjectName("checkBoxVSpin");

        gridLayout_11->addWidget(checkBoxVSpin, 2, 1, 1, 1);

        checkBoxMenubar = new QCheckBox(tab_4);
        checkBoxMenubar->setObjectName("checkBoxMenubar");

        gridLayout_11->addWidget(checkBoxMenubar, 2, 3, 1, 2);

        checkBoxComboEdit = new QCheckBox(tab_4);
        checkBoxComboEdit->setObjectName("checkBoxComboEdit");

        gridLayout_11->addWidget(checkBoxComboEdit, 3, 1, 1, 1);

        checkBoxMenuToolbar = new QCheckBox(tab_4);
        checkBoxMenuToolbar->setObjectName("checkBoxMenuToolbar");

        gridLayout_11->addWidget(checkBoxMenuToolbar, 3, 3, 1, 2);

        checkBoxComboMenu = new QCheckBox(tab_4);
        checkBoxComboMenu->setObjectName("checkBoxComboMenu");

        gridLayout_11->addWidget(checkBoxComboMenu, 4, 1, 1, 1);

        checkBoxGroupToolbar = new QCheckBox(tab_4);
        checkBoxGroupToolbar->setObjectName("checkBoxGroupToolbar");

        gridLayout_11->addWidget(checkBoxGroupToolbar, 4, 3, 1, 2);

        checkBoxHideComboCheckboxes = new QCheckBox(tab_4);
        checkBoxHideComboCheckboxes->setObjectName("checkBoxHideComboCheckboxes");

        gridLayout_11->addWidget(checkBoxHideComboCheckboxes, 5, 1, 1, 1);

        checkBoxAlt = new QCheckBox(tab_4);
        checkBoxAlt->setObjectName("checkBoxAlt");

        gridLayout_11->addWidget(checkBoxAlt, 5, 3, 1, 2);

        checkBoxleftTab = new QCheckBox(tab_4);
        checkBoxleftTab->setObjectName("checkBoxleftTab");

        gridLayout_11->addWidget(checkBoxleftTab, 6, 1, 1, 1);

        checkBoxJoinTab = new QCheckBox(tab_4);
        checkBoxJoinTab->setObjectName("checkBoxJoinTab");

        gridLayout_11->addWidget(checkBoxJoinTab, 7, 1, 1, 1);

        checkBoxNoScrollArrow = new QCheckBox(tab_4);
        checkBoxNoScrollArrow->setObjectName("checkBoxNoScrollArrow");

        gridLayout_11->addWidget(checkBoxNoScrollArrow, 8, 1, 1, 1);

        label_10 = new QLabel(tab_4);
        label_10->setObjectName("label_10");

        gridLayout_11->addWidget(label_10, 7, 3, 1, 1);

        comboClick = new QComboBox(tab_4);
        comboClick->setObjectName("comboClick");

        gridLayout_11->addWidget(comboClick, 7, 4, 1, 1);

        horizontalSpacer_8 = new QSpacerItem(10, 5, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_11->addItem(horizontalSpacer_8, 9, 0, 1, 1);

        horizontalSpacer_9 = new QSpacerItem(20, 5, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_11->addItem(horizontalSpacer_9, 9, 2, 1, 1);

        label_2 = new QLabel(tab_4);
        label_2->setObjectName("label_2");

        gridLayout_11->addWidget(label_2, 8, 3, 1, 1);

        comboToolButton = new QComboBox(tab_4);
        comboToolButton->setObjectName("comboToolButton");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(comboToolButton->sizePolicy().hasHeightForWidth());
        comboToolButton->setSizePolicy(sizePolicy2);

        gridLayout_11->addWidget(comboToolButton, 8, 4, 1, 1);

        horizontalSpacer_10 = new QSpacerItem(5, 5, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_11->addItem(horizontalSpacer_10, 9, 5, 1, 1);

        checkBoxScrollIn = new QCheckBox(tab_4);
        checkBoxScrollIn->setObjectName("checkBoxScrollIn");

        gridLayout_11->addWidget(checkBoxScrollIn, 9, 1, 1, 1);

        label_3 = new QLabel(tab_4);
        label_3->setObjectName("label_3");

        gridLayout_11->addWidget(label_3, 9, 3, 1, 1);

        comboDialogButton = new QComboBox(tab_4);
        comboDialogButton->setObjectName("comboDialogButton");

        gridLayout_11->addWidget(comboDialogButton, 9, 4, 1, 1);

        checkBoxFocusRect = new QCheckBox(tab_4);
        checkBoxFocusRect->setObjectName("checkBoxFocusRect");

        gridLayout_11->addWidget(checkBoxFocusRect, 10, 1, 1, 1);

        checkBoxTree = new QCheckBox(tab_4);
        checkBoxTree->setObjectName("checkBoxTree");

        gridLayout_11->addWidget(checkBoxTree, 11, 1, 1, 1);

        labelX11Drag = new QLabel(tab_4);
        labelX11Drag->setObjectName("labelX11Drag");

        gridLayout_11->addWidget(labelX11Drag, 11, 3, 1, 1);

        comboX11Drag = new QComboBox(tab_4);
        comboX11Drag->setObjectName("comboX11Drag");

        gridLayout_11->addWidget(comboX11Drag, 11, 4, 1, 1);

        checkBoxScrollableMenu = new QCheckBox(tab_4);
        checkBoxScrollableMenu->setObjectName("checkBoxScrollableMenu");

        gridLayout_11->addWidget(checkBoxScrollableMenu, 12, 1, 1, 1);

        checkBoxBtnDrag = new QCheckBox(tab_4);
        checkBoxBtnDrag->setObjectName("checkBoxBtnDrag");

        gridLayout_11->addWidget(checkBoxBtnDrag, 12, 3, 1, 2);

        tabWidget->addTab(tab_4, QString());

        gridLayout_5->addWidget(tabWidget, 0, 0, 1, 1);


        gridLayout_4->addWidget(groupBox, 3, 0, 1, 2);

        toolBox->addItem(page_3, QString::fromUtf8("Configure Active Theme"));
        page_4 = new QWidget();
        page_4->setObjectName("page_4");
        page_4->setGeometry(QRect(0, 0, 554, 303));
        gridLayout_6 = new QGridLayout(page_4);
        gridLayout_6->setObjectName("gridLayout_6");
        appLabel = new QLabel(page_4);
        appLabel->setObjectName("appLabel");
        appLabel->setWordWrap(true);
        appLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse);

        gridLayout_6->addWidget(appLabel, 0, 0, 1, 2);

        verticalSpacer_10 = new QSpacerItem(5, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_6->addItem(verticalSpacer_10, 1, 0, 1, 1);

        label_6 = new QLabel(page_4);
        label_6->setObjectName("label_6");
        QFont font;
        font.setBold(true);
        label_6->setFont(font);
        label_6->setAlignment(Qt::AlignCenter);

        gridLayout_6->addWidget(label_6, 2, 0, 1, 1);

        label_7 = new QLabel(page_4);
        label_7->setObjectName("label_7");
        label_7->setFont(font);
        label_7->setAlignment(Qt::AlignCenter);

        gridLayout_6->addWidget(label_7, 2, 1, 1, 1);

        verticalSpacer_11 = new QSpacerItem(5, 15, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_6->addItem(verticalSpacer_11, 3, 0, 1, 1);

        appCombo = new KvManager::ComboBox(page_4);
        appCombo->setObjectName("appCombo");

        gridLayout_6->addWidget(appCombo, 4, 0, 1, 1);

        appsEdit = new QLineEdit(page_4);
        appsEdit->setObjectName("appsEdit");

        gridLayout_6->addWidget(appsEdit, 4, 1, 1, 1);

        verticalSpacer_13 = new QSpacerItem(5, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_6->addItem(verticalSpacer_13, 5, 0, 1, 1);

        removeAppButton = new QPushButton(page_4);
        removeAppButton->setObjectName("removeAppButton");

        gridLayout_6->addWidget(removeAppButton, 6, 0, 1, 1, Qt::AlignLeft);

        saveAppButton = new QPushButton(page_4);
        saveAppButton->setObjectName("saveAppButton");

        gridLayout_6->addWidget(saveAppButton, 6, 1, 1, 1, Qt::AlignRight);

        verticalSpacer = new QSpacerItem(5, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_6->addItem(verticalSpacer, 7, 0, 1, 1);

        toolBox->addItem(page_4, QString::fromUtf8("Application Themes"));

        gridLayout_3->addWidget(toolBox, 0, 0, 1, 4);

        quit = new QPushButton(widget);
        quit->setObjectName("quit");
        quit->setAutoDefault(false);

        gridLayout_3->addWidget(quit, 2, 3, 1, 1, Qt::AlignRight);

        preview = new QPushButton(widget);
        preview->setObjectName("preview");

        gridLayout_3->addWidget(preview, 2, 0, 1, 1, Qt::AlignLeft);

        aboutButton = new QPushButton(widget);
        aboutButton->setObjectName("aboutButton");

        gridLayout_3->addWidget(aboutButton, 2, 2, 1, 1, Qt::AlignHCenter);

        verticalSpacer_12 = new QSpacerItem(5, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_3->addItem(verticalSpacer_12, 1, 0, 1, 4);

        whatsthisButton = new QPushButton(widget);
        whatsthisButton->setObjectName("whatsthisButton");

        gridLayout_3->addWidget(whatsthisButton, 2, 1, 1, 1, Qt::AlignHCenter);

        MainWindow->setCentralWidget(widget);
        statusBar = new QStatusBar(MainWindow);
        statusBar->setObjectName("statusBar");
        MainWindow->setStatusBar(statusBar);

        retranslateUi(MainWindow);

        toolBox->setCurrentIndex(0);
        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(MainWindow);
    } // setupUi

    void retranslateUi(QMainWindow *MainWindow)
    {
        MainWindow->setWindowTitle(QCoreApplication::translate("KvManager::KvantumManager", "Kvantum Manager", nullptr));
        installLabel->setText(QCoreApplication::translate("KvManager::KvantumManager", "<center><b><i>Kvantum</i></b> comes with many themes but external themes can also be installed for being used by it. Here you could choose a theme folder and then press the button below to install it in your Home.</center>", nullptr));
        openTheme->setText(QCoreApplication::translate("KvManager::KvantumManager", "Select a Kvantum\n"
"theme folder", nullptr));
#if QT_CONFIG(tooltip)
        installTheme->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Add this theme to the list of themes that\n"
"Kvantum can use in addition to its own themes.", nullptr));
#endif // QT_CONFIG(tooltip)
        installTheme->setText(QCoreApplication::translate("KvManager::KvantumManager", "Install this theme", nullptr));
        toolBox->setItemText(toolBox->indexOf(page), QCoreApplication::translate("KvManager::KvantumManager", "Install/Update Theme", nullptr));
        label->setText(QCoreApplication::translate("KvManager::KvantumManager", "Select a theme:", nullptr));
#if QT_CONFIG(tooltip)
        deleteTheme->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Remove the selected theme\n"
"from all user installation paths.\n"
"\n"
"The root installation will still be\n"
"available if present; this button\n"
"only removes user themes.", nullptr));
#endif // QT_CONFIG(tooltip)
        deleteTheme->setText(QCoreApplication::translate("KvManager::KvantumManager", "Delete this theme", nullptr));
#if QT_CONFIG(tooltip)
        useTheme->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Make Kvantum use this theme!\n"
"\n"
"A disabled button means that\n"
"the theme is already used.", nullptr));
#endif // QT_CONFIG(tooltip)
        useTheme->setText(QCoreApplication::translate("KvManager::KvantumManager", "Use this theme", nullptr));
        usageLabel->setText(QCoreApplication::translate("KvManager::KvantumManager", "<br><br>Since <b><i>Kvantum</i></b> is independent of all desktop environments, you first need to <i>activate</i> it with a Qt platform integration program. KDE and LXQt provide simple tools for changing the active Qt style plugin. With other platforms, you need a Qt configuration tool.<br/><br/>Under KDE, also select and apply the color scheme of this theme because some KDE applications may get their colors directly from the KDE color scheme.<br/><br/>Running applications will get the new theme after being closed and reopened. Logging out and in would be good for all KDE/LXQt parts to see it completely.", nullptr));
        toolBox->setItemText(toolBox->indexOf(page_2), QCoreApplication::translate("KvManager::KvantumManager", "Change/Delete Theme", nullptr));
#if QT_CONFIG(tooltip)
        restoreButton->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Revert to the default (root)\n"
"settings of this theme.\n"
"(Ctrl+Z)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        restoreButton->setWhatsThis(QCoreApplication::translate("KvManager::KvantumManager", "<html><head/><body><p>Revert to the default (root) settings of this theme!</p><p>When clicked and confirmed, all changes to the configuration will be lost but the probable customized SVG file will remain intact.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        restoreButton->setText(QCoreApplication::translate("KvManager::KvantumManager", "Restore", nullptr));
#if QT_CONFIG(shortcut)
        restoreButton->setShortcut(QCoreApplication::translate("KvManager::KvantumManager", "Ctrl+Z", nullptr));
#endif // QT_CONFIG(shortcut)
#if QT_CONFIG(tooltip)
        saveButton->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Save this configuration\n"
"(Ctrl+S)", nullptr));
#endif // QT_CONFIG(tooltip)
        saveButton->setText(QCoreApplication::translate("KvManager::KvantumManager", "Save", nullptr));
#if QT_CONFIG(shortcut)
        saveButton->setShortcut(QCoreApplication::translate("KvManager::KvantumManager", "Ctrl+S", nullptr));
#endif // QT_CONFIG(shortcut)
        groupBox->setTitle(QCoreApplication::translate("KvManager::KvantumManager", "Safe Settings", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxDolphin->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Merge Dolphin's view with its surroundings?\n"
"\n"
"By default, it has the base background.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxDolphin->setText(QCoreApplication::translate("KvManager::KvantumManager", "Transparent Dolphin view", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxNormalBtn->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "No bold font for default push buttons?\n"
"\n"
"Such push buttons have bold text by default.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxNormalBtn->setText(QCoreApplication::translate("KvManager::KvantumManager", "Normal font for default push buttons", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxPcmanfmSide->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Merge PCManFM-qt's sidepane with its surroundings.\n"
"\n"
"Under LXQt, it needs logging out and in or closing\n"
"PCManFM-qt and then, stopping and starting Desktop\n"
"with LXQt Session Settings.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxPcmanfmSide->setText(QCoreApplication::translate("KvManager::KvantumManager", "Transparent sidepane for PCManFM-qt", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxIconlessBtn->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "No icon for push buttons that have text?\n"
"\n"
"By default, most push buttons have icon.\n"
"\n"
"If this is disabled, see:\n"
"Miscellaneous \342\206\222 Respect current DE if possible", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxIconlessBtn->setText(QCoreApplication::translate("KvManager::KvantumManager", "Iconless push buttons", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxPcmanfmView->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Merge PCManFM-qt's view with its surroundings.\n"
"\n"
"Under LXQt, it needs logging out and in or closing\n"
"PCManFM-qt and then, stopping and starting Desktop\n"
"with LXQt Session Settings.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxPcmanfmView->setText(QCoreApplication::translate("KvManager::KvantumManager", "Transparent view for PCManFM-qt", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxIconlessMenu->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "No icon for menu-items?\n"
"\n"
"By default, some of them may have icon.\n"
"\n"
"If this is disabled, see:\n"
"Miscellaneous \342\206\222 Respect current DE if possible", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxIconlessMenu->setText(QCoreApplication::translate("KvManager::KvantumManager", "Iconless menus", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxBlurTranslucent->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Blur the regions behind windows that are made\n"
"translucent by their apps explicitly if possible.\n"
"\n"
"This needs the KDE blur effect.\n"
"\n"
"Konsole, QTerminal and LXQt panel are some examples.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxBlurTranslucent->setText(QCoreApplication::translate("KvManager::KvantumManager", "Blur explicitly translucent windows", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxToolbar->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Only the top toolbar should be styled?\n"
"\n"
"By default, all toolbars are styled,\n"
"whether they are on the top or at any\n"
"other position.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxToolbar->setText(QCoreApplication::translate("KvManager::KvantumManager", "Single top toolbar", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxBlurActive->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "By default, both active and inactive translucent windows\n"
"will be blurred if blurring is enabled.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxBlurActive->setText(QCoreApplication::translate("KvManager::KvantumManager", "No blurring for inactive windows", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxVToolbar->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "By default, vertical toolbars are not styled.\n"
"\n"
"If this is disabled, see the above option.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxVToolbar->setText(QCoreApplication::translate("KvManager::KvantumManager", "Style vertical toolbars", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxKtitle->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Do not draw any background for KTitles.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        checkBoxKtitle->setWhatsThis(QCoreApplication::translate("KvManager::KvantumManager", "<html><head/><body><p>Do not draw any background for KTitles?</p><p>Ktitles are used by some KDE applications to show different sections in configuration dialogs.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        checkBoxKtitle->setText(QCoreApplication::translate("KvManager::KvantumManager", "Transparent KTitle label", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxTint->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Do not tint selected label icons with\n"
"the highlight color!", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        checkBoxTint->setWhatsThis(QCoreApplication::translate("KvManager::KvantumManager", "<html><head/><body><p>By default, selected label icons are tinted by the highlight color.</p><p>Checking this box removes the tint.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        checkBoxTint->setText(QCoreApplication::translate("KvManager::KvantumManager", "No selection tint", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxMenuTitle->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Do not draw any background for (KDE) menu titles.\n"
"(Needs Logging out and in for Plasma menus.)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        checkBoxMenuTitle->setWhatsThis(QCoreApplication::translate("KvManager::KvantumManager", "<html><head/><body><p>Do not draw any background for (KDE) menu titles?</p><p>Menu titles are like menu separators but with icon and text.</p><p>This needs Logging out and in for KDE Plasma menus. For LXQt panel, a panel restart with <span style=\" font-style:italic;\">Session Settings </span>is enough.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        checkBoxMenuTitle->setText(QCoreApplication::translate("KvManager::KvantumManager", "Transparent menu title", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxCenteredForms->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "If checked, the contents of a form will be\n"
"horizontally centered as far as possible.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxCenteredForms->setText(QCoreApplication::translate("KvManager::KvantumManager", "Centered form layouts", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxDark->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Some apps may not respect dark themes.\n"
"Kvantum can try to correct their behavior\n"
"as far as possible.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxDark->setText(QCoreApplication::translate("KvManager::KvantumManager", "Respect dark themes", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxNoninteger->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "You might see annoying artifacts that are caused\n"
"by bugs in Qt's handling of non-integer scaling\n"
"with window translucency or gradient.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxNoninteger->setText(QCoreApplication::translate("KvManager::KvantumManager", "Disable translucency with non-integer scaling", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxGrip->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Show size grips of dialogs and statusbars\n"
"as far as possible.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        checkBoxGrip->setWhatsThis(QCoreApplication::translate("KvManager::KvantumManager", "<html><head/><body><p>Show size grips of dialogs and statusbars as far as possible?</p><p>By default, the application decides whether they should be shown, but this hack could be useful for resizing windows easily when there is no window border.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        checkBoxGrip->setText(QCoreApplication::translate("KvManager::KvantumManager", "Force size grips", nullptr));
#if QT_CONFIG(tooltip)
        labelTint->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "The highlight color is used for tinting.\n"
"\n"
"This is mostly relevant with monochrome icons.\n"
"\n"
"Hard-coded icons/styles may not respect this key.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelTint->setText(QCoreApplication::translate("KvManager::KvantumManager", "Tint label icons on mouseover by ", nullptr));
#if QT_CONFIG(tooltip)
        spinTint->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "The highlight color is used for tinting.\n"
"\n"
"This is mostly relevant with monochrome icons.\n"
"\n"
"Hard-coded icons/styles may not respect this key.", nullptr));
#endif // QT_CONFIG(tooltip)
        spinTint->setSuffix(QCoreApplication::translate("KvManager::KvantumManager", " %", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxScrollJump->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "By default, the scroll slider jumps to a position\n"
"when the scrollbar is left clicked.\n"
"\n"
"If this is disabled, see:\n"
"Miscellaneous \342\206\222 Respect current DE if possible", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxScrollJump->setText(QCoreApplication::translate("KvManager::KvantumManager", "Scroll jump with middle click", nullptr));
#if QT_CONFIG(tooltip)
        labelOpacity->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Useful with monochrome icon sets and\n"
"when the opacity of disabled icons is not\n"
"reduced by other means.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        labelOpacity->setWhatsThis(QCoreApplication::translate("KvManager::KvantumManager", "<html><head/><body><p>Useful with monochrome icon sets and when the opacity of disabled icons is not reduced by other means.</p><p>KDE automatically reduces the opacity of disabled icons. Therefore, this option might be useful rather under other desktop environments.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        labelOpacity->setText(QCoreApplication::translate("KvManager::KvantumManager", "Opacity of disabled icons:", nullptr));
#if QT_CONFIG(tooltip)
        spinOpacity->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Useful with monochrome icon sets and\n"
"when the opacity of disabled icons is not\n"
"reduced by other means.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        spinOpacity->setWhatsThis(QCoreApplication::translate("KvManager::KvantumManager", "<html><head/><body><p>Useful with monochrome icon sets and when the opacity of disabled icons is not reduced by other means.</p><p>KDE automatically reduces the opacity of disabled icons. Therefore, this option might be useful rather under other desktop environments.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        spinOpacity->setSuffix(QCoreApplication::translate("KvManager::KvantumManager", " %", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxKineticScrolling->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Scroll some scrollable widgets by flicking them\n"
"with the left mouse button.\n"
"\n"
"Warning: Qt's kinetic scrolling has bugs and may\n"
"seriously interfere with other jobs.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxKineticScrolling->setText(QCoreApplication::translate("KvManager::KvantumManager", "Kinetic scrolling", nullptr));
#if QT_CONFIG(tooltip)
        labelLxqtMenu->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Has effect only when the main menu is NOT styled by LXQt.\n"
"\n"
"Values less than 16 mean the default menu icon size.\n"
"\n"
"Needs LXQt panel to be restarted either by \"Session Settings\"\n"
"or through logging out and in again.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelLxqtMenu->setText(QCoreApplication::translate("KvManager::KvantumManager", "LXQt main menu icon size:", nullptr));
#if QT_CONFIG(tooltip)
        spinLxqtMenu->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Has effect only when the main menu is NOT styled by LXQt.\n"
"\n"
"Values less than 16 mean the default menu icon size.\n"
"\n"
"Needs LXQt panel to be restarted either by \"Session Settings\"\n"
"or through logging out and in again.", nullptr));
#endif // QT_CONFIG(tooltip)
        spinLxqtMenu->setSuffix(QCoreApplication::translate("KvManager::KvantumManager", " px", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), QCoreApplication::translate("KvManager::KvantumManager", "Hacks", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxNoComposite->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "If checked, menus, tooltips and windows\n"
"will not have translucency or shadow.\n"
"\n"
"If this is disabled, see:\n"
"Miscellaneous \342\206\222 Respect current DE if possible", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        checkBoxNoComposite->setWhatsThis(QCoreApplication::translate("KvManager::KvantumManager", "<html><head/><body><p>If checked, menus, tooltips and windows will not have translucency or shadow.</p><p>When unchecked, translucency and shadow will be available if there are appropriate elements in the theme's SVG file.</p><p>If this is disabled, see Miscellaneous \342\206\222 Respect current DE if possible.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        checkBoxNoComposite->setText(QCoreApplication::translate("KvManager::KvantumManager", "Disable composite effects", nullptr));
#if QT_CONFIG(tooltip)
        blurBox->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "If blurring is enabled, these values set the corner\n"
"radii for blurring translucent menus and tooltips\n"
"that have rounded corners.\n"
"\n"
"Usually, a value of 2 is enough.", nullptr));
#endif // QT_CONFIG(tooltip)
        blurBox->setTitle(QCoreApplication::translate("KvManager::KvantumManager", "Blur Corner Radius", nullptr));
        label_11->setText(QCoreApplication::translate("KvManager::KvantumManager", "Menu:", nullptr));
        label_12->setText(QCoreApplication::translate("KvManager::KvantumManager", "Tooltip:", nullptr));
#if QT_CONFIG(tooltip)
        contrastBox->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "This needs the KDE contrast effect and is applied\n"
"only to translucent windows that support the blur\n"
"effect (but the KDE blur effect can be disabled).\n"
"\n"
"A value of 1.00 means no change.", nullptr));
#endif // QT_CONFIG(tooltip)
        contrastBox->setTitle(QCoreApplication::translate("KvManager::KvantumManager", "Contrast Effect", nullptr));
        label_9->setText(QCoreApplication::translate("KvManager::KvantumManager", "Saturation:", nullptr));
        label_8->setText(QCoreApplication::translate("KvManager::KvantumManager", "Intensity:", nullptr));
        label_4->setText(QCoreApplication::translate("KvManager::KvantumManager", "Contrast:", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxBlurPopup->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Needs KDE blur effect, a graphic card that supports it,\n"
"and translucent menu/tooltip SVG elements.\n"
"\n"
"Automatically checked if window blurring is enabled.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxBlurPopup->setText(QCoreApplication::translate("KvManager::KvantumManager", "Blurring for menus and tooltips", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxShadowlessPopup->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Do not draw shadows for menus and tooltips.\n"
"\n"
"This may be useful under DEs that give\n"
"shadow to menus and tooltips.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxShadowlessPopup->setText(QCoreApplication::translate("KvManager::KvantumManager", "Shadowless menus and tooltips", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxTrans->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Has effect only when there is a translucent SVG background\n"
"for windows or the window opacity is reduced (see below).", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxTrans->setText(QCoreApplication::translate("KvManager::KvantumManager", "Translucent windows", nullptr));
#if QT_CONFIG(tooltip)
        opaqueLabel->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "A comma-separated list of executables,\n"
"whose windows should not be translucent.\n"
"\n"
"(Some apps, like video players, may have\n"
"problems with translucency!)", nullptr));
#endif // QT_CONFIG(tooltip)
        opaqueLabel->setText(QCoreApplication::translate("KvManager::KvantumManager", "Opaque apps:", nullptr));
#if QT_CONFIG(tooltip)
        opaqueEdit->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "A comma-separated list of executables,\n"
"whose windows should not be translucent.\n"
"\n"
"(Some apps, like video players, may have\n"
"problems with translucency!)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        reduceOpacityLabel->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "This will reduce the window opacity\n"
"if window translucency is enabled.\n"
"\n"
"A translucent SVG background is NOT\n"
"needed for this key to work.\n"
"\n"
"A negative value means that only the\n"
"opacity of inactive windows is reduced.", nullptr));
#endif // QT_CONFIG(tooltip)
        reduceOpacityLabel->setText(QCoreApplication::translate("KvManager::KvantumManager", "Reduce window opacity by", nullptr));
#if QT_CONFIG(tooltip)
        spinReduceOpacity->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "This will reduce the window opacity\n"
"if window translucency is enabled.\n"
"\n"
"A translucent SVG background is NOT\n"
"needed for this key to work.\n"
"\n"
"A negative value means that only the\n"
"opacity of inactive windows is reduced.", nullptr));
#endif // QT_CONFIG(tooltip)
        spinReduceOpacity->setSuffix(QCoreApplication::translate("KvManager::KvantumManager", " %", nullptr));
        reduceMenuOpacityLabel->setText(QCoreApplication::translate("KvManager::KvantumManager", "Reduce menu opacity by", nullptr));
        spinReduceMenuOpacity->setSuffix(QCoreApplication::translate("KvManager::KvantumManager", " %", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxBlurWindow->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Needs KDE blur effect, a graphic card\n"
"that supports it, and a translucent\n"
"window SVG background in the theme.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxBlurWindow->setText(QCoreApplication::translate("KvManager::KvantumManager", "Blurring for translucent windows", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxAnimation->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "A 200ms fading animation when the state of\n"
"some widgets is changed, mostly by the mouse.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        checkBoxAnimation->setWhatsThis(QCoreApplication::translate("KvManager::KvantumManager", "<html><head/><body><p>A 200ms fading animation when the state of some widgets is changed, mostly by the mouse.</p><p>The CPU usage is negligible because often only one widget is animated. The resulting visual effect depends on the active theme.</p><p>These widgets are supported: buttons (including radio buttons and check boxes), combo boxes, spin boxes, slider handles, line-edits and scroll views.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        checkBoxAnimation->setText(QCoreApplication::translate("KvManager::KvantumManager", "Animation for state change under mouse", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxPattern->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Check this to remove all window/dialog tiling patterns!\n"
"Uncheck it if you want those patterns back!", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxPattern->setText(QCoreApplication::translate("KvManager::KvantumManager", "Remove window/dialog tiling patterns", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxInactiveness->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Use the same colors and shapes with active and inactive\n"
"windows if this theme distinguishes between them?", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxInactiveness->setText(QCoreApplication::translate("KvManager::KvantumManager", "Ignore inactive state", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxTransient->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Make scrollbars transient!\n"
"\n"
"Transient scrollbars appear on top of\n"
"their scroll views only when needed.\n"
"They usually take no extra space.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxTransient->setText(QCoreApplication::translate("KvManager::KvantumManager", "Transient scrollbars", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxTransientGroove->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Should transient scrollbars have\n"
"semi-transparent grooves when needed?", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxTransientGroove->setText(QCoreApplication::translate("KvManager::KvantumManager", "Transient scrollbar grooves when needed", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), QCoreApplication::translate("KvManager::KvantumManager", "Compositing && General Look", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("KvManager::KvantumManager", "Sizes", nullptr));
#if QT_CONFIG(tooltip)
        labelSmall->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Affects menu-items and headers.\n"
"\n"
"The default value is 16 px but\n"
"some apps may set it themselves.\n"
"\n"
"If this is disabled, see:\n"
"Miscellaneous \342\206\222 Respect current DE if possible", nullptr));
#endif // QT_CONFIG(tooltip)
        labelSmall->setText(QCoreApplication::translate("KvManager::KvantumManager", "Small icon:", nullptr));
#if QT_CONFIG(tooltip)
        spinSmall->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Affects menu-items and headers.\n"
"\n"
"The default value is 16 px but\n"
"some apps may set it themselves.\n"
"\n"
"If this is disabled, see:\n"
"Miscellaneous \342\206\222 Respect current DE if possible", nullptr));
#endif // QT_CONFIG(tooltip)
        spinSmall->setSuffix(QCoreApplication::translate("KvManager::KvantumManager", " px", nullptr));
#if QT_CONFIG(tooltip)
        labelLarge->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Affects icon views.\n"
"\n"
"The default value is 32 px but\n"
"some apps set it themselves.\n"
"\n"
"If this is disabled, see:\n"
"Miscellaneous \342\206\222 Respect current DE if possible", nullptr));
#endif // QT_CONFIG(tooltip)
        labelLarge->setText(QCoreApplication::translate("KvManager::KvantumManager", "Large icon:", nullptr));
#if QT_CONFIG(tooltip)
        spinLarge->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Affects icon views.\n"
"\n"
"The default value is 32 px but\n"
"some apps set it themselves.\n"
"\n"
"If this is disabled, see:\n"
"Miscellaneous \342\206\222 Respect current DE if possible", nullptr));
#endif // QT_CONFIG(tooltip)
        spinLarge->setSuffix(QCoreApplication::translate("KvManager::KvantumManager", " px", nullptr));
#if QT_CONFIG(tooltip)
        labelButton->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Affects buttons, tab-bars and list-views.\n"
"\n"
"The default value is 16 px.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelButton->setText(QCoreApplication::translate("KvManager::KvantumManager", "Button icon:", nullptr));
#if QT_CONFIG(tooltip)
        spinButton->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Affects buttons, tab-bars and list-views.\n"
"\n"
"The default value is 16 px.", nullptr));
#endif // QT_CONFIG(tooltip)
        spinButton->setSuffix(QCoreApplication::translate("KvManager::KvantumManager", " px", nullptr));
#if QT_CONFIG(tooltip)
        labelToolbar->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Affects toolbars.\n"
"\n"
"The default value is 22 px but\n"
"some apps set it themselves.\n"
"KDE apps get it from KDE setting.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelToolbar->setText(QCoreApplication::translate("KvManager::KvantumManager", "Toolbar icon:", nullptr));
#if QT_CONFIG(tooltip)
        spinToolbar->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Affects toolbars.\n"
"\n"
"The default value is 22 px but\n"
"some apps set it themselves.\n"
"KDE apps get it from KDE setting.", nullptr));
#endif // QT_CONFIG(tooltip)
        spinToolbar->setSpecialValueText(QCoreApplication::translate("KvManager::KvantumManager", "Font size", nullptr));
        spinToolbar->setSuffix(QCoreApplication::translate("KvManager::KvantumManager", " px", nullptr));
#if QT_CONFIG(tooltip)
        labelLayout->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "The default value is 3 px but\n"
"some apps set it themeselves.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelLayout->setText(QCoreApplication::translate("KvManager::KvantumManager", "Layout spacing:", nullptr));
#if QT_CONFIG(tooltip)
        spinLayout->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "The default value is 3 px but\n"
"some apps set it themeselves.", nullptr));
#endif // QT_CONFIG(tooltip)
        spinLayout->setSuffix(QCoreApplication::translate("KvManager::KvantumManager", " px", nullptr));
#if QT_CONFIG(tooltip)
        labelMarging->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "The default value is 6 px but some apps set it themeselves.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelMarging->setText(QCoreApplication::translate("KvManager::KvantumManager", "Layout margin:", nullptr));
#if QT_CONFIG(tooltip)
        spinLayoutMargin->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "The default value is 6 px but some apps set it themeselves.", nullptr));
#endif // QT_CONFIG(tooltip)
        spinLayoutMargin->setSuffix(QCoreApplication::translate("KvManager::KvantumManager", " px", nullptr));
#if QT_CONFIG(tooltip)
        labelOverlap->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "The horizontal overlap between a submenu and its parent.\n"
"\n"
"0 by default.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelOverlap->setText(QCoreApplication::translate("KvManager::KvantumManager", "Submenu overlap: ", nullptr));
#if QT_CONFIG(tooltip)
        spinOverlap->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "The horizontal overlap between a submenu and its parent.\n"
"\n"
"0 by default.", nullptr));
#endif // QT_CONFIG(tooltip)
        spinOverlap->setSuffix(QCoreApplication::translate("KvManager::KvantumManager", " px", nullptr));
#if QT_CONFIG(tooltip)
        labelSpinWidth->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "The width of horizontal spin buttons.\n"
"(Has no effect when spin indicators are vertical.)", nullptr));
#endif // QT_CONFIG(tooltip)
        labelSpinWidth->setText(QCoreApplication::translate("KvManager::KvantumManager", "Spin button width: ", nullptr));
#if QT_CONFIG(tooltip)
        spinSpinBtnWidth->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "The width of horizontal spin buttons.\n"
"(Has no effect when spin indicators are vertical.)", nullptr));
#endif // QT_CONFIG(tooltip)
        spinSpinBtnWidth->setSuffix(QCoreApplication::translate("KvManager::KvantumManager", " px", nullptr));
#if QT_CONFIG(tooltip)
        labelMinScrollLength->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "The minimum length of scrollbars.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        labelMinScrollLength->setWhatsThis(QCoreApplication::translate("KvManager::KvantumManager", "<html><head/><body><p>The minimum height of vertical scrollbars and the minimum width of horizontal scrollbars.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        labelMinScrollLength->setText(QCoreApplication::translate("KvManager::KvantumManager", "Minimum scrollbar length: ", nullptr));
#if QT_CONFIG(tooltip)
        spinMinScrollLength->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "The minimum length of scrollbars.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        spinMinScrollLength->setWhatsThis(QCoreApplication::translate("KvManager::KvantumManager", "<html><head/><body><p>The minimum height of vertical scrollbars and the minimum width of horizontal scrollbars.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        spinMinScrollLength->setSuffix(QCoreApplication::translate("KvManager::KvantumManager", " px", nullptr));
        groupBox_3->setTitle(QCoreApplication::translate("KvManager::KvantumManager", "Delays", nullptr));
#if QT_CONFIG(tooltip)
        labelTooltipDelay->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "The delay, in milliseconds, before a tooltip is shown.\n"
"\n"
"Zero means tooltips are shown instantly.\n"
"\n"
"-1 means the default Qt behavior.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelTooltipDelay->setText(QCoreApplication::translate("KvManager::KvantumManager", "Tooltip delay:", nullptr));
#if QT_CONFIG(tooltip)
        label_5->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "The delay, in milliseconds, to wait before opening a submenu.\n"
"250 by default.\n"
"\n"
"-1 means no popup (opening by clicking),\n"
"while 0 means no delay.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_5->setText(QCoreApplication::translate("KvManager::KvantumManager", "Submenu delay: ", nullptr));
#if QT_CONFIG(tooltip)
        spinTooltipDelay->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "The delay, in milliseconds, before a tooltip is shown.\n"
"\n"
"Zero means tooltips are shown instantly.\n"
"\n"
"-1 means the default Qt behavior.", nullptr));
#endif // QT_CONFIG(tooltip)
        spinTooltipDelay->setSuffix(QCoreApplication::translate("KvManager::KvantumManager", " ms", nullptr));
#if QT_CONFIG(tooltip)
        spinSubmenuDelay->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "The delay, in milliseconds, to wait before opening a submenu.\n"
"250 by default.\n"
"\n"
"-1 means no popup (opening by clicking),\n"
"while 0 means no delay.", nullptr));
#endif // QT_CONFIG(tooltip)
        spinSubmenuDelay->setSuffix(QCoreApplication::translate("KvManager::KvantumManager", " ms", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), QCoreApplication::translate("KvManager::KvantumManager", "Sizes && Delays", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxDE->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "When this is enabled and checked, Kvantum will try to\n"
"respect some settings of the current desktop environment.\n"
"\n"
"This checkbox may disable some options.\n"
"Uncheck it if you want to use those options!", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        checkBoxDE->setWhatsThis(QCoreApplication::translate("KvManager::KvantumManager", "<html><head/><body><p>When this is enabled and checked, Kvantum will try to respect some settings of the current desktop environment if it is KDE, Unity, Gnome or Pantheon.</p><p>Under KDE, it makes Kvantum read KDE settings for small and large icon sizes and also single or double clicking.</p><p>Under Unity, Gnome and Pantheon, it removes icons from menus and push-buttons (even if the corresponding dconf keys are changed) and disables window translucency.</p><p>This checkbox may disable some options. Uncheck it if you want to use those options!</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        checkBoxDE->setText(QCoreApplication::translate("KvManager::KvantumManager", "Respect current DE if possible", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxGroupLabel->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "By default, the label is on the frame\n"
"and the frame is cut to contain it.\n"
"\n"
"Checking this puts the label right above\n"
"the frame, so that the frame isn't cut.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxGroupLabel->setText(QCoreApplication::translate("KvManager::KvantumManager", "Group-box label above frame", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxInlineSpin->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "By default, spin indicators are drawn as\n"
"two buttons with arrows or plus/minus signs.\n"
"\n"
"Checking this integrates the spin indicators\n"
"into the spin line-edit..", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxInlineSpin->setText(QCoreApplication::translate("KvManager::KvantumManager", "Inline spin indicators", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxRubber->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "By default, drop rectangles for movable\n"
"toolbars and dock widgets are hollow.\n"
"\n"
"This option fills drop rectangles with\n"
"the highlight color.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxRubber->setText(QCoreApplication::translate("KvManager::KvantumManager", "Fill rubber-band rectangles", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxVSpin->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "By default, spin indicators are drawn on adjacent buttons.\n"
"\n"
"Checking this puts the spin-up indicator above the\n"
"spin-down one inside the spin line-edit.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxVSpin->setText(QCoreApplication::translate("KvManager::KvantumManager", "Vertical spin indicators", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxMenubar->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Mouse tracking is enabled\n"
"for menubars by default.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        checkBoxMenubar->setWhatsThis(QCoreApplication::translate("KvManager::KvantumManager", "<html><head/><body><p>Mouse tracking is enabled for menubars by default, i.e., after a menubar item is clicked and its menu is shown, the menus of the other menubar items will be shown if the cursor is put on them without clicking.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        checkBoxMenubar->setText(QCoreApplication::translate("KvManager::KvantumManager", "Mouse tracking for menubars", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxComboEdit->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Draw the whole editable combo-box as a\n"
"line-edit with arrow (and icon, if it exists)?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        checkBoxComboEdit->setWhatsThis(QCoreApplication::translate("KvManager::KvantumManager", "<html><head/><body><p>Draw the whole editable combo-box as a line-edit with arrow (and icon, if it exists)?</p><p>By default, a combo-box consists of a line-edit, a button with arrow on one side and another button with icon on the other side.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        checkBoxComboEdit->setText(QCoreApplication::translate("KvManager::KvantumManager", "Editable combo as line-edit", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxMenuToolbar->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "If checked, the menubar and toolbar will be drawn as a whole by\n"
"the toolbar SVG element when they are adjacent to each another.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxMenuToolbar->setText(QCoreApplication::translate("KvManager::KvantumManager", "Merge menubar with toolbar", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxComboMenu->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Draw combo popups as menu popups (i.e. like in Gtk)?\n"
"\n"
"By default, combo popups do not cover the combo box.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxComboMenu->setText(QCoreApplication::translate("KvManager::KvantumManager", "Combo popup as menu", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxGroupToolbar->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "If checked, toolbar buttons will be drawn grouped and raised\n"
"between toolbar separators.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxGroupToolbar->setText(QCoreApplication::translate("KvManager::KvantumManager", "Group toolbar buttons", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxHideComboCheckboxes->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "When drawing combo popups as menus,\n"
"there will be a checkbox next to each entry\n"
"(although Kvantum draws it as a radio button).\n"
"\n"
"This option will hide these.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxHideComboCheckboxes->setText(QCoreApplication::translate("KvManager::KvantumManager", "Non-checkable combo menu", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxAlt->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "If unchecked, shortcuts will not be underlined at all.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxAlt->setText(QCoreApplication::translate("KvManager::KvantumManager", "Underline shortcuts with Alt", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxleftTab->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "In Kvantum, tabs are centered by default.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxleftTab->setText(QCoreApplication::translate("KvManager::KvantumManager", "Left aligned tabs", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxJoinTab->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Inactive tabs are joined together by default,\n"
"i.e., there is no border between them.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxJoinTab->setText(QCoreApplication::translate("KvManager::KvantumManager", "Join inactive tabs", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxNoScrollArrow->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Scrollbars have add-line and sub-line arrows by default.\n"
"\n"
"Checking this box removes arrows as far as possible.\n"
"\n"
"If disabled, see Compositing & General Look \342\206\222 Transient scrollbars!", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxNoScrollArrow->setText(QCoreApplication::translate("KvManager::KvantumManager", "No arrows for scrollbars", nullptr));
#if QT_CONFIG(tooltip)
        label_10->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "How to activate view items?", nullptr));
#endif // QT_CONFIG(tooltip)
        label_10->setText(QCoreApplication::translate("KvManager::KvantumManager", "Click behavior:", nullptr));
#if QT_CONFIG(tooltip)
        comboClick->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "How to activate view items?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_2->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Will have effect only if style\n"
"is not set by the app in its code.\n"
"\n"
"Default is \"Follow Style\".", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(QCoreApplication::translate("KvManager::KvantumManager", "Toolbutton style:", nullptr));
#if QT_CONFIG(tooltip)
        comboToolButton->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Will have effect only if style\n"
"is not set by the app in its code.\n"
"\n"
"Default is \"Follow Style\".", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxScrollIn->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Draw scrollbars inside view frames?\n"
"\n"
"By default, scrollbars are drawn outide view frames.\n"
"\n"
"If disabled, see Compositing & General Look \342\206\222 Transient scrollbars!", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxScrollIn->setText(QCoreApplication::translate("KvManager::KvantumManager", "Scrollbars inside frames", nullptr));
        label_3->setText(QCoreApplication::translate("KvManager::KvantumManager", "Dialog button layout:", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxFocusRect->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "They may look like dotted rectangles\n"
"on focused buttons and other widgets.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxFocusRect->setText(QCoreApplication::translate("KvManager::KvantumManager", "Remove focus rectangles", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxTree->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Draw tree branch lines?\n"
"\n"
"By default, tree branches have indicators but no line.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxTree->setText(QCoreApplication::translate("KvManager::KvantumManager", "Tree branch lines", nullptr));
#if QT_CONFIG(tooltip)
        labelX11Drag->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Drag windows from their menubars, primary toolbars\n"
"or anywhere possible (and not only from their title bars)?\n"
"\n"
"If this is disabled, see:\n"
"Miscellaneous \342\206\222 Respect current DE if possible", nullptr));
#endif // QT_CONFIG(tooltip)
        labelX11Drag->setText(QCoreApplication::translate("KvManager::KvantumManager", "Drag from:", nullptr));
#if QT_CONFIG(tooltip)
        comboX11Drag->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Drag windows from their menubars, primary toolbars\n"
"or anywhere possible (and not only from their title bars)?\n"
"\n"
"If this is disabled, see:\n"
"Miscellaneous \342\206\222 Respect current DE if possible", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxScrollableMenu->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Should big menus be scrollable and have\n"
"scroll arrows on their top and/or bottom?\n"
"\n"
"By default, big menus are scrollable.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxScrollableMenu->setText(QCoreApplication::translate("KvManager::KvantumManager", "Scrollable menus", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxBtnDrag->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Warning: This can be quite confusing at first.\n"
"\n"
"If you have enabled it, you could temporarily disable it\n"
"for a button that can be dragged and dropped by pressing\n"
"the Ctrl key before pressing the button.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxBtnDrag->setText(QCoreApplication::translate("KvManager::KvantumManager", "Allow dragging from buttons", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_4), QCoreApplication::translate("KvManager::KvantumManager", "Miscellaneous", nullptr));
        toolBox->setItemText(toolBox->indexOf(page_3), QCoreApplication::translate("KvManager::KvantumManager", "Configure Active Theme", nullptr));
        appLabel->setText(QCoreApplication::translate("KvManager::KvantumManager", "<center>Here you could assign themes to specific applications.</center><br><center>For each theme, you could add a comma-separated list of executables whose applications should use that theme instead of the active theme. After doing so for all of your chosen themes, save the result by clicking on the <i>Save</i> button!</center>", nullptr));
        label_6->setText(QCoreApplication::translate("KvManager::KvantumManager", "Installed Theme", nullptr));
        label_7->setText(QCoreApplication::translate("KvManager::KvantumManager", "Application(s)", nullptr));
#if QT_CONFIG(tooltip)
        appsEdit->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Each executable name can be either a\n"
"simple string or a regular expression.", nullptr));
#endif // QT_CONFIG(tooltip)
        appsEdit->setPlaceholderText(QCoreApplication::translate("KvManager::KvantumManager", "app1,app2,app3", nullptr));
#if QT_CONFIG(tooltip)
        removeAppButton->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Use the active theme for all apps!\n"
"\n"
"This Needs saving to take effect.", nullptr));
#endif // QT_CONFIG(tooltip)
        removeAppButton->setText(QCoreApplication::translate("KvManager::KvantumManager", "Remove List", nullptr));
#if QT_CONFIG(tooltip)
        saveAppButton->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Save the current list of apps", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        saveAppButton->setWhatsThis(QCoreApplication::translate("KvManager::KvantumManager", "<html><head/><body><p>Save the current list of applications with their corresponding themes!</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        saveAppButton->setText(QCoreApplication::translate("KvManager::KvantumManager", "Save", nullptr));
        toolBox->setItemText(toolBox->indexOf(page_4), QCoreApplication::translate("KvManager::KvantumManager", "Application Themes", nullptr));
#if QT_CONFIG(tooltip)
        quit->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Ctrl+Q", nullptr));
#endif // QT_CONFIG(tooltip)
        quit->setText(QCoreApplication::translate("KvManager::KvantumManager", "Quit", nullptr));
#if QT_CONFIG(shortcut)
        quit->setShortcut(QCoreApplication::translate("KvManager::KvantumManager", "Ctrl+Q", nullptr));
#endif // QT_CONFIG(shortcut)
#if QT_CONFIG(tooltip)
        preview->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "Preview the active theme\n"
"or update its preview.", nullptr));
#endif // QT_CONFIG(tooltip)
        preview->setText(QCoreApplication::translate("KvManager::KvantumManager", "Preview", nullptr));
        aboutButton->setText(QCoreApplication::translate("KvManager::KvantumManager", "About", nullptr));
#if QT_CONFIG(tooltip)
        whatsthisButton->setToolTip(QCoreApplication::translate("KvManager::KvantumManager", "What's This?", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        whatsthisButton->setWhatsThis(QCoreApplication::translate("KvManager::KvantumManager", "<html><head/><body><p>Click on this button and then click on a GUI element that has &quot;What's This&quot; tooltip  to get information about what it does.</p><p>There are also ordinary tooltips but this kind of tooltip will not disappear until you click somewhere.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        whatsthisButton->setText(QCoreApplication::translate("KvManager::KvantumManager", "Help", nullptr));
    } // retranslateUi

};

} // namespace KvManager

namespace KvManager {
namespace Ui {
    class KvantumManager: public Ui_KvantumManager {};
} // namespace Ui
} // namespace KvManager

#endif // UI_KVANTUMMANAGER_H
