/****************************************************************************
** Meta object code from reading C++ file 'animation5.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../Kvantum/Kvantum/style/qt5/animation5.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'animation5.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kvantum__Animation_t {
    QByteArrayData data[3];
    char stringdata0[26];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kvantum__Animation_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kvantum__Animation_t qt_meta_stringdata_Kvantum__Animation = {
    {
QT_MOC_LITERAL(0, 0, 18), // "Kvantum::Animation"
QT_MOC_LITERAL(1, 19, 5), // "start"
QT_MOC_LITERAL(2, 25, 0) // ""

    },
    "Kvantum::Animation\0start\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kvantum__Animation[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void Kvantum::Animation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Animation *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->start(); break;
        default: ;
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Kvantum::Animation::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractAnimation::staticMetaObject>(),
    qt_meta_stringdata_Kvantum__Animation.data,
    qt_meta_data_Kvantum__Animation,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Kvantum::Animation::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kvantum::Animation::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kvantum__Animation.stringdata0))
        return static_cast<void*>(this);
    return QAbstractAnimation::qt_metacast(_clname);
}

int Kvantum::Animation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractAnimation::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_Kvantum__ProgressbarAnimation_t {
    QByteArrayData data[1];
    char stringdata0[30];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kvantum__ProgressbarAnimation_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kvantum__ProgressbarAnimation_t qt_meta_stringdata_Kvantum__ProgressbarAnimation = {
    {
QT_MOC_LITERAL(0, 0, 29) // "Kvantum::ProgressbarAnimation"

    },
    "Kvantum::ProgressbarAnimation"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kvantum__ProgressbarAnimation[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void Kvantum::ProgressbarAnimation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Kvantum::ProgressbarAnimation::staticMetaObject = { {
    QMetaObject::SuperData::link<Animation::staticMetaObject>(),
    qt_meta_stringdata_Kvantum__ProgressbarAnimation.data,
    qt_meta_data_Kvantum__ProgressbarAnimation,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Kvantum::ProgressbarAnimation::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kvantum::ProgressbarAnimation::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kvantum__ProgressbarAnimation.stringdata0))
        return static_cast<void*>(this);
    return Animation::qt_metacast(_clname);
}

int Kvantum::ProgressbarAnimation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Animation::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_Kvantum__NumberAnimation_t {
    QByteArrayData data[1];
    char stringdata0[25];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kvantum__NumberAnimation_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kvantum__NumberAnimation_t qt_meta_stringdata_Kvantum__NumberAnimation = {
    {
QT_MOC_LITERAL(0, 0, 24) // "Kvantum::NumberAnimation"

    },
    "Kvantum::NumberAnimation"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kvantum__NumberAnimation[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void Kvantum::NumberAnimation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Kvantum::NumberAnimation::staticMetaObject = { {
    QMetaObject::SuperData::link<Animation::staticMetaObject>(),
    qt_meta_stringdata_Kvantum__NumberAnimation.data,
    qt_meta_data_Kvantum__NumberAnimation,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Kvantum::NumberAnimation::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kvantum::NumberAnimation::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kvantum__NumberAnimation.stringdata0))
        return static_cast<void*>(this);
    return Animation::qt_metacast(_clname);
}

int Kvantum::NumberAnimation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Animation::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_Kvantum__ScrollbarAnimation_t {
    QByteArrayData data[4];
    char stringdata0[52];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kvantum__ScrollbarAnimation_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kvantum__ScrollbarAnimation_t qt_meta_stringdata_Kvantum__ScrollbarAnimation = {
    {
QT_MOC_LITERAL(0, 0, 27), // "Kvantum::ScrollbarAnimation"
QT_MOC_LITERAL(1, 28, 17), // "updateCurrentTime"
QT_MOC_LITERAL(2, 46, 0), // ""
QT_MOC_LITERAL(3, 47, 4) // "time"

    },
    "Kvantum::ScrollbarAnimation\0"
    "updateCurrentTime\0\0time"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kvantum__ScrollbarAnimation[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,

       0        // eod
};

void Kvantum::ScrollbarAnimation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ScrollbarAnimation *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->updateCurrentTime((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Kvantum::ScrollbarAnimation::staticMetaObject = { {
    QMetaObject::SuperData::link<NumberAnimation::staticMetaObject>(),
    qt_meta_stringdata_Kvantum__ScrollbarAnimation.data,
    qt_meta_data_Kvantum__ScrollbarAnimation,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Kvantum::ScrollbarAnimation::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kvantum::ScrollbarAnimation::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kvantum__ScrollbarAnimation.stringdata0))
        return static_cast<void*>(this);
    return NumberAnimation::qt_metacast(_clname);
}

int Kvantum::ScrollbarAnimation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NumberAnimation::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
