// This file is autogenerated. Changes will be overwritten.
#include "OXRBQHTNNB/moc_Kvantum5.cpp"
#include "OXRBQHTNNB/moc_KvantumPlugin5.cpp"
#include "OXRBQHTNNB/moc_animation5.cpp"
#include "OXRBQHTNNB/moc_blurhelper5.cpp"
#include "OXRBQHTNNB/moc_shortcuthandler5.cpp"
#include "OXRBQHTNNB/moc_windowmanager5.cpp"
