/****************************************************************************
** Meta object code from reading C++ file 'Kvantum5.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../Kvantum/Kvantum/style/qt5/Kvantum5.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Kvantum5.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kvantum__KvComboItemDelegate_t {
    QByteArrayData data[1];
    char stringdata0[29];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kvantum__KvComboItemDelegate_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kvantum__KvComboItemDelegate_t qt_meta_stringdata_Kvantum__KvComboItemDelegate = {
    {
QT_MOC_LITERAL(0, 0, 28) // "Kvantum::KvComboItemDelegate"

    },
    "Kvantum::KvComboItemDelegate"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kvantum__KvComboItemDelegate[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void Kvantum::KvComboItemDelegate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Kvantum::KvComboItemDelegate::staticMetaObject = { {
    QMetaObject::SuperData::link<QItemDelegate::staticMetaObject>(),
    qt_meta_stringdata_Kvantum__KvComboItemDelegate.data,
    qt_meta_data_Kvantum__KvComboItemDelegate,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Kvantum::KvComboItemDelegate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kvantum::KvComboItemDelegate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kvantum__KvComboItemDelegate.stringdata0))
        return static_cast<void*>(this);
    return QItemDelegate::qt_metacast(_clname);
}

int Kvantum::KvComboItemDelegate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QItemDelegate::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_Kvantum__Style_t {
    QByteArrayData data[13];
    char stringdata0[176];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kvantum__Style_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kvantum__Style_t qt_meta_stringdata_Kvantum__Style = {
    {
QT_MOC_LITERAL(0, 0, 14), // "Kvantum::Style"
QT_MOC_LITERAL(1, 15, 20), // "X-KDE-CustomElements"
QT_MOC_LITERAL(2, 36, 4), // "true"
QT_MOC_LITERAL(3, 41, 17), // "forgetPopupOrigin"
QT_MOC_LITERAL(4, 59, 0), // ""
QT_MOC_LITERAL(5, 60, 1), // "o"
QT_MOC_LITERAL(6, 62, 15), // "forgetMovedMenu"
QT_MOC_LITERAL(7, 78, 19), // "setAnimationOpacity"
QT_MOC_LITERAL(8, 98, 22), // "setAnimationOpacityOut"
QT_MOC_LITERAL(9, 121, 14), // "noTranslucency"
QT_MOC_LITERAL(10, 136, 13), // "removeFromSet"
QT_MOC_LITERAL(11, 150, 15), // "removeAnimation"
QT_MOC_LITERAL(12, 166, 9) // "animation"

    },
    "Kvantum::Style\0X-KDE-CustomElements\0"
    "true\0forgetPopupOrigin\0\0o\0forgetMovedMenu\0"
    "setAnimationOpacity\0setAnimationOpacityOut\0"
    "noTranslucency\0removeFromSet\0"
    "removeAnimation\0animation"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kvantum__Style[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
       7,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // classinfo: key, value
       1,    2,

 // slots: name, argc, parameters, tag, flags
       3,    1,   51,    4, 0x08 /* Private */,
       6,    1,   54,    4, 0x08 /* Private */,
       7,    0,   57,    4, 0x08 /* Private */,
       8,    0,   58,    4, 0x08 /* Private */,
       9,    1,   59,    4, 0x08 /* Private */,
      10,    1,   62,    4, 0x08 /* Private */,
      11,    1,   65,    4, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QObjectStar,    5,
    QMetaType::Void, QMetaType::QObjectStar,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QObjectStar,    5,
    QMetaType::Void, QMetaType::QObjectStar,    5,
    QMetaType::Void, QMetaType::QObjectStar,   12,

       0        // eod
};

void Kvantum::Style::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Style *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->forgetPopupOrigin((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 1: _t->forgetMovedMenu((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 2: _t->setAnimationOpacity(); break;
        case 3: _t->setAnimationOpacityOut(); break;
        case 4: _t->noTranslucency((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 5: _t->removeFromSet((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 6: _t->removeAnimation((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Kvantum::Style::staticMetaObject = { {
    QMetaObject::SuperData::link<QCommonStyle::staticMetaObject>(),
    qt_meta_stringdata_Kvantum__Style.data,
    qt_meta_data_Kvantum__Style,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Kvantum::Style::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kvantum::Style::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kvantum__Style.stringdata0))
        return static_cast<void*>(this);
    return QCommonStyle::qt_metacast(_clname);
}

int Kvantum::Style::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QCommonStyle::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
