/********************************************************************************
** Form generated from reading UI file 'KvantumPreviewBase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KVANTUMPREVIEWBASE_H
#define UI_KVANTUMPREVIEWBASE_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDateTimeEdit>
#include <QtWidgets/QDial>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QMdiArea>
#include <QtWidgets/QMenu>
#include <QtWidgets/QMenuBar>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QScrollBar>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QStatusBar>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QToolBar>
#include <QtWidgets/QToolBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_KvantumPreviewBase
{
public:
    QAction *actionQuit;
    QAction *actionMenu_Item;
    QAction *actionTest;
    QAction *actionDocMode;
    QAction *actionMenuButton;
    QAction *actionNew_Item;
    QAction *actionMenu_radio;
    QAction *actionMenu_radio1;
    QTabWidget *tabWidget;
    QWidget *tab;
    QGridLayout *gridLayout_20;
    QSpacerItem *verticalSpacer_14;
    QHBoxLayout *horizontalLayout;
    QDialogButtonBox *buttonBox;
    QSpacerItem *horizontalSpacer_2;
    QGridLayout *gridLayout_3;
    QPushButton *pushButton_7;
    QPushButton *pushButton;
    QPushButton *pushButton_9;
    QPushButton *pushButton_4;
    QPushButton *pushButton_11;
    QPushButton *pushButton_2;
    QPushButton *pushButton_10;
    QPushButton *pushButton_3;
    QPushButton *pushButton_12;
    QSpacerItem *horizontalSpacer_12;
    QPushButton *pushButton_5;
    QPushButton *pushButton_6;
    QSpacerItem *horizontalSpacer_17;
    QSpacerItem *horizontalSpacer_11;
    QCheckBox *checkBoxFlat;
    QLabel *label_7;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_13;
    QSpacerItem *verticalSpacer_3;
    QSpacerItem *verticalSpacer_2;
    QSpacerItem *verticalSpacer_15;
    QPushButton *pushButton_8;
    QWidget *tab_2;
    QGridLayout *gridLayout_5;
    QGridLayout *gridLayout_2;
    QToolButton *toolButton;
    QSpacerItem *horizontalSpacer_18;
    QToolButton *toolButton_18;
    QToolButton *toolButton_17;
    QSpacerItem *horizontalSpacer_19;
    QToolButton *toolButton_16;
    QToolButton *toolButton_2;
    QToolButton *toolButton_15;
    QToolButton *toolButton_3;
    QToolButton *toolButton_12;
    QToolButton *toolButton_4;
    QToolButton *toolButton_9;
    QToolButton *toolButton_5;
    QToolButton *toolButton_14;
    QToolButton *toolButton_6;
    QToolButton *toolButton_13;
    QToolButton *toolButton_7;
    QToolButton *toolButton_10;
    QToolButton *toolButton_8;
    QToolButton *toolButton_11;
    QSpacerItem *horizontalSpacer_3;
    QSpacerItem *horizontalSpacer_4;
    QSpacerItem *verticalSpacer;
    QSpacerItem *verticalSpacer_4;
    QCheckBox *checkBoxRaise;
    QSpacerItem *verticalSpacer_16;
    QWidget *tab_5;
    QGridLayout *gridLayout_7;
    QSpacerItem *verticalSpacer_5;
    QGridLayout *gridLayout_6;
    QRadioButton *radioButton;
    QRadioButton *radioButton_5;
    QRadioButton *radioButton_3;
    QRadioButton *radioButton_4;
    QRadioButton *radioButton_2;
    QRadioButton *radioButton_6;
    QCheckBox *checkBox;
    QCheckBox *checkBox_4;
    QCheckBox *checkBox_2;
    QCheckBox *checkBox_5;
    QCheckBox *checkBox_7;
    QCheckBox *checkBox_8;
    QCheckBox *checkBox_3;
    QCheckBox *checkBox_6;
    QSpacerItem *horizontalSpacer_6;
    QSpacerItem *verticalSpacer_6;
    QSpacerItem *horizontalSpacer_5;
    QWidget *tab_6;
    QGridLayout *gridLayout_9;
    QSpacerItem *verticalSpacer_10;
    QSpacerItem *horizontalSpacer_8;
    QGridLayout *gridLayout_8;
    QComboBox *comboBox;
    QComboBox *comboBox_7;
    QComboBox *comboBox_3;
    QComboBox *comboBox_8;
    QComboBox *comboBox_2;
    QComboBox *comboBox_5;
    QComboBox *comboBox_4;
    QComboBox *comboBox_6;
    QLineEdit *lineEdit;
    QLineEdit *lineEdit_3;
    QLineEdit *lineEdit_2;
    QLineEdit *lineEdit_4;
    QSpinBox *spinBox;
    QSpinBox *spinBox_2;
    QDateTimeEdit *dateTimeEdit_2;
    QDateTimeEdit *dateTimeEdit;
    QSpacerItem *horizontalSpacer_7;
    QSpacerItem *verticalSpacer_9;
    QWidget *tab_3;
    QGridLayout *gridLayout_12;
    QGridLayout *gridLayout_11;
    QProgressBar *progressBar_6;
    QProgressBar *progressBar_8;
    QProgressBar *progressBar_5;
    QProgressBar *progressBar_9;
    QDial *dial;
    QProgressBar *progressBar_10;
    QSpacerItem *verticalSpacer_7;
    QSpacerItem *horizontalSpacer_21;
    QSpacerItem *horizontalSpacer_22;
    QProgressBar *progressBar_7;
    QSpacerItem *horizontalSpacer_15;
    QSpacerItem *horizontalSpacer_20;
    QProgressBar *progressBar;
    QProgressBar *progressBar_4;
    QProgressBar *progressBar_2;
    QProgressBar *progressBar_3;
    QSpacerItem *horizontalSpacer_9;
    QGridLayout *gridLayout_10;
    QSlider *horizontalSlider;
    QSlider *horizontalSlider_2;
    QSlider *verticalSlider;
    QScrollBar *verticalScrollBar;
    QSlider *verticalSlider_2;
    QScrollBar *verticalScrollBar_2;
    QScrollBar *horizontalScrollBar;
    QScrollBar *horizontalScrollBar_2;
    QSlider *verticalSlider_4;
    QSlider *verticalSlider_3;
    QSlider *horizontalSlider_3;
    QSlider *horizontalSlider_4;
    QSlider *verticalSlider_5;
    QSlider *verticalSlider_6;
    QSpacerItem *horizontalSpacer_10;
    QSpacerItem *verticalSpacer_11;
    QSpacerItem *verticalSpacer_12;
    QSpacerItem *verticalSpacer_13;
    QWidget *tab_4;
    QGridLayout *gridLayout_18;
    QSplitter *splitter_2;
    QSplitter *splitter;
    QTreeWidget *treeWidget;
    QListWidget *listWidget;
    QMdiArea *mdiArea;
    QWidget *subwindow;
    QGridLayout *gridLayout_21;
    QSpacerItem *horizontalSpacer_16;
    QSpacerItem *verticalSpacer_17;
    QWidget *layoutWidget;
    QGridLayout *gridLayout_4;
    QFrame *frame_2;
    QGridLayout *gridLayout_17;
    QLabel *label_5;
    QGroupBox *groupBox_3;
    QTabWidget *tabWidget_6;
    QWidget *tab_15;
    QHBoxLayout *horizontalLayout_10;
    QLabel *label_16;
    QWidget *tab_16;
    QHBoxLayout *horizontalLayout_11;
    QLabel *label_17;
    QTabWidget *tabWidget_5;
    QWidget *tab_13;
    QHBoxLayout *horizontalLayout_9;
    QLabel *label_12;
    QWidget *tab_14;
    QHBoxLayout *horizontalLayout_6;
    QLabel *label_14;
    QStackedWidget *stackedWidget;
    QWidget *page_5;
    QGridLayout *gridLayout_14;
    QLabel *label_2;
    QWidget *page_6;
    QGridLayout *gridLayout_15;
    QLabel *label_3;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *label_6;
    QTableWidget *tableWidget;
    QDockWidget *dockWidget;
    QWidget *dockWidgetContents;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_19;
    QLabel *label_8;
    QToolBox *toolBox;
    QWidget *page;
    QVBoxLayout *verticalLayout;
    QLabel *label_18;
    QWidget *page_2;
    QToolBox *toolBox_2;
    QWidget *page_3;
    QWidget *page_4;
    QTabWidget *tabWidget_2;
    QWidget *tab_7;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *checkBoxDocMode;
    QWidget *tab_8;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_9;
    QFrame *frame;
    QGridLayout *gridLayout_16;
    QLabel *label_4;
    QTabWidget *tabWidget_3;
    QWidget *tab_9;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_10;
    QWidget *tab_10;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label_11;
    QTabWidget *tabWidget_4;
    QWidget *tab_12;
    QHBoxLayout *horizontalLayout_8;
    QLabel *label_15;
    QWidget *tab_11;
    QHBoxLayout *horizontalLayout_7;
    QLabel *label_13;
    QMenuBar *menubar;
    QMenu *menuFile;
    QMenu *menuSubmenu;
    QStatusBar *statusbar;
    QToolBar *toolBar;
    QToolBar *toolBar_2;

    void setupUi(QMainWindow *KvantumPreviewBase)
    {
        if (KvantumPreviewBase->objectName().isEmpty())
            KvantumPreviewBase->setObjectName("KvantumPreviewBase");
        KvantumPreviewBase->resize(800, 600);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/Icons/data/kvantum.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        KvantumPreviewBase->setWindowIcon(icon);
        actionQuit = new QAction(KvantumPreviewBase);
        actionQuit->setObjectName("actionQuit");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("application-exit")));
        actionQuit->setIcon(icon1);
        actionMenu_Item = new QAction(KvantumPreviewBase);
        actionMenu_Item->setObjectName("actionMenu_Item");
        actionMenu_Item->setCheckable(true);
        actionTest = new QAction(KvantumPreviewBase);
        actionTest->setObjectName("actionTest");
        actionTest->setCheckable(true);
        QIcon icon2;
        QString iconThemeName = QString::fromUtf8("format-text-direction-rtl");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8(""), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionTest->setIcon(icon2);
        actionDocMode = new QAction(KvantumPreviewBase);
        actionDocMode->setObjectName("actionDocMode");
        actionDocMode->setCheckable(true);
        actionDocMode->setIcon(icon);
        actionMenuButton = new QAction(KvantumPreviewBase);
        actionMenuButton->setObjectName("actionMenuButton");
        actionMenuButton->setCheckable(true);
        actionMenuButton->setIcon(icon);
        actionNew_Item = new QAction(KvantumPreviewBase);
        actionNew_Item->setObjectName("actionNew_Item");
        actionNew_Item->setCheckable(true);
        actionNew_Item->setChecked(true);
        actionMenu_radio = new QAction(KvantumPreviewBase);
        actionMenu_radio->setObjectName("actionMenu_radio");
        actionMenu_radio->setCheckable(true);
        actionMenu_radio1 = new QAction(KvantumPreviewBase);
        actionMenu_radio1->setObjectName("actionMenu_radio1");
        actionMenu_radio1->setCheckable(true);
        tabWidget = new QTabWidget(KvantumPreviewBase);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setMovable(true);
        tab = new QWidget();
        tab->setObjectName("tab");
        gridLayout_20 = new QGridLayout(tab);
        gridLayout_20->setObjectName("gridLayout_20");
        verticalSpacer_14 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_20->addItem(verticalSpacer_14, 9, 2, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName("horizontalLayout");
        buttonBox = new QDialogButtonBox(tab);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::No|QDialogButtonBox::Ok|QDialogButtonBox::Open|QDialogButtonBox::Save|QDialogButtonBox::Yes);

        horizontalLayout->addWidget(buttonBox);


        gridLayout_20->addLayout(horizontalLayout, 8, 1, 1, 3);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_20->addItem(horizontalSpacer_2, 8, 0, 1, 1);

        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName("gridLayout_3");
        pushButton_7 = new QPushButton(tab);
        pushButton_7->setObjectName("pushButton_7");
        pushButton_7->setCheckable(true);

        gridLayout_3->addWidget(pushButton_7, 0, 2, 5, 1);

        pushButton = new QPushButton(tab);
        pushButton->setObjectName("pushButton");

        gridLayout_3->addWidget(pushButton, 0, 0, 1, 1);

        pushButton_9 = new QPushButton(tab);
        pushButton_9->setObjectName("pushButton_9");
        pushButton_9->setEnabled(false);

        gridLayout_3->addWidget(pushButton_9, 0, 4, 1, 1);

        pushButton_4 = new QPushButton(tab);
        pushButton_4->setObjectName("pushButton_4");
        pushButton_4->setCheckable(true);
        pushButton_4->setChecked(true);

        gridLayout_3->addWidget(pushButton_4, 1, 0, 1, 1);

        pushButton_11 = new QPushButton(tab);
        pushButton_11->setObjectName("pushButton_11");
        pushButton_11->setEnabled(false);
        pushButton_11->setCheckable(true);
        pushButton_11->setChecked(true);

        gridLayout_3->addWidget(pushButton_11, 1, 4, 1, 1);

        pushButton_2 = new QPushButton(tab);
        pushButton_2->setObjectName("pushButton_2");

        gridLayout_3->addWidget(pushButton_2, 2, 0, 1, 1);

        pushButton_10 = new QPushButton(tab);
        pushButton_10->setObjectName("pushButton_10");
        pushButton_10->setEnabled(false);

        gridLayout_3->addWidget(pushButton_10, 2, 4, 1, 1);

        pushButton_3 = new QPushButton(tab);
        pushButton_3->setObjectName("pushButton_3");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("folder")));
        pushButton_3->setIcon(icon3);
        pushButton_3->setIconSize(QSize(32, 32));

        gridLayout_3->addWidget(pushButton_3, 3, 0, 1, 1);

        pushButton_12 = new QPushButton(tab);
        pushButton_12->setObjectName("pushButton_12");
        pushButton_12->setEnabled(false);
        pushButton_12->setIcon(icon3);
        pushButton_12->setIconSize(QSize(32, 32));

        gridLayout_3->addWidget(pushButton_12, 3, 4, 1, 1);

        horizontalSpacer_12 = new QSpacerItem(10, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_12, 2, 3, 1, 1);

        pushButton_5 = new QPushButton(tab);
        pushButton_5->setObjectName("pushButton_5");

        gridLayout_3->addWidget(pushButton_5, 4, 0, 1, 1);

        pushButton_6 = new QPushButton(tab);
        pushButton_6->setObjectName("pushButton_6");
        pushButton_6->setEnabled(false);

        gridLayout_3->addWidget(pushButton_6, 4, 4, 1, 1);

        horizontalSpacer_17 = new QSpacerItem(10, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_17, 0, 1, 1, 1);


        gridLayout_20->addLayout(gridLayout_3, 3, 1, 2, 3);

        horizontalSpacer_11 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_20->addItem(horizontalSpacer_11, 8, 4, 1, 1);

        checkBoxFlat = new QCheckBox(tab);
        checkBoxFlat->setObjectName("checkBoxFlat");

        gridLayout_20->addWidget(checkBoxFlat, 1, 2, 1, 1, Qt::AlignHCenter);

        label_7 = new QLabel(tab);
        label_7->setObjectName("label_7");
        QFont font;
        font.setBold(true);
        label_7->setFont(font);
        label_7->setAlignment(Qt::AlignCenter);
        label_7->setMargin(10);

        gridLayout_20->addWidget(label_7, 7, 1, 1, 3);

        horizontalSpacer = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_20->addItem(horizontalSpacer, 3, 4, 2, 1);

        horizontalSpacer_13 = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_20->addItem(horizontalSpacer_13, 3, 0, 2, 1);

        verticalSpacer_3 = new QSpacerItem(20, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_20->addItem(verticalSpacer_3, 0, 2, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_20->addItem(verticalSpacer_2, 6, 2, 1, 1);

        verticalSpacer_15 = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_20->addItem(verticalSpacer_15, 2, 2, 1, 1);

        pushButton_8 = new QPushButton(tab);
        pushButton_8->setObjectName("pushButton_8");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(pushButton_8->sizePolicy().hasHeightForWidth());
        pushButton_8->setSizePolicy(sizePolicy);

        gridLayout_20->addWidget(pushButton_8, 5, 2, 1, 1);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        gridLayout_5 = new QGridLayout(tab_2);
        gridLayout_5->setObjectName("gridLayout_5");
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        toolButton = new QToolButton(tab_2);
        toolButton->setObjectName("toolButton");

        gridLayout_2->addWidget(toolButton, 0, 0, 1, 1);

        horizontalSpacer_18 = new QSpacerItem(10, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_18, 0, 1, 1, 1);

        toolButton_18 = new QToolButton(tab_2);
        toolButton_18->setObjectName("toolButton_18");
        toolButton_18->setText(QString::fromUtf8("..."));
        toolButton_18->setArrowType(Qt::DownArrow);

        gridLayout_2->addWidget(toolButton_18, 0, 2, 8, 1);

        toolButton_17 = new QToolButton(tab_2);
        toolButton_17->setObjectName("toolButton_17");
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/Icons/data/icon.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButton_17->setIcon(icon4);
        toolButton_17->setCheckable(true);
        toolButton_17->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);

        gridLayout_2->addWidget(toolButton_17, 0, 3, 8, 1);

        horizontalSpacer_19 = new QSpacerItem(10, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_19, 0, 4, 1, 1);

        toolButton_16 = new QToolButton(tab_2);
        toolButton_16->setObjectName("toolButton_16");
        toolButton_16->setEnabled(false);

        gridLayout_2->addWidget(toolButton_16, 0, 5, 1, 1);

        toolButton_2 = new QToolButton(tab_2);
        toolButton_2->setObjectName("toolButton_2");

        gridLayout_2->addWidget(toolButton_2, 1, 0, 1, 1);

        toolButton_15 = new QToolButton(tab_2);
        toolButton_15->setObjectName("toolButton_15");
        toolButton_15->setEnabled(false);

        gridLayout_2->addWidget(toolButton_15, 1, 5, 1, 1);

        toolButton_3 = new QToolButton(tab_2);
        toolButton_3->setObjectName("toolButton_3");
        toolButton_3->setCheckable(true);
        toolButton_3->setChecked(true);
        toolButton_3->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
        toolButton_3->setArrowType(Qt::LeftArrow);

        gridLayout_2->addWidget(toolButton_3, 2, 0, 1, 1);

        toolButton_12 = new QToolButton(tab_2);
        toolButton_12->setObjectName("toolButton_12");
        toolButton_12->setEnabled(false);
        toolButton_12->setCheckable(true);
        toolButton_12->setChecked(true);
        toolButton_12->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
        toolButton_12->setArrowType(Qt::LeftArrow);

        gridLayout_2->addWidget(toolButton_12, 2, 5, 1, 1);

        toolButton_4 = new QToolButton(tab_2);
        toolButton_4->setObjectName("toolButton_4");
        QIcon icon5;
        icon5.addFile(QString::fromUtf8(":/Icons/data/icon.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButton_4->setIcon(icon5);
        toolButton_4->setIconSize(QSize(32, 32));
        toolButton_4->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        gridLayout_2->addWidget(toolButton_4, 3, 0, 1, 1);

        toolButton_9 = new QToolButton(tab_2);
        toolButton_9->setObjectName("toolButton_9");
        toolButton_9->setEnabled(false);
        toolButton_9->setIcon(icon5);
        toolButton_9->setIconSize(QSize(32, 32));
        toolButton_9->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        gridLayout_2->addWidget(toolButton_9, 3, 5, 1, 1);

        toolButton_5 = new QToolButton(tab_2);
        toolButton_5->setObjectName("toolButton_5");
        toolButton_5->setIcon(icon4);
        toolButton_5->setIconSize(QSize(32, 32));
        toolButton_5->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);

        gridLayout_2->addWidget(toolButton_5, 4, 0, 1, 1);

        toolButton_14 = new QToolButton(tab_2);
        toolButton_14->setObjectName("toolButton_14");
        toolButton_14->setEnabled(false);
        toolButton_14->setIcon(icon4);
        toolButton_14->setIconSize(QSize(32, 32));
        toolButton_14->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);

        gridLayout_2->addWidget(toolButton_14, 4, 5, 1, 1);

        toolButton_6 = new QToolButton(tab_2);
        toolButton_6->setObjectName("toolButton_6");
        toolButton_6->setIcon(icon4);
        toolButton_6->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        toolButton_6->setArrowType(Qt::LeftArrow);

        gridLayout_2->addWidget(toolButton_6, 5, 0, 1, 1);

        toolButton_13 = new QToolButton(tab_2);
        toolButton_13->setObjectName("toolButton_13");
        toolButton_13->setEnabled(false);
        toolButton_13->setIcon(icon4);
        toolButton_13->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        toolButton_13->setArrowType(Qt::LeftArrow);

        gridLayout_2->addWidget(toolButton_13, 5, 5, 1, 1);

        toolButton_7 = new QToolButton(tab_2);
        toolButton_7->setObjectName("toolButton_7");
        toolButton_7->setIcon(icon4);
        toolButton_7->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
        toolButton_7->setArrowType(Qt::UpArrow);

        gridLayout_2->addWidget(toolButton_7, 6, 0, 1, 1);

        toolButton_10 = new QToolButton(tab_2);
        toolButton_10->setObjectName("toolButton_10");
        toolButton_10->setEnabled(false);
        toolButton_10->setIcon(icon4);
        toolButton_10->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
        toolButton_10->setArrowType(Qt::UpArrow);

        gridLayout_2->addWidget(toolButton_10, 6, 5, 1, 1);

        toolButton_8 = new QToolButton(tab_2);
        toolButton_8->setObjectName("toolButton_8");
        QIcon icon6(QIcon::fromTheme(QString::fromUtf8("user-home")));
        toolButton_8->setIcon(icon6);
        toolButton_8->setCheckable(true);
        toolButton_8->setPopupMode(QToolButton::MenuButtonPopup);
        toolButton_8->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
        toolButton_8->setArrowType(Qt::RightArrow);

        gridLayout_2->addWidget(toolButton_8, 7, 0, 1, 1);

        toolButton_11 = new QToolButton(tab_2);
        toolButton_11->setObjectName("toolButton_11");
        toolButton_11->setEnabled(false);
        toolButton_11->setIcon(icon6);
        toolButton_11->setCheckable(true);
        toolButton_11->setPopupMode(QToolButton::MenuButtonPopup);
        toolButton_11->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
        toolButton_11->setArrowType(Qt::RightArrow);

        gridLayout_2->addWidget(toolButton_11, 7, 5, 1, 1);


        gridLayout_5->addLayout(gridLayout_2, 3, 1, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_5->addItem(horizontalSpacer_3, 3, 0, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_5->addItem(horizontalSpacer_4, 3, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_5->addItem(verticalSpacer, 4, 1, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_5->addItem(verticalSpacer_4, 0, 1, 1, 1);

        checkBoxRaise = new QCheckBox(tab_2);
        checkBoxRaise->setObjectName("checkBoxRaise");

        gridLayout_5->addWidget(checkBoxRaise, 1, 1, 1, 1, Qt::AlignHCenter);

        verticalSpacer_16 = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_5->addItem(verticalSpacer_16, 2, 1, 1, 1);

        tabWidget->addTab(tab_2, QString());
        tab_5 = new QWidget();
        tab_5->setObjectName("tab_5");
        gridLayout_7 = new QGridLayout(tab_5);
        gridLayout_7->setObjectName("gridLayout_7");
        verticalSpacer_5 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_7->addItem(verticalSpacer_5, 0, 1, 1, 1);

        gridLayout_6 = new QGridLayout();
        gridLayout_6->setObjectName("gridLayout_6");
        radioButton = new QRadioButton(tab_5);
        radioButton->setObjectName("radioButton");
        radioButton->setChecked(false);

        gridLayout_6->addWidget(radioButton, 0, 1, 1, 1);

        radioButton_5 = new QRadioButton(tab_5);
        radioButton_5->setObjectName("radioButton_5");
        radioButton_5->setEnabled(false);
        radioButton_5->setAutoExclusive(false);

        gridLayout_6->addWidget(radioButton_5, 0, 2, 1, 1);

        radioButton_3 = new QRadioButton(tab_5);
        radioButton_3->setObjectName("radioButton_3");

        gridLayout_6->addWidget(radioButton_3, 1, 1, 1, 1);

        radioButton_4 = new QRadioButton(tab_5);
        radioButton_4->setObjectName("radioButton_4");
        radioButton_4->setEnabled(false);
        radioButton_4->setAutoExclusive(false);

        gridLayout_6->addWidget(radioButton_4, 1, 2, 1, 1);

        radioButton_2 = new QRadioButton(tab_5);
        radioButton_2->setObjectName("radioButton_2");
        radioButton_2->setIcon(icon4);
        radioButton_2->setIconSize(QSize(32, 32));
        radioButton_2->setChecked(true);
        radioButton_2->setAutoExclusive(false);

        gridLayout_6->addWidget(radioButton_2, 2, 1, 1, 1);

        radioButton_6 = new QRadioButton(tab_5);
        radioButton_6->setObjectName("radioButton_6");
        radioButton_6->setEnabled(false);
        radioButton_6->setIcon(icon4);
        radioButton_6->setIconSize(QSize(32, 32));
        radioButton_6->setChecked(true);
        radioButton_6->setAutoExclusive(false);

        gridLayout_6->addWidget(radioButton_6, 2, 2, 1, 1);

        checkBox = new QCheckBox(tab_5);
        checkBox->setObjectName("checkBox");
        checkBox->setChecked(true);

        gridLayout_6->addWidget(checkBox, 3, 1, 1, 1);

        checkBox_4 = new QCheckBox(tab_5);
        checkBox_4->setObjectName("checkBox_4");
        checkBox_4->setEnabled(false);
        checkBox_4->setChecked(true);

        gridLayout_6->addWidget(checkBox_4, 3, 2, 1, 1);

        checkBox_2 = new QCheckBox(tab_5);
        checkBox_2->setObjectName("checkBox_2");

        gridLayout_6->addWidget(checkBox_2, 4, 1, 1, 1);

        checkBox_5 = new QCheckBox(tab_5);
        checkBox_5->setObjectName("checkBox_5");
        checkBox_5->setEnabled(false);

        gridLayout_6->addWidget(checkBox_5, 4, 2, 1, 1);

        checkBox_7 = new QCheckBox(tab_5);
        checkBox_7->setObjectName("checkBox_7");
        checkBox_7->setTristate(true);

        gridLayout_6->addWidget(checkBox_7, 5, 1, 1, 1);

        checkBox_8 = new QCheckBox(tab_5);
        checkBox_8->setObjectName("checkBox_8");
        checkBox_8->setEnabled(false);
        checkBox_8->setTristate(true);

        gridLayout_6->addWidget(checkBox_8, 5, 2, 1, 1);

        checkBox_3 = new QCheckBox(tab_5);
        checkBox_3->setObjectName("checkBox_3");
        checkBox_3->setIcon(icon4);

        gridLayout_6->addWidget(checkBox_3, 6, 1, 1, 1);

        checkBox_6 = new QCheckBox(tab_5);
        checkBox_6->setObjectName("checkBox_6");
        checkBox_6->setEnabled(false);
        checkBox_6->setIcon(icon4);
        checkBox_6->setTristate(true);

        gridLayout_6->addWidget(checkBox_6, 6, 2, 1, 1);


        gridLayout_7->addLayout(gridLayout_6, 1, 1, 2, 1);

        horizontalSpacer_6 = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_7->addItem(horizontalSpacer_6, 1, 2, 2, 1);

        verticalSpacer_6 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_7->addItem(verticalSpacer_6, 3, 1, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_7->addItem(horizontalSpacer_5, 1, 0, 2, 1);

        tabWidget->addTab(tab_5, QString());
        tab_6 = new QWidget();
        tab_6->setObjectName("tab_6");
        gridLayout_9 = new QGridLayout(tab_6);
        gridLayout_9->setObjectName("gridLayout_9");
        verticalSpacer_10 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_9->addItem(verticalSpacer_10, 0, 1, 1, 1);

        horizontalSpacer_8 = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_9->addItem(horizontalSpacer_8, 1, 0, 1, 1);

        gridLayout_8 = new QGridLayout();
        gridLayout_8->setObjectName("gridLayout_8");
        comboBox = new QComboBox(tab_6);
        comboBox->addItem(icon4, QString());
        comboBox->addItem(icon6, QString());
        comboBox->addItem(QString());
        comboBox->addItem(QString());
        comboBox->addItem(QString());
        comboBox->setObjectName("comboBox");

        gridLayout_8->addWidget(comboBox, 0, 0, 1, 1);

        comboBox_7 = new QComboBox(tab_6);
        comboBox_7->addItem(icon4, QString());
        comboBox_7->addItem(icon6, QString());
        comboBox_7->addItem(QString());
        comboBox_7->addItem(QString());
        comboBox_7->addItem(QString());
        comboBox_7->setObjectName("comboBox_7");
        comboBox_7->setEnabled(false);

        gridLayout_8->addWidget(comboBox_7, 0, 1, 1, 1);

        comboBox_3 = new QComboBox(tab_6);
        comboBox_3->addItem(icon4, QString());
        comboBox_3->addItem(icon4, QString());
        comboBox_3->addItem(QString());
        comboBox_3->addItem(QString());
        comboBox_3->addItem(QString());
        comboBox_3->addItem(QString());
        comboBox_3->addItem(QString());
        comboBox_3->addItem(QString());
        comboBox_3->addItem(QString());
        comboBox_3->addItem(QString());
        comboBox_3->addItem(QString());
        comboBox_3->setObjectName("comboBox_3");
        comboBox_3->setFrame(false);

        gridLayout_8->addWidget(comboBox_3, 1, 0, 1, 1);

        comboBox_8 = new QComboBox(tab_6);
        comboBox_8->addItem(icon4, QString());
        comboBox_8->addItem(icon4, QString());
        comboBox_8->addItem(QString());
        comboBox_8->addItem(QString());
        comboBox_8->addItem(QString());
        comboBox_8->addItem(QString());
        comboBox_8->addItem(QString());
        comboBox_8->addItem(QString());
        comboBox_8->addItem(QString());
        comboBox_8->addItem(QString());
        comboBox_8->addItem(QString());
        comboBox_8->setObjectName("comboBox_8");
        comboBox_8->setEnabled(false);
        comboBox_8->setFrame(false);

        gridLayout_8->addWidget(comboBox_8, 1, 1, 1, 1);

        comboBox_2 = new QComboBox(tab_6);
        comboBox_2->addItem(icon4, QString());
        comboBox_2->addItem(icon4, QString());
        comboBox_2->addItem(QString());
        comboBox_2->addItem(QString());
        comboBox_2->addItem(QString());
        comboBox_2->setObjectName("comboBox_2");
        comboBox_2->setEditable(true);

        gridLayout_8->addWidget(comboBox_2, 2, 0, 1, 1);

        comboBox_5 = new QComboBox(tab_6);
        comboBox_5->addItem(icon4, QString());
        comboBox_5->addItem(icon4, QString());
        comboBox_5->addItem(QString());
        comboBox_5->addItem(QString());
        comboBox_5->addItem(QString());
        comboBox_5->setObjectName("comboBox_5");
        comboBox_5->setEnabled(false);
        comboBox_5->setEditable(true);

        gridLayout_8->addWidget(comboBox_5, 2, 1, 1, 1);

        comboBox_4 = new QComboBox(tab_6);
        QIcon icon7;
        icon7.addFile(QString::fromUtf8(":/Icons/data/icon-wide.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        comboBox_4->addItem(icon7, QString());
        comboBox_4->addItem(icon7, QString());
        comboBox_4->addItem(QString());
        comboBox_4->addItem(QString());
        comboBox_4->addItem(QString());
        comboBox_4->addItem(QString());
        comboBox_4->addItem(QString());
        comboBox_4->addItem(QString());
        comboBox_4->addItem(QString());
        comboBox_4->addItem(QString());
        comboBox_4->addItem(QString());
        comboBox_4->setObjectName("comboBox_4");
        comboBox_4->setEditable(true);
        comboBox_4->setIconSize(QSize(32, 16));
        comboBox_4->setFrame(false);

        gridLayout_8->addWidget(comboBox_4, 3, 0, 1, 1);

        comboBox_6 = new QComboBox(tab_6);
        comboBox_6->addItem(icon7, QString());
        comboBox_6->addItem(icon7, QString());
        comboBox_6->addItem(QString());
        comboBox_6->addItem(QString());
        comboBox_6->addItem(QString());
        comboBox_6->addItem(QString());
        comboBox_6->addItem(QString());
        comboBox_6->addItem(QString());
        comboBox_6->addItem(QString());
        comboBox_6->addItem(QString());
        comboBox_6->addItem(QString());
        comboBox_6->setObjectName("comboBox_6");
        comboBox_6->setEnabled(false);
        comboBox_6->setEditable(true);
        comboBox_6->setIconSize(QSize(32, 16));
        comboBox_6->setFrame(false);

        gridLayout_8->addWidget(comboBox_6, 3, 1, 1, 1);

        lineEdit = new QLineEdit(tab_6);
        lineEdit->setObjectName("lineEdit");
        lineEdit->setFrame(true);

        gridLayout_8->addWidget(lineEdit, 4, 0, 1, 1);

        lineEdit_3 = new QLineEdit(tab_6);
        lineEdit_3->setObjectName("lineEdit_3");
        lineEdit_3->setEnabled(false);
        lineEdit_3->setFrame(true);

        gridLayout_8->addWidget(lineEdit_3, 4, 1, 1, 1);

        lineEdit_2 = new QLineEdit(tab_6);
        lineEdit_2->setObjectName("lineEdit_2");
        lineEdit_2->setFrame(false);

        gridLayout_8->addWidget(lineEdit_2, 5, 0, 1, 1);

        lineEdit_4 = new QLineEdit(tab_6);
        lineEdit_4->setObjectName("lineEdit_4");
        lineEdit_4->setEnabled(false);
        lineEdit_4->setFrame(false);

        gridLayout_8->addWidget(lineEdit_4, 5, 1, 1, 1);

        spinBox = new QSpinBox(tab_6);
        spinBox->setObjectName("spinBox");

        gridLayout_8->addWidget(spinBox, 6, 0, 1, 1);

        spinBox_2 = new QSpinBox(tab_6);
        spinBox_2->setObjectName("spinBox_2");
        spinBox_2->setEnabled(false);

        gridLayout_8->addWidget(spinBox_2, 6, 1, 1, 1);

        dateTimeEdit_2 = new QDateTimeEdit(tab_6);
        dateTimeEdit_2->setObjectName("dateTimeEdit_2");
        dateTimeEdit_2->setEnabled(false);
        dateTimeEdit_2->setButtonSymbols(QAbstractSpinBox::PlusMinus);

        gridLayout_8->addWidget(dateTimeEdit_2, 7, 1, 1, 1);

        dateTimeEdit = new QDateTimeEdit(tab_6);
        dateTimeEdit->setObjectName("dateTimeEdit");
        dateTimeEdit->setButtonSymbols(QAbstractSpinBox::PlusMinus);

        gridLayout_8->addWidget(dateTimeEdit, 7, 0, 1, 1);


        gridLayout_9->addLayout(gridLayout_8, 1, 1, 1, 1);

        horizontalSpacer_7 = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_9->addItem(horizontalSpacer_7, 1, 2, 1, 1);

        verticalSpacer_9 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_9->addItem(verticalSpacer_9, 2, 1, 1, 1);

        tabWidget->addTab(tab_6, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        gridLayout_12 = new QGridLayout(tab_3);
        gridLayout_12->setObjectName("gridLayout_12");
        gridLayout_11 = new QGridLayout();
        gridLayout_11->setSpacing(5);
        gridLayout_11->setObjectName("gridLayout_11");
        progressBar_6 = new QProgressBar(tab_3);
        progressBar_6->setObjectName("progressBar_6");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(progressBar_6->sizePolicy().hasHeightForWidth());
        progressBar_6->setSizePolicy(sizePolicy1);
        progressBar_6->setMinimumSize(QSize(0, 100));
        progressBar_6->setValue(25);
        progressBar_6->setOrientation(Qt::Vertical);
        progressBar_6->setInvertedAppearance(true);

        gridLayout_11->addWidget(progressBar_6, 0, 2, 1, 3);

        progressBar_8 = new QProgressBar(tab_3);
        progressBar_8->setObjectName("progressBar_8");
        progressBar_8->setEnabled(true);
        sizePolicy1.setHeightForWidth(progressBar_8->sizePolicy().hasHeightForWidth());
        progressBar_8->setSizePolicy(sizePolicy1);
        progressBar_8->setMinimumSize(QSize(0, 100));
        progressBar_8->setMaximum(0);
        progressBar_8->setValue(-1);
        progressBar_8->setOrientation(Qt::Vertical);
        progressBar_8->setInvertedAppearance(true);

        gridLayout_11->addWidget(progressBar_8, 0, 12, 1, 1);

        progressBar_5 = new QProgressBar(tab_3);
        progressBar_5->setObjectName("progressBar_5");
        sizePolicy1.setHeightForWidth(progressBar_5->sizePolicy().hasHeightForWidth());
        progressBar_5->setSizePolicy(sizePolicy1);
        progressBar_5->setMinimumSize(QSize(0, 100));
        progressBar_5->setValue(25);
        progressBar_5->setOrientation(Qt::Vertical);

        gridLayout_11->addWidget(progressBar_5, 0, 1, 1, 1);

        progressBar_9 = new QProgressBar(tab_3);
        progressBar_9->setObjectName("progressBar_9");
        progressBar_9->setEnabled(false);
        sizePolicy1.setHeightForWidth(progressBar_9->sizePolicy().hasHeightForWidth());
        progressBar_9->setSizePolicy(sizePolicy1);
        progressBar_9->setMinimumSize(QSize(0, 100));
        progressBar_9->setValue(25);
        progressBar_9->setOrientation(Qt::Vertical);
        progressBar_9->setTextDirection(QProgressBar::BottomToTop);

        gridLayout_11->addWidget(progressBar_9, 0, 6, 1, 1, Qt::AlignRight);

        dial = new QDial(tab_3);
        dial->setObjectName("dial");
        dial->setMinimumSize(QSize(80, 80));
        dial->setMaximum(100);
        dial->setSliderPosition(25);
        dial->setNotchesVisible(true);

        gridLayout_11->addWidget(dial, 2, 6, 2, 2, Qt::AlignHCenter|Qt::AlignVCenter);

        progressBar_10 = new QProgressBar(tab_3);
        progressBar_10->setObjectName("progressBar_10");
        progressBar_10->setEnabled(false);
        sizePolicy1.setHeightForWidth(progressBar_10->sizePolicy().hasHeightForWidth());
        progressBar_10->setSizePolicy(sizePolicy1);
        progressBar_10->setMinimumSize(QSize(0, 100));
        progressBar_10->setValue(25);
        progressBar_10->setOrientation(Qt::Vertical);
        progressBar_10->setInvertedAppearance(true);
        progressBar_10->setTextDirection(QProgressBar::BottomToTop);

        gridLayout_11->addWidget(progressBar_10, 0, 7, 1, 1, Qt::AlignLeft);

        verticalSpacer_7 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_11->addItem(verticalSpacer_7, 1, 1, 1, 12);

        horizontalSpacer_21 = new QSpacerItem(5, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_11->addItem(horizontalSpacer_21, 2, 5, 2, 1);

        horizontalSpacer_22 = new QSpacerItem(5, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_11->addItem(horizontalSpacer_22, 2, 8, 2, 1);

        progressBar_7 = new QProgressBar(tab_3);
        progressBar_7->setObjectName("progressBar_7");
        sizePolicy1.setHeightForWidth(progressBar_7->sizePolicy().hasHeightForWidth());
        progressBar_7->setSizePolicy(sizePolicy1);
        progressBar_7->setMinimumSize(QSize(0, 100));
        progressBar_7->setMaximum(0);
        progressBar_7->setValue(-1);
        progressBar_7->setOrientation(Qt::Vertical);

        gridLayout_11->addWidget(progressBar_7, 0, 9, 1, 3, Qt::AlignRight);

        horizontalSpacer_15 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_11->addItem(horizontalSpacer_15, 0, 0, 1, 1);

        horizontalSpacer_20 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_11->addItem(horizontalSpacer_20, 0, 13, 1, 1);

        progressBar = new QProgressBar(tab_3);
        progressBar->setObjectName("progressBar");
        progressBar->setMinimum(0);
        progressBar->setMaximum(0);

        gridLayout_11->addWidget(progressBar, 2, 9, 1, 5, Qt::AlignBottom);

        progressBar_4 = new QProgressBar(tab_3);
        progressBar_4->setObjectName("progressBar_4");
        progressBar_4->setEnabled(true);
        progressBar_4->setMinimum(0);
        progressBar_4->setMaximum(0);
        progressBar_4->setInvertedAppearance(true);

        gridLayout_11->addWidget(progressBar_4, 3, 9, 1, 5, Qt::AlignTop);

        progressBar_2 = new QProgressBar(tab_3);
        progressBar_2->setObjectName("progressBar_2");
        progressBar_2->setValue(25);

        gridLayout_11->addWidget(progressBar_2, 2, 0, 1, 5, Qt::AlignBottom);

        progressBar_3 = new QProgressBar(tab_3);
        progressBar_3->setObjectName("progressBar_3");
        progressBar_3->setValue(25);
        progressBar_3->setInvertedAppearance(true);

        gridLayout_11->addWidget(progressBar_3, 3, 0, 1, 5, Qt::AlignTop);


        gridLayout_12->addLayout(gridLayout_11, 3, 1, 1, 1);

        horizontalSpacer_9 = new QSpacerItem(50, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_12->addItem(horizontalSpacer_9, 1, 0, 3, 1);

        gridLayout_10 = new QGridLayout();
        gridLayout_10->setObjectName("gridLayout_10");
        horizontalSlider = new QSlider(tab_3);
        horizontalSlider->setObjectName("horizontalSlider");
        horizontalSlider->setOrientation(Qt::Horizontal);
        horizontalSlider->setTickPosition(QSlider::TicksAbove);

        gridLayout_10->addWidget(horizontalSlider, 0, 0, 1, 4);

        horizontalSlider_2 = new QSlider(tab_3);
        horizontalSlider_2->setObjectName("horizontalSlider_2");
        horizontalSlider_2->setEnabled(false);
        horizontalSlider_2->setOrientation(Qt::Horizontal);
        horizontalSlider_2->setTickPosition(QSlider::TicksAbove);

        gridLayout_10->addWidget(horizontalSlider_2, 0, 6, 1, 4);

        verticalSlider = new QSlider(tab_3);
        verticalSlider->setObjectName("verticalSlider");
        verticalSlider->setOrientation(Qt::Vertical);
        verticalSlider->setTickPosition(QSlider::TicksBelow);

        gridLayout_10->addWidget(verticalSlider, 2, 2, 1, 1);

        verticalScrollBar = new QScrollBar(tab_3);
        verticalScrollBar->setObjectName("verticalScrollBar");
        verticalScrollBar->setOrientation(Qt::Vertical);

        gridLayout_10->addWidget(verticalScrollBar, 2, 3, 1, 1);

        verticalSlider_2 = new QSlider(tab_3);
        verticalSlider_2->setObjectName("verticalSlider_2");
        verticalSlider_2->setEnabled(false);
        verticalSlider_2->setOrientation(Qt::Vertical);
        verticalSlider_2->setTickPosition(QSlider::TicksBelow);

        gridLayout_10->addWidget(verticalSlider_2, 2, 8, 1, 1);

        verticalScrollBar_2 = new QScrollBar(tab_3);
        verticalScrollBar_2->setObjectName("verticalScrollBar_2");
        verticalScrollBar_2->setEnabled(false);
        verticalScrollBar_2->setOrientation(Qt::Vertical);

        gridLayout_10->addWidget(verticalScrollBar_2, 2, 9, 1, 1);

        horizontalScrollBar = new QScrollBar(tab_3);
        horizontalScrollBar->setObjectName("horizontalScrollBar");
        horizontalScrollBar->setOrientation(Qt::Horizontal);

        gridLayout_10->addWidget(horizontalScrollBar, 3, 0, 1, 3);

        horizontalScrollBar_2 = new QScrollBar(tab_3);
        horizontalScrollBar_2->setObjectName("horizontalScrollBar_2");
        horizontalScrollBar_2->setEnabled(false);
        horizontalScrollBar_2->setOrientation(Qt::Horizontal);

        gridLayout_10->addWidget(horizontalScrollBar_2, 3, 6, 1, 3);

        verticalSlider_4 = new QSlider(tab_3);
        verticalSlider_4->setObjectName("verticalSlider_4");
        verticalSlider_4->setEnabled(false);
        verticalSlider_4->setOrientation(Qt::Vertical);
        verticalSlider_4->setInvertedAppearance(true);
        verticalSlider_4->setTickPosition(QSlider::TicksAbove);

        gridLayout_10->addWidget(verticalSlider_4, 2, 7, 1, 1);

        verticalSlider_3 = new QSlider(tab_3);
        verticalSlider_3->setObjectName("verticalSlider_3");
        verticalSlider_3->setMinimumSize(QSize(0, 120));
        verticalSlider_3->setOrientation(Qt::Vertical);
        verticalSlider_3->setInvertedAppearance(true);
        verticalSlider_3->setTickPosition(QSlider::TicksAbove);

        gridLayout_10->addWidget(verticalSlider_3, 2, 1, 1, 1);

        horizontalSlider_3 = new QSlider(tab_3);
        horizontalSlider_3->setObjectName("horizontalSlider_3");
        horizontalSlider_3->setOrientation(Qt::Horizontal);
        horizontalSlider_3->setInvertedAppearance(true);
        horizontalSlider_3->setTickPosition(QSlider::TicksBelow);

        gridLayout_10->addWidget(horizontalSlider_3, 1, 0, 1, 4);

        horizontalSlider_4 = new QSlider(tab_3);
        horizontalSlider_4->setObjectName("horizontalSlider_4");
        horizontalSlider_4->setEnabled(false);
        horizontalSlider_4->setOrientation(Qt::Horizontal);
        horizontalSlider_4->setInvertedAppearance(true);
        horizontalSlider_4->setTickPosition(QSlider::TicksBelow);

        gridLayout_10->addWidget(horizontalSlider_4, 1, 6, 1, 4);

        verticalSlider_5 = new QSlider(tab_3);
        verticalSlider_5->setObjectName("verticalSlider_5");
        verticalSlider_5->setOrientation(Qt::Vertical);

        gridLayout_10->addWidget(verticalSlider_5, 0, 4, 3, 1);

        verticalSlider_6 = new QSlider(tab_3);
        verticalSlider_6->setObjectName("verticalSlider_6");
        verticalSlider_6->setEnabled(false);
        verticalSlider_6->setOrientation(Qt::Vertical);

        gridLayout_10->addWidget(verticalSlider_6, 0, 5, 3, 1);


        gridLayout_12->addLayout(gridLayout_10, 1, 1, 1, 1);

        horizontalSpacer_10 = new QSpacerItem(50, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_12->addItem(horizontalSpacer_10, 1, 2, 3, 1);

        verticalSpacer_11 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_12->addItem(verticalSpacer_11, 0, 1, 1, 1);

        verticalSpacer_12 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_12->addItem(verticalSpacer_12, 2, 1, 1, 1);

        verticalSpacer_13 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_12->addItem(verticalSpacer_13, 4, 1, 1, 1);

        tabWidget->addTab(tab_3, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName("tab_4");
        gridLayout_18 = new QGridLayout(tab_4);
        gridLayout_18->setObjectName("gridLayout_18");
        splitter_2 = new QSplitter(tab_4);
        splitter_2->setObjectName("splitter_2");
        splitter_2->setOrientation(Qt::Horizontal);
        splitter = new QSplitter(splitter_2);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Vertical);
        treeWidget = new QTreeWidget(splitter);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setIcon(1, icon6);
        __qtreewidgetitem->setIcon(0, icon4);
        treeWidget->setHeaderItem(__qtreewidgetitem);
        QTreeWidgetItem *__qtreewidgetitem1 = new QTreeWidgetItem(treeWidget);
        __qtreewidgetitem1->setCheckState(0, Qt::PartiallyChecked);
        QTreeWidgetItem *__qtreewidgetitem2 = new QTreeWidgetItem(treeWidget);
        new QTreeWidgetItem(__qtreewidgetitem2);
        new QTreeWidgetItem(__qtreewidgetitem2);
        QTreeWidgetItem *__qtreewidgetitem3 = new QTreeWidgetItem(treeWidget);
        __qtreewidgetitem3->setFlags(Qt::ItemIsSelectable|Qt::ItemIsEditable|Qt::ItemIsDragEnabled|Qt::ItemIsUserCheckable|Qt::ItemIsEnabled);
        __qtreewidgetitem3->setIcon(2, icon6);
        __qtreewidgetitem3->setIcon(0, icon4);
        new QTreeWidgetItem(__qtreewidgetitem3);
        new QTreeWidgetItem(__qtreewidgetitem3);
        QTreeWidgetItem *__qtreewidgetitem4 = new QTreeWidgetItem(__qtreewidgetitem3);
        __qtreewidgetitem4->setIcon(0, icon4);
        treeWidget->setObjectName("treeWidget");
        treeWidget->setSortingEnabled(true);
        splitter->addWidget(treeWidget);
        treeWidget->header()->setProperty("showSortIndicator", QVariant(true));
        listWidget = new QListWidget(splitter);
        QListWidgetItem *__qlistwidgetitem = new QListWidgetItem(listWidget);
        __qlistwidgetitem->setCheckState(Qt::Unchecked);
        __qlistwidgetitem->setIcon(icon4);
        __qlistwidgetitem->setFlags(Qt::ItemIsSelectable|Qt::ItemIsEditable|Qt::ItemIsDragEnabled|Qt::ItemIsUserCheckable|Qt::ItemIsEnabled);
        QListWidgetItem *__qlistwidgetitem1 = new QListWidgetItem(listWidget);
        __qlistwidgetitem1->setIcon(icon4);
        __qlistwidgetitem1->setFlags(Qt::ItemIsSelectable|Qt::ItemIsEditable|Qt::ItemIsDragEnabled|Qt::ItemIsUserCheckable|Qt::ItemIsEnabled);
        QListWidgetItem *__qlistwidgetitem2 = new QListWidgetItem(listWidget);
        __qlistwidgetitem2->setFlags(Qt::ItemIsSelectable|Qt::ItemIsEditable|Qt::ItemIsDragEnabled|Qt::ItemIsUserCheckable|Qt::ItemIsEnabled);
        listWidget->setObjectName("listWidget");
        listWidget->setViewMode(QListView::IconMode);
        splitter->addWidget(listWidget);
        mdiArea = new QMdiArea(splitter);
        mdiArea->setObjectName("mdiArea");
        subwindow = new QWidget();
        subwindow->setObjectName("subwindow");
        gridLayout_21 = new QGridLayout(subwindow);
        gridLayout_21->setObjectName("gridLayout_21");
        horizontalSpacer_16 = new QSpacerItem(227, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_21->addItem(horizontalSpacer_16, 1, 0, 1, 1);

        verticalSpacer_17 = new QSpacerItem(20, 100, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_21->addItem(verticalSpacer_17, 0, 0, 1, 1);

        mdiArea->addSubWindow(subwindow);
        splitter->addWidget(mdiArea);
        splitter_2->addWidget(splitter);
        layoutWidget = new QWidget(splitter_2);
        layoutWidget->setObjectName("layoutWidget");
        gridLayout_4 = new QGridLayout(layoutWidget);
        gridLayout_4->setObjectName("gridLayout_4");
        gridLayout_4->setContentsMargins(0, 0, 0, 0);
        frame_2 = new QFrame(layoutWidget);
        frame_2->setObjectName("frame_2");
        frame_2->setFrameShape(QFrame::Panel);
        frame_2->setFrameShadow(QFrame::Raised);
        gridLayout_17 = new QGridLayout(frame_2);
        gridLayout_17->setObjectName("gridLayout_17");
        label_5 = new QLabel(frame_2);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignCenter);
        label_5->setMargin(5);

        gridLayout_17->addWidget(label_5, 0, 0, 1, 1);


        gridLayout_4->addWidget(frame_2, 2, 1, 1, 1);

        groupBox_3 = new QGroupBox(layoutWidget);
        groupBox_3->setObjectName("groupBox_3");
        groupBox_3->setEnabled(false);
        groupBox_3->setCheckable(true);

        gridLayout_4->addWidget(groupBox_3, 3, 2, 1, 1);

        tabWidget_6 = new QTabWidget(layoutWidget);
        tabWidget_6->setObjectName("tabWidget_6");
        tabWidget_6->setEnabled(false);
        tabWidget_6->setTabsClosable(true);
        tab_15 = new QWidget();
        tab_15->setObjectName("tab_15");
        horizontalLayout_10 = new QHBoxLayout(tab_15);
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        label_16 = new QLabel(tab_15);
        label_16->setObjectName("label_16");

        horizontalLayout_10->addWidget(label_16, 0, Qt::AlignHCenter|Qt::AlignVCenter);

        tabWidget_6->addTab(tab_15, QString());
        tab_16 = new QWidget();
        tab_16->setObjectName("tab_16");
        horizontalLayout_11 = new QHBoxLayout(tab_16);
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        label_17 = new QLabel(tab_16);
        label_17->setObjectName("label_17");

        horizontalLayout_11->addWidget(label_17, 0, Qt::AlignHCenter|Qt::AlignVCenter);

        tabWidget_6->addTab(tab_16, icon4, QString());

        gridLayout_4->addWidget(tabWidget_6, 1, 2, 1, 1);

        tabWidget_5 = new QTabWidget(layoutWidget);
        tabWidget_5->setObjectName("tabWidget_5");
        tabWidget_5->setTabPosition(QTabWidget::South);
        tabWidget_5->setTabsClosable(true);
        tabWidget_5->setMovable(true);
        tab_13 = new QWidget();
        tab_13->setObjectName("tab_13");
        horizontalLayout_9 = new QHBoxLayout(tab_13);
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        label_12 = new QLabel(tab_13);
        label_12->setObjectName("label_12");

        horizontalLayout_9->addWidget(label_12, 0, Qt::AlignHCenter|Qt::AlignVCenter);

        tabWidget_5->addTab(tab_13, icon4, QString());
        tab_14 = new QWidget();
        tab_14->setObjectName("tab_14");
        horizontalLayout_6 = new QHBoxLayout(tab_14);
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        label_14 = new QLabel(tab_14);
        label_14->setObjectName("label_14");

        horizontalLayout_6->addWidget(label_14, 0, Qt::AlignHCenter|Qt::AlignVCenter);

        tabWidget_5->addTab(tab_14, QString());

        gridLayout_4->addWidget(tabWidget_5, 0, 1, 1, 1);

        stackedWidget = new QStackedWidget(layoutWidget);
        stackedWidget->setObjectName("stackedWidget");
        stackedWidget->setFrameShape(QFrame::Panel);
        stackedWidget->setFrameShadow(QFrame::Sunken);
        page_5 = new QWidget();
        page_5->setObjectName("page_5");
        gridLayout_14 = new QGridLayout(page_5);
        gridLayout_14->setObjectName("gridLayout_14");
        label_2 = new QLabel(page_5);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignCenter);

        gridLayout_14->addWidget(label_2, 0, 0, 1, 1);

        stackedWidget->addWidget(page_5);
        page_6 = new QWidget();
        page_6->setObjectName("page_6");
        gridLayout_15 = new QGridLayout(page_6);
        gridLayout_15->setObjectName("gridLayout_15");
        label_3 = new QLabel(page_6);
        label_3->setObjectName("label_3");

        gridLayout_15->addWidget(label_3, 0, 0, 1, 1);

        stackedWidget->addWidget(page_6);

        gridLayout_4->addWidget(stackedWidget, 2, 2, 1, 1);

        groupBox = new QGroupBox(layoutWidget);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        label_6 = new QLabel(groupBox);
        label_6->setObjectName("label_6");
        label_6->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_6, 0, 0, 1, 1);


        gridLayout_4->addWidget(groupBox, 3, 0, 1, 1);

        tableWidget = new QTableWidget(layoutWidget);
        if (tableWidget->columnCount() < 2)
            tableWidget->setColumnCount(2);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        __qtablewidgetitem->setIcon(icon6);
        tableWidget->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        if (tableWidget->rowCount() < 2)
            tableWidget->setRowCount(2);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        tableWidget->setVerticalHeaderItem(0, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        tableWidget->setVerticalHeaderItem(1, __qtablewidgetitem3);
        QTableWidgetItem *__qtablewidgetitem4 = new QTableWidgetItem();
        __qtablewidgetitem4->setTextAlignment(Qt::AlignCenter);
        tableWidget->setItem(0, 0, __qtablewidgetitem4);
        QTableWidgetItem *__qtablewidgetitem5 = new QTableWidgetItem();
        __qtablewidgetitem5->setTextAlignment(Qt::AlignCenter);
        tableWidget->setItem(0, 1, __qtablewidgetitem5);
        QTableWidgetItem *__qtablewidgetitem6 = new QTableWidgetItem();
        __qtablewidgetitem6->setTextAlignment(Qt::AlignCenter);
        tableWidget->setItem(1, 0, __qtablewidgetitem6);
        QTableWidgetItem *__qtablewidgetitem7 = new QTableWidgetItem();
        __qtablewidgetitem7->setTextAlignment(Qt::AlignCenter);
        tableWidget->setItem(1, 1, __qtablewidgetitem7);
        tableWidget->setObjectName("tableWidget");
        tableWidget->setSortingEnabled(true);
        tableWidget->horizontalHeader()->setProperty("showSortIndicator", QVariant(true));

        gridLayout_4->addWidget(tableWidget, 4, 0, 1, 1);

        dockWidget = new QDockWidget(layoutWidget);
        dockWidget->setObjectName("dockWidget");
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName("dockWidgetContents");
        dockWidget->setWidget(dockWidgetContents);

        gridLayout_4->addWidget(dockWidget, 0, 2, 1, 1);

        groupBox_2 = new QGroupBox(layoutWidget);
        groupBox_2->setObjectName("groupBox_2");
        groupBox_2->setCheckable(true);
        gridLayout_19 = new QGridLayout(groupBox_2);
        gridLayout_19->setObjectName("gridLayout_19");
        label_8 = new QLabel(groupBox_2);
        label_8->setObjectName("label_8");
        label_8->setAlignment(Qt::AlignCenter);

        gridLayout_19->addWidget(label_8, 0, 0, 1, 1);


        gridLayout_4->addWidget(groupBox_2, 3, 1, 1, 1);

        toolBox = new QToolBox(layoutWidget);
        toolBox->setObjectName("toolBox");
        page = new QWidget();
        page->setObjectName("page");
        page->setGeometry(QRect(0, 0, 171, 72));
        verticalLayout = new QVBoxLayout(page);
        verticalLayout->setObjectName("verticalLayout");
        label_18 = new QLabel(page);
        label_18->setObjectName("label_18");
        label_18->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(label_18);

        toolBox->addItem(page, icon4, QString::fromUtf8("Page 1"));
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        page_2->setGeometry(QRect(0, 0, 92, 22));
        toolBox->addItem(page_2, icon6, QString::fromUtf8("Page 2"));

        gridLayout_4->addWidget(toolBox, 4, 1, 1, 1);

        toolBox_2 = new QToolBox(layoutWidget);
        toolBox_2->setObjectName("toolBox_2");
        toolBox_2->setEnabled(false);
        page_3 = new QWidget();
        page_3->setObjectName("page_3");
        page_3->setGeometry(QRect(0, 0, 92, 22));
        toolBox_2->addItem(page_3, icon4, QString::fromUtf8("Page 1"));
        page_4 = new QWidget();
        page_4->setObjectName("page_4");
        page_4->setGeometry(QRect(0, 0, 171, 72));
        toolBox_2->addItem(page_4, QString::fromUtf8("Page 2"));

        gridLayout_4->addWidget(toolBox_2, 4, 2, 1, 1);

        tabWidget_2 = new QTabWidget(layoutWidget);
        tabWidget_2->setObjectName("tabWidget_2");
        tabWidget_2->setMinimumSize(QSize(0, 100));
        tabWidget_2->setTabsClosable(true);
        tabWidget_2->setMovable(true);
        tab_7 = new QWidget();
        tab_7->setObjectName("tab_7");
        horizontalLayout_2 = new QHBoxLayout(tab_7);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        checkBoxDocMode = new QCheckBox(tab_7);
        checkBoxDocMode->setObjectName("checkBoxDocMode");

        horizontalLayout_2->addWidget(checkBoxDocMode, 0, Qt::AlignHCenter|Qt::AlignVCenter);

        tabWidget_2->addTab(tab_7, icon6, QString());
        tab_8 = new QWidget();
        tab_8->setObjectName("tab_8");
        horizontalLayout_3 = new QHBoxLayout(tab_8);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_9 = new QLabel(tab_8);
        label_9->setObjectName("label_9");

        horizontalLayout_3->addWidget(label_9, 0, Qt::AlignHCenter|Qt::AlignVCenter);

        tabWidget_2->addTab(tab_8, icon4, QString());

        gridLayout_4->addWidget(tabWidget_2, 0, 0, 1, 1);

        frame = new QFrame(layoutWidget);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::Box);
        frame->setFrameShadow(QFrame::Raised);
        gridLayout_16 = new QGridLayout(frame);
        gridLayout_16->setObjectName("gridLayout_16");
        label_4 = new QLabel(frame);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignCenter);
        label_4->setMargin(5);

        gridLayout_16->addWidget(label_4, 0, 0, 1, 1);


        gridLayout_4->addWidget(frame, 2, 0, 1, 1);

        tabWidget_3 = new QTabWidget(layoutWidget);
        tabWidget_3->setObjectName("tabWidget_3");
        tabWidget_3->setTabPosition(QTabWidget::West);
        tabWidget_3->setTabsClosable(true);
        tabWidget_3->setMovable(true);
        tab_9 = new QWidget();
        tab_9->setObjectName("tab_9");
        horizontalLayout_4 = new QHBoxLayout(tab_9);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        label_10 = new QLabel(tab_9);
        label_10->setObjectName("label_10");

        horizontalLayout_4->addWidget(label_10, 0, Qt::AlignHCenter|Qt::AlignVCenter);

        tabWidget_3->addTab(tab_9, icon4, QString());
        tab_10 = new QWidget();
        tab_10->setObjectName("tab_10");
        horizontalLayout_5 = new QHBoxLayout(tab_10);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        label_11 = new QLabel(tab_10);
        label_11->setObjectName("label_11");

        horizontalLayout_5->addWidget(label_11, 0, Qt::AlignHCenter|Qt::AlignVCenter);

        tabWidget_3->addTab(tab_10, QString());

        gridLayout_4->addWidget(tabWidget_3, 1, 0, 1, 1);

        tabWidget_4 = new QTabWidget(layoutWidget);
        tabWidget_4->setObjectName("tabWidget_4");
        tabWidget_4->setTabPosition(QTabWidget::East);
        tabWidget_4->setTabsClosable(true);
        tabWidget_4->setMovable(true);
        tab_12 = new QWidget();
        tab_12->setObjectName("tab_12");
        horizontalLayout_8 = new QHBoxLayout(tab_12);
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        label_15 = new QLabel(tab_12);
        label_15->setObjectName("label_15");

        horizontalLayout_8->addWidget(label_15, 0, Qt::AlignHCenter|Qt::AlignVCenter);

        tabWidget_4->addTab(tab_12, icon4, QString());
        tab_11 = new QWidget();
        tab_11->setObjectName("tab_11");
        horizontalLayout_7 = new QHBoxLayout(tab_11);
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        label_13 = new QLabel(tab_11);
        label_13->setObjectName("label_13");

        horizontalLayout_7->addWidget(label_13, 0, Qt::AlignHCenter|Qt::AlignVCenter);

        tabWidget_4->addTab(tab_11, QString());

        gridLayout_4->addWidget(tabWidget_4, 1, 1, 1, 1);

        splitter_2->addWidget(layoutWidget);

        gridLayout_18->addWidget(splitter_2, 0, 0, 1, 1);

        tabWidget->addTab(tab_4, QString());
        KvantumPreviewBase->setCentralWidget(tabWidget);
        menubar = new QMenuBar(KvantumPreviewBase);
        menubar->setObjectName("menubar");
        menubar->setGeometry(QRect(0, 0, 800, 21));
        menuFile = new QMenu(menubar);
        menuFile->setObjectName("menuFile");
        menuFile->setTearOffEnabled(true);
        menuSubmenu = new QMenu(menuFile);
        menuSubmenu->setObjectName("menuSubmenu");
        KvantumPreviewBase->setMenuBar(menubar);
        statusbar = new QStatusBar(KvantumPreviewBase);
        statusbar->setObjectName("statusbar");
        KvantumPreviewBase->setStatusBar(statusbar);
        toolBar = new QToolBar(KvantumPreviewBase);
        toolBar->setObjectName("toolBar");
        toolBar->setMovable(true);
        toolBar->setToolButtonStyle(Qt::ToolButtonFollowStyle);
        KvantumPreviewBase->addToolBar(Qt::ToolBarArea::TopToolBarArea, toolBar);
        toolBar_2 = new QToolBar(KvantumPreviewBase);
        toolBar_2->setObjectName("toolBar_2");
        toolBar_2->setMovable(true);
        toolBar_2->setToolButtonStyle(Qt::ToolButtonFollowStyle);
        KvantumPreviewBase->addToolBar(Qt::ToolBarArea::TopToolBarArea, toolBar_2);

        menubar->addAction(menuFile->menuAction());
        menuFile->addAction(actionDocMode);
        menuFile->addSeparator();
        menuFile->addAction(actionMenu_Item);
        menuFile->addAction(actionNew_Item);
        menuFile->addAction(menuSubmenu->menuAction());
        menuFile->addSeparator();
        menuFile->addAction(actionQuit);
        menuSubmenu->addAction(actionDocMode);
        menuSubmenu->addSeparator();
        menuSubmenu->addAction(actionMenu_radio);
        menuSubmenu->addAction(actionMenu_radio1);
        toolBar->addAction(actionQuit);
        toolBar->addSeparator();
        toolBar->addAction(actionTest);
        toolBar_2->addAction(actionDocMode);
        toolBar_2->addAction(actionMenuButton);

        retranslateUi(KvantumPreviewBase);
        QObject::connect(pushButton_4, &QPushButton::toggled, pushButton_11, &QPushButton::setChecked);
        QObject::connect(toolButton_3, &QToolButton::toggled, toolButton_12, &QToolButton::setChecked);
        QObject::connect(spinBox, &QSpinBox::valueChanged, spinBox_2, &QSpinBox::setValue);
        QObject::connect(comboBox, &QComboBox::currentIndexChanged, comboBox_7, &QComboBox::setCurrentIndex);
        QObject::connect(comboBox_3, &QComboBox::currentIndexChanged, comboBox_8, &QComboBox::setCurrentIndex);
        QObject::connect(comboBox_2, &QComboBox::currentIndexChanged, comboBox_5, &QComboBox::setCurrentIndex);
        QObject::connect(comboBox_4, &QComboBox::currentIndexChanged, comboBox_6, &QComboBox::setCurrentIndex);
        QObject::connect(lineEdit, &QLineEdit::textChanged, lineEdit_3, &QLineEdit::setText);
        QObject::connect(lineEdit_2, &QLineEdit::textChanged, lineEdit_4, &QLineEdit::setText);
        QObject::connect(tabWidget_2, &QTabWidget::currentChanged, tabWidget_6, &QTabWidget::setCurrentIndex);
        QObject::connect(toolBox, &QToolBox::currentChanged, toolBox_2, &QToolBox::setCurrentIndex);
        QObject::connect(groupBox_2, &QGroupBox::toggled, groupBox_3, &QGroupBox::setChecked);
        QObject::connect(horizontalSlider, &QSlider::valueChanged, horizontalSlider_2, &QSlider::setValue);
        QObject::connect(verticalSlider, &QSlider::valueChanged, verticalSlider_2, &QSlider::setValue);
        QObject::connect(verticalScrollBar, &QScrollBar::valueChanged, verticalScrollBar_2, &QScrollBar::setValue);
        QObject::connect(horizontalScrollBar, &QScrollBar::valueChanged, horizontalScrollBar_2, &QScrollBar::setValue);
        QObject::connect(radioButton, &QRadioButton::toggled, radioButton_5, &QRadioButton::setChecked);
        QObject::connect(radioButton_3, &QRadioButton::toggled, radioButton_4, &QRadioButton::setChecked);
        QObject::connect(radioButton_2, &QRadioButton::toggled, radioButton_6, &QRadioButton::setChecked);
        QObject::connect(checkBox, &QCheckBox::toggled, checkBox_4, &QCheckBox::setChecked);
        QObject::connect(checkBox_2, &QCheckBox::toggled, checkBox_5, &QCheckBox::setChecked);
        QObject::connect(checkBox_3, &QCheckBox::toggled, checkBox_6, &QCheckBox::setChecked);
        QObject::connect(horizontalSlider, &QSlider::valueChanged, horizontalSlider_3, &QSlider::setValue);
        QObject::connect(horizontalSlider, &QSlider::valueChanged, horizontalSlider_4, &QSlider::setValue);
        QObject::connect(verticalSlider, &QSlider::valueChanged, verticalSlider_3, &QSlider::setValue);
        QObject::connect(verticalSlider, &QSlider::valueChanged, verticalSlider_4, &QSlider::setValue);
        QObject::connect(verticalSlider_3, &QSlider::valueChanged, verticalSlider, &QSlider::setValue);
        QObject::connect(horizontalSlider_3, &QSlider::valueChanged, horizontalSlider, &QSlider::setValue);
        QObject::connect(dateTimeEdit, &QDateTimeEdit::dateTimeChanged, dateTimeEdit_2, &QDateTimeEdit::setDateTime);
        QObject::connect(actionQuit, &QAction::triggered, KvantumPreviewBase, qOverload<>(&QMainWindow::close));
        QObject::connect(dial, &QDial::valueChanged, progressBar_2, &QProgressBar::setValue);
        QObject::connect(dial, &QDial::valueChanged, progressBar_3, &QProgressBar::setValue);
        QObject::connect(dial, &QDial::valueChanged, progressBar_5, &QProgressBar::setValue);
        QObject::connect(dial, &QDial::valueChanged, progressBar_6, &QProgressBar::setValue);
        QObject::connect(dial, &QDial::valueChanged, progressBar_9, &QProgressBar::setValue);
        QObject::connect(dial, &QDial::valueChanged, progressBar_10, &QProgressBar::setValue);
        QObject::connect(toolButton_8, &QToolButton::toggled, toolButton_11, &QToolButton::setChecked);
        QObject::connect(verticalSlider_5, &QSlider::valueChanged, verticalSlider_6, &QSlider::setValue);

        tabWidget->setCurrentIndex(0);
        pushButton_5->setDefault(true);
        pushButton_6->setDefault(true);
        tabWidget_6->setCurrentIndex(0);
        tabWidget_5->setCurrentIndex(0);
        stackedWidget->setCurrentIndex(0);
        toolBox->setCurrentIndex(0);
        toolBox_2->setCurrentIndex(0);
        tabWidget_2->setCurrentIndex(0);
        tabWidget_3->setCurrentIndex(0);
        tabWidget_4->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(KvantumPreviewBase);
    } // setupUi

    void retranslateUi(QMainWindow *KvantumPreviewBase)
    {
        KvantumPreviewBase->setWindowTitle(QCoreApplication::translate("KvantumPreviewBase", "Kvantum Preview", nullptr));
        actionQuit->setText(QCoreApplication::translate("KvantumPreviewBase", "&Quit", nullptr));
#if QT_CONFIG(tooltip)
        actionQuit->setToolTip(QCoreApplication::translate("KvantumPreviewBase", "Quit", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(shortcut)
        actionQuit->setShortcut(QCoreApplication::translate("KvantumPreviewBase", "Ctrl+Q", nullptr));
#endif // QT_CONFIG(shortcut)
        actionMenu_Item->setText(QCoreApplication::translate("KvantumPreviewBase", "&Checkbox", nullptr));
        actionTest->setText(QCoreApplication::translate("KvantumPreviewBase", "Toggle Layout", nullptr));
#if QT_CONFIG(tooltip)
        actionTest->setToolTip(QCoreApplication::translate("KvantumPreviewBase", "Toggle layout direction", nullptr));
#endif // QT_CONFIG(tooltip)
        actionDocMode->setText(QCoreApplication::translate("KvantumPreviewBase", "&Doc Mode", nullptr));
#if QT_CONFIG(tooltip)
        actionDocMode->setToolTip(QCoreApplication::translate("KvantumPreviewBase", "Show tabs in the document mode", nullptr));
#endif // QT_CONFIG(tooltip)
        actionMenuButton->setText(QCoreApplication::translate("KvantumPreviewBase", "Menu Button", nullptr));
#if QT_CONFIG(tooltip)
        actionMenuButton->setToolTip(QCoreApplication::translate("KvantumPreviewBase", "Hold pressed to show a menu", nullptr));
#endif // QT_CONFIG(tooltip)
        actionNew_Item->setText(QCoreApplication::translate("KvantumPreviewBase", "C&heckbox", nullptr));
        actionMenu_radio->setText(QCoreApplication::translate("KvantumPreviewBase", "&Radio button", nullptr));
        actionMenu_radio1->setText(QCoreApplication::translate("KvantumPreviewBase", "Radio &button", nullptr));
        pushButton_7->setText(QCoreApplication::translate("KvantumPreviewBase", "Toggle\n"
"push\n"
"button\n"
"\n"
"with\n"
"height\n"
"greater\n"
"than\n"
"width", nullptr));
        pushButton->setText(QCoreApplication::translate("KvantumPreviewBase", "Simple push button", nullptr));
        pushButton_9->setText(QCoreApplication::translate("KvantumPreviewBase", "Simple push button", nullptr));
        pushButton_4->setText(QCoreApplication::translate("KvantumPreviewBase", "Toggle push button", nullptr));
        pushButton_11->setText(QCoreApplication::translate("KvantumPreviewBase", "Toggle push button", nullptr));
        pushButton_2->setText(QCoreApplication::translate("KvantumPreviewBase", "Multi-line\n"
" push button", nullptr));
        pushButton_10->setText(QCoreApplication::translate("KvantumPreviewBase", "Multi-line\n"
" push button", nullptr));
        pushButton_3->setText(QCoreApplication::translate("KvantumPreviewBase", "Push button\n"
"with 32px folder icon", nullptr));
        pushButton_12->setText(QCoreApplication::translate("KvantumPreviewBase", "Push button\n"
"with 32px folder icon", nullptr));
        pushButton_5->setText(QCoreApplication::translate("KvantumPreviewBase", "Default\n"
"push button", nullptr));
        pushButton_6->setText(QCoreApplication::translate("KvantumPreviewBase", "Default\n"
"push button", nullptr));
        checkBoxFlat->setText(QCoreApplication::translate("KvantumPreviewBase", "Flat buttons", nullptr));
        label_7->setText(QCoreApplication::translate("KvantumPreviewBase", "Button Box", nullptr));
        pushButton_8->setText(QCoreApplication::translate("KvantumPreviewBase", "Push button with menu", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), QCoreApplication::translate("KvantumPreviewBase", "Push buttons", nullptr));
        toolButton->setText(QCoreApplication::translate("KvantumPreviewBase", "Simple toolbutton", nullptr));
        toolButton_17->setText(QCoreApplication::translate("KvantumPreviewBase", "Toggle\n"
"tool\n"
"button\n"
"\n"
"with\n"
"height\n"
"greater\n"
"than\n"
"width", nullptr));
        toolButton_16->setText(QCoreApplication::translate("KvantumPreviewBase", "Simple toolbutton", nullptr));
        toolButton_2->setText(QCoreApplication::translate("KvantumPreviewBase", "Multi-line\n"
"toolbutton", nullptr));
        toolButton_15->setText(QCoreApplication::translate("KvantumPreviewBase", "Multi-line\n"
"toolbutton", nullptr));
        toolButton_3->setText(QCoreApplication::translate("KvantumPreviewBase", "Toggle toolbutton\n"
"with an arrow", nullptr));
        toolButton_12->setText(QCoreApplication::translate("KvantumPreviewBase", "Toggle toolbutton\n"
"with an arrow", nullptr));
        toolButton_4->setText(QCoreApplication::translate("KvantumPreviewBase", "Toolbutton with 32px PNG icon\n"
"beside text", nullptr));
        toolButton_9->setText(QCoreApplication::translate("KvantumPreviewBase", "Toolbutton with 32px PNG icon\n"
"beside text", nullptr));
        toolButton_5->setText(QCoreApplication::translate("KvantumPreviewBase", "Toolbutton with 32px SVG icon\n"
"and text below", nullptr));
        toolButton_14->setText(QCoreApplication::translate("KvantumPreviewBase", "Toolbutton with 32px SVG icon\n"
"and text below", nullptr));
        toolButton_6->setText(QCoreApplication::translate("KvantumPreviewBase", "Toolbutton with text below\n"
"and arrow", nullptr));
        toolButton_13->setText(QCoreApplication::translate("KvantumPreviewBase", "Toolbutton with text below\n"
"and arrow", nullptr));
        toolButton_7->setText(QCoreApplication::translate("KvantumPreviewBase", "Toolbutton with icon at the side\n"
"and arrow", nullptr));
        toolButton_10->setText(QCoreApplication::translate("KvantumPreviewBase", "Toolbutton with icon at the side\n"
"and arrow", nullptr));
        toolButton_8->setText(QCoreApplication::translate("KvantumPreviewBase", "Toggle toolbutton with icon,\n"
"ordinary arrow\n"
"and dropdown menu arrow", nullptr));
        toolButton_11->setText(QCoreApplication::translate("KvantumPreviewBase", "Toggle toolbutton with icon,\n"
"ordinary arrow\n"
"and dropdown menu arrow", nullptr));
        checkBoxRaise->setText(QCoreApplication::translate("KvantumPreviewBase", "Auto-raise", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), QCoreApplication::translate("KvantumPreviewBase", "Tool buttons", nullptr));
        radioButton->setText(QCoreApplication::translate("KvantumPreviewBase", "Simple radio button", nullptr));
        radioButton_5->setText(QCoreApplication::translate("KvantumPreviewBase", "Simple radio button", nullptr));
        radioButton_3->setText(QCoreApplication::translate("KvantumPreviewBase", "Multi-line\n"
"radio button", nullptr));
        radioButton_4->setText(QCoreApplication::translate("KvantumPreviewBase", "Multi-line\n"
"radio button", nullptr));
        radioButton_2->setText(QCoreApplication::translate("KvantumPreviewBase", "Radio button with 32px SVG icon", nullptr));
        radioButton_6->setText(QCoreApplication::translate("KvantumPreviewBase", "Radio button with 32px SVG icon", nullptr));
        checkBox->setText(QCoreApplication::translate("KvantumPreviewBase", "Simple check box", nullptr));
        checkBox_4->setText(QCoreApplication::translate("KvantumPreviewBase", "Simple check box", nullptr));
        checkBox_2->setText(QCoreApplication::translate("KvantumPreviewBase", "Multi-line\n"
"check box", nullptr));
        checkBox_5->setText(QCoreApplication::translate("KvantumPreviewBase", "Multi-line\n"
"check box", nullptr));
        checkBox_7->setText(QCoreApplication::translate("KvantumPreviewBase", "Tri-state check box", nullptr));
        checkBox_8->setText(QCoreApplication::translate("KvantumPreviewBase", "Tri-state check box", nullptr));
        checkBox_3->setText(QCoreApplication::translate("KvantumPreviewBase", "Check box with icon", nullptr));
        checkBox_6->setText(QCoreApplication::translate("KvantumPreviewBase", "Check box with icon", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_5), QCoreApplication::translate("KvantumPreviewBase", "Radio/Check buttons", nullptr));
        comboBox->setItemText(0, QCoreApplication::translate("KvantumPreviewBase", "Standard combo box", nullptr));
        comboBox->setItemText(1, QCoreApplication::translate("KvantumPreviewBase", "Standard combo box 1", nullptr));
        comboBox->setItemText(2, QCoreApplication::translate("KvantumPreviewBase", "Standard combo box 2", nullptr));
        comboBox->setItemText(3, QCoreApplication::translate("KvantumPreviewBase", "Standard combo box 3", nullptr));
        comboBox->setItemText(4, QCoreApplication::translate("KvantumPreviewBase", "Standard combo box 4", nullptr));

        comboBox_7->setItemText(0, QCoreApplication::translate("KvantumPreviewBase", "Standard combo box", nullptr));
        comboBox_7->setItemText(1, QCoreApplication::translate("KvantumPreviewBase", "Standard combo box 1", nullptr));
        comboBox_7->setItemText(2, QCoreApplication::translate("KvantumPreviewBase", "Standard combo box 2", nullptr));
        comboBox_7->setItemText(3, QCoreApplication::translate("KvantumPreviewBase", "Standard combo box 3", nullptr));
        comboBox_7->setItemText(4, QCoreApplication::translate("KvantumPreviewBase", "Standard combo box 4", nullptr));

        comboBox_3->setItemText(0, QCoreApplication::translate("KvantumPreviewBase", "Frameless (no difference)", nullptr));
        comboBox_3->setItemText(1, QCoreApplication::translate("KvantumPreviewBase", "Frameless 1", nullptr));
        comboBox_3->setItemText(2, QCoreApplication::translate("KvantumPreviewBase", "Frameless 2", nullptr));
        comboBox_3->setItemText(3, QCoreApplication::translate("KvantumPreviewBase", "Frameless 3", nullptr));
        comboBox_3->setItemText(4, QCoreApplication::translate("KvantumPreviewBase", "Frameless 4", nullptr));
        comboBox_3->setItemText(5, QCoreApplication::translate("KvantumPreviewBase", "Frameless 5", nullptr));
        comboBox_3->setItemText(6, QCoreApplication::translate("KvantumPreviewBase", "Frameless 6", nullptr));
        comboBox_3->setItemText(7, QCoreApplication::translate("KvantumPreviewBase", "Frameless 7", nullptr));
        comboBox_3->setItemText(8, QCoreApplication::translate("KvantumPreviewBase", "Frameless 8", nullptr));
        comboBox_3->setItemText(9, QCoreApplication::translate("KvantumPreviewBase", "Frameless 9", nullptr));
        comboBox_3->setItemText(10, QCoreApplication::translate("KvantumPreviewBase", "Frameless 10", nullptr));

        comboBox_8->setItemText(0, QCoreApplication::translate("KvantumPreviewBase", "Frameless (no difference)", nullptr));
        comboBox_8->setItemText(1, QCoreApplication::translate("KvantumPreviewBase", "Frameless 1", nullptr));
        comboBox_8->setItemText(2, QCoreApplication::translate("KvantumPreviewBase", "Frameless 2", nullptr));
        comboBox_8->setItemText(3, QCoreApplication::translate("KvantumPreviewBase", "Frameless 3", nullptr));
        comboBox_8->setItemText(4, QCoreApplication::translate("KvantumPreviewBase", "Frameless 4", nullptr));
        comboBox_8->setItemText(5, QCoreApplication::translate("KvantumPreviewBase", "Frameless 5", nullptr));
        comboBox_8->setItemText(6, QCoreApplication::translate("KvantumPreviewBase", "Frameless 6", nullptr));
        comboBox_8->setItemText(7, QCoreApplication::translate("KvantumPreviewBase", "Frameless 7", nullptr));
        comboBox_8->setItemText(8, QCoreApplication::translate("KvantumPreviewBase", "Frameless 8", nullptr));
        comboBox_8->setItemText(9, QCoreApplication::translate("KvantumPreviewBase", "Frameless 9", nullptr));
        comboBox_8->setItemText(10, QCoreApplication::translate("KvantumPreviewBase", "Frameless 10", nullptr));

        comboBox_2->setItemText(0, QCoreApplication::translate("KvantumPreviewBase", "Editable combo box", nullptr));
        comboBox_2->setItemText(1, QCoreApplication::translate("KvantumPreviewBase", "Editable combo box 1", nullptr));
        comboBox_2->setItemText(2, QCoreApplication::translate("KvantumPreviewBase", "Editable combo box 2", nullptr));
        comboBox_2->setItemText(3, QCoreApplication::translate("KvantumPreviewBase", "Editable combo box 3", nullptr));
        comboBox_2->setItemText(4, QCoreApplication::translate("KvantumPreviewBase", "Editable combo box 4", nullptr));

        comboBox_5->setItemText(0, QCoreApplication::translate("KvantumPreviewBase", "Editable combo box", nullptr));
        comboBox_5->setItemText(1, QCoreApplication::translate("KvantumPreviewBase", "Editable combo box 1", nullptr));
        comboBox_5->setItemText(2, QCoreApplication::translate("KvantumPreviewBase", "Editable combo box 2", nullptr));
        comboBox_5->setItemText(3, QCoreApplication::translate("KvantumPreviewBase", "Editable combo box 3", nullptr));
        comboBox_5->setItemText(4, QCoreApplication::translate("KvantumPreviewBase", "Editable combo box 4", nullptr));

        comboBox_4->setItemText(0, QCoreApplication::translate("KvantumPreviewBase", "Frameless (no difference)", nullptr));
        comboBox_4->setItemText(1, QCoreApplication::translate("KvantumPreviewBase", "Frameless 1", nullptr));
        comboBox_4->setItemText(2, QCoreApplication::translate("KvantumPreviewBase", "Frameless 2", nullptr));
        comboBox_4->setItemText(3, QCoreApplication::translate("KvantumPreviewBase", "Frameless 3", nullptr));
        comboBox_4->setItemText(4, QCoreApplication::translate("KvantumPreviewBase", "Frameless 4", nullptr));
        comboBox_4->setItemText(5, QCoreApplication::translate("KvantumPreviewBase", "Frameless 5", nullptr));
        comboBox_4->setItemText(6, QCoreApplication::translate("KvantumPreviewBase", "Frameless 6", nullptr));
        comboBox_4->setItemText(7, QCoreApplication::translate("KvantumPreviewBase", "Frameless 7", nullptr));
        comboBox_4->setItemText(8, QCoreApplication::translate("KvantumPreviewBase", "Frameless 8", nullptr));
        comboBox_4->setItemText(9, QCoreApplication::translate("KvantumPreviewBase", "Frameless 9", nullptr));
        comboBox_4->setItemText(10, QCoreApplication::translate("KvantumPreviewBase", "Frameless 10", nullptr));

        comboBox_6->setItemText(0, QCoreApplication::translate("KvantumPreviewBase", "Frameless (no difference)", nullptr));
        comboBox_6->setItemText(1, QCoreApplication::translate("KvantumPreviewBase", "Frameless 1", nullptr));
        comboBox_6->setItemText(2, QCoreApplication::translate("KvantumPreviewBase", "Frameless 2", nullptr));
        comboBox_6->setItemText(3, QCoreApplication::translate("KvantumPreviewBase", "Frameless 3", nullptr));
        comboBox_6->setItemText(4, QCoreApplication::translate("KvantumPreviewBase", "Frameless 4", nullptr));
        comboBox_6->setItemText(5, QCoreApplication::translate("KvantumPreviewBase", "Frameless 5", nullptr));
        comboBox_6->setItemText(6, QCoreApplication::translate("KvantumPreviewBase", "Frameless 6", nullptr));
        comboBox_6->setItemText(7, QCoreApplication::translate("KvantumPreviewBase", "Frameless 7", nullptr));
        comboBox_6->setItemText(8, QCoreApplication::translate("KvantumPreviewBase", "Frameless 8", nullptr));
        comboBox_6->setItemText(9, QCoreApplication::translate("KvantumPreviewBase", "Frameless 9", nullptr));
        comboBox_6->setItemText(10, QCoreApplication::translate("KvantumPreviewBase", "Frameless 10", nullptr));

        lineEdit->setText(QCoreApplication::translate("KvantumPreviewBase", "Line-edit", nullptr));
        lineEdit_3->setText(QCoreApplication::translate("KvantumPreviewBase", "Line-edit", nullptr));
        lineEdit_2->setText(QCoreApplication::translate("KvantumPreviewBase", "Frameless (no difference)", nullptr));
        lineEdit_4->setText(QCoreApplication::translate("KvantumPreviewBase", "Frameless (no difference)", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_6), QCoreApplication::translate("KvantumPreviewBase", "Combos/Spins/Inputs", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), QCoreApplication::translate("KvantumPreviewBase", "Sliders/Scrolls/Progress/Dial", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = treeWidget->headerItem();
        ___qtreewidgetitem->setText(2, QCoreApplication::translate("KvantumPreviewBase", "Header 3", nullptr));
        ___qtreewidgetitem->setText(1, QCoreApplication::translate("KvantumPreviewBase", "Header 2", nullptr));
        ___qtreewidgetitem->setText(0, QCoreApplication::translate("KvantumPreviewBase", "Header 1", nullptr));

        const bool __sortingEnabled = treeWidget->isSortingEnabled();
        treeWidget->setSortingEnabled(false);
        QTreeWidgetItem *___qtreewidgetitem1 = treeWidget->topLevelItem(0);
        ___qtreewidgetitem1->setText(0, QCoreApplication::translate("KvantumPreviewBase", "3rd Item", nullptr));
        QTreeWidgetItem *___qtreewidgetitem2 = treeWidget->topLevelItem(1);
        ___qtreewidgetitem2->setText(0, QCoreApplication::translate("KvantumPreviewBase", "2nd Item", nullptr));
        QTreeWidgetItem *___qtreewidgetitem3 = ___qtreewidgetitem2->child(0);
        ___qtreewidgetitem3->setText(0, QCoreApplication::translate("KvantumPreviewBase", "2nd Child", nullptr));
        QTreeWidgetItem *___qtreewidgetitem4 = ___qtreewidgetitem2->child(1);
        ___qtreewidgetitem4->setText(0, QCoreApplication::translate("KvantumPreviewBase", "1st Child", nullptr));
        QTreeWidgetItem *___qtreewidgetitem5 = treeWidget->topLevelItem(2);
        ___qtreewidgetitem5->setText(2, QCoreApplication::translate("KvantumPreviewBase", "Editable", nullptr));
        ___qtreewidgetitem5->setText(1, QCoreApplication::translate("KvantumPreviewBase", "Editable", nullptr));
        ___qtreewidgetitem5->setText(0, QCoreApplication::translate("KvantumPreviewBase", "1st Item", nullptr));
        QTreeWidgetItem *___qtreewidgetitem6 = ___qtreewidgetitem5->child(0);
        ___qtreewidgetitem6->setText(0, QCoreApplication::translate("KvantumPreviewBase", "3rd Child", nullptr));
        QTreeWidgetItem *___qtreewidgetitem7 = ___qtreewidgetitem5->child(1);
        ___qtreewidgetitem7->setText(0, QCoreApplication::translate("KvantumPreviewBase", "2nd Child", nullptr));
        QTreeWidgetItem *___qtreewidgetitem8 = ___qtreewidgetitem5->child(2);
        ___qtreewidgetitem8->setText(1, QCoreApplication::translate("KvantumPreviewBase", "Non-Editable", nullptr));
        ___qtreewidgetitem8->setText(0, QCoreApplication::translate("KvantumPreviewBase", "1st Child", nullptr));
        treeWidget->setSortingEnabled(__sortingEnabled);


        const bool __sortingEnabled1 = listWidget->isSortingEnabled();
        listWidget->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = listWidget->item(0);
        ___qlistwidgetitem->setText(QCoreApplication::translate("KvantumPreviewBase", "1st Item", nullptr));
        QListWidgetItem *___qlistwidgetitem1 = listWidget->item(1);
        ___qlistwidgetitem1->setText(QCoreApplication::translate("KvantumPreviewBase", "2nd Item", nullptr));
        QListWidgetItem *___qlistwidgetitem2 = listWidget->item(2);
        ___qlistwidgetitem2->setText(QCoreApplication::translate("KvantumPreviewBase", "3rd Item", nullptr));
        listWidget->setSortingEnabled(__sortingEnabled1);

        subwindow->setWindowTitle(QCoreApplication::translate("KvantumPreviewBase", "Subwindow", nullptr));
        label_5->setText(QCoreApplication::translate("KvantumPreviewBase", "Panel frame", nullptr));
        groupBox_3->setTitle(QCoreApplication::translate("KvantumPreviewBase", "GroupBox", nullptr));
        label_16->setText(QCoreApplication::translate("KvantumPreviewBase", "Page 1 (disabled)", nullptr));
        tabWidget_6->setTabText(tabWidget_6->indexOf(tab_15), QCoreApplication::translate("KvantumPreviewBase", "Tab 1", nullptr));
        label_17->setText(QCoreApplication::translate("KvantumPreviewBase", "Page 2 (disabled)", nullptr));
        tabWidget_6->setTabText(tabWidget_6->indexOf(tab_16), QCoreApplication::translate("KvantumPreviewBase", "Tab 2", nullptr));
        label_12->setText(QCoreApplication::translate("KvantumPreviewBase", "Page 1", nullptr));
        tabWidget_5->setTabText(tabWidget_5->indexOf(tab_13), QCoreApplication::translate("KvantumPreviewBase", "Tab 1", nullptr));
        label_14->setText(QCoreApplication::translate("KvantumPreviewBase", "Page 2", nullptr));
        tabWidget_5->setTabText(tabWidget_5->indexOf(tab_14), QCoreApplication::translate("KvantumPreviewBase", "Tab 2", nullptr));
        label_2->setText(QCoreApplication::translate("KvantumPreviewBase", "Stack widget (page1)", nullptr));
        label_3->setText(QCoreApplication::translate("KvantumPreviewBase", "Stack Widget (page2)", nullptr));
        groupBox->setTitle(QCoreApplication::translate("KvantumPreviewBase", "GroupBox", nullptr));
        label_6->setText(QCoreApplication::translate("KvantumPreviewBase", "Group box", nullptr));
        QTableWidgetItem *___qtablewidgetitem = tableWidget->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(QCoreApplication::translate("KvantumPreviewBase", "Column 0", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = tableWidget->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(QCoreApplication::translate("KvantumPreviewBase", "Column 1", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = tableWidget->verticalHeaderItem(0);
        ___qtablewidgetitem2->setText(QCoreApplication::translate("KvantumPreviewBase", "Row 0", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = tableWidget->verticalHeaderItem(1);
        ___qtablewidgetitem3->setText(QCoreApplication::translate("KvantumPreviewBase", "Row 1", nullptr));

        const bool __sortingEnabled2 = tableWidget->isSortingEnabled();
        tableWidget->setSortingEnabled(false);
        QTableWidgetItem *___qtablewidgetitem4 = tableWidget->item(0, 0);
        ___qtablewidgetitem4->setText(QCoreApplication::translate("KvantumPreviewBase", "0-0", nullptr));
        QTableWidgetItem *___qtablewidgetitem5 = tableWidget->item(0, 1);
        ___qtablewidgetitem5->setText(QCoreApplication::translate("KvantumPreviewBase", "0-1", nullptr));
        QTableWidgetItem *___qtablewidgetitem6 = tableWidget->item(1, 0);
        ___qtablewidgetitem6->setText(QCoreApplication::translate("KvantumPreviewBase", "1-0", nullptr));
        QTableWidgetItem *___qtablewidgetitem7 = tableWidget->item(1, 1);
        ___qtablewidgetitem7->setText(QCoreApplication::translate("KvantumPreviewBase", "1-1", nullptr));
        tableWidget->setSortingEnabled(__sortingEnabled2);

        dockWidget->setWindowTitle(QCoreApplication::translate("KvantumPreviewBase", "Dock Widget", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("KvantumPreviewBase", "GroupBox", nullptr));
        label_8->setText(QCoreApplication::translate("KvantumPreviewBase", "Checkable group box", nullptr));
        label_18->setText(QCoreApplication::translate("KvantumPreviewBase", "Tool Box", nullptr));
        toolBox->setItemText(toolBox->indexOf(page), QCoreApplication::translate("KvantumPreviewBase", "Page 1", nullptr));
        toolBox->setItemText(toolBox->indexOf(page_2), QCoreApplication::translate("KvantumPreviewBase", "Page 2", nullptr));
        toolBox_2->setItemText(toolBox_2->indexOf(page_3), QCoreApplication::translate("KvantumPreviewBase", "Page 1", nullptr));
        toolBox_2->setItemText(toolBox_2->indexOf(page_4), QCoreApplication::translate("KvantumPreviewBase", "Page 2", nullptr));
        checkBoxDocMode->setText(QCoreApplication::translate("KvantumPreviewBase", "Document mode", nullptr));
        tabWidget_2->setTabText(tabWidget_2->indexOf(tab_7), QCoreApplication::translate("KvantumPreviewBase", "Tab 1", nullptr));
        label_9->setText(QCoreApplication::translate("KvantumPreviewBase", "Page 2", nullptr));
        tabWidget_2->setTabText(tabWidget_2->indexOf(tab_8), QCoreApplication::translate("KvantumPreviewBase", "Tab 2", nullptr));
        label_4->setText(QCoreApplication::translate("KvantumPreviewBase", "Box frame", nullptr));
        label_10->setText(QCoreApplication::translate("KvantumPreviewBase", "Page 1", nullptr));
        tabWidget_3->setTabText(tabWidget_3->indexOf(tab_9), QCoreApplication::translate("KvantumPreviewBase", "Tab 1", nullptr));
        label_11->setText(QCoreApplication::translate("KvantumPreviewBase", "Page 2", nullptr));
        tabWidget_3->setTabText(tabWidget_3->indexOf(tab_10), QCoreApplication::translate("KvantumPreviewBase", "Tab 2", nullptr));
        label_15->setText(QCoreApplication::translate("KvantumPreviewBase", "Page 1", nullptr));
        tabWidget_4->setTabText(tabWidget_4->indexOf(tab_12), QCoreApplication::translate("KvantumPreviewBase", "Tab 1", nullptr));
        label_13->setText(QCoreApplication::translate("KvantumPreviewBase", "Page 2", nullptr));
        tabWidget_4->setTabText(tabWidget_4->indexOf(tab_11), QCoreApplication::translate("KvantumPreviewBase", "Tab 2", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_4), QCoreApplication::translate("KvantumPreviewBase", "Containers", nullptr));
        menuFile->setTitle(QCoreApplication::translate("KvantumPreviewBase", "&File", nullptr));
        menuSubmenu->setTitle(QCoreApplication::translate("KvantumPreviewBase", "&Submenu", nullptr));
        toolBar->setWindowTitle(QCoreApplication::translate("KvantumPreviewBase", "toolBar", nullptr));
        toolBar_2->setWindowTitle(QCoreApplication::translate("KvantumPreviewBase", "toolBar_2", nullptr));
    } // retranslateUi

};

namespace Ui {
    class KvantumPreviewBase: public Ui_KvantumPreviewBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_KVANTUMPREVIEWBASE_H
